(function(){const m=document.createElement("link").relList;if(m&&m.supports&&m.supports("modulepreload"))return;for(const D of document.querySelectorAll('link[rel="modulepreload"]'))r(D);new MutationObserver(D=>{for(const p of D)if(p.type==="childList")for(const x of p.addedNodes)x.tagName==="LINK"&&x.rel==="modulepreload"&&r(x)}).observe(document,{childList:!0,subtree:!0});function b(D){const p={};return D.integrity&&(p.integrity=D.integrity),D.referrerPolicy&&(p.referrerPolicy=D.referrerPolicy),D.crossOrigin==="use-credentials"?p.credentials="include":D.crossOrigin==="anonymous"?p.credentials="omit":p.credentials="same-origin",p}function r(D){if(D.ep)return;D.ep=!0;const p=b(D);fetch(D.href,p)}})();var hf={exports:{}},Ru={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var nd;function w1(){if(nd)return Ru;nd=1;var f=Symbol.for("react.transitional.element"),m=Symbol.for("react.fragment");function b(r,D,p){var x=null;if(p!==void 0&&(x=""+p),D.key!==void 0&&(x=""+D.key),"key"in D){p={};for(var N in D)N!=="key"&&(p[N]=D[N])}else p=D;return D=p.ref,{$$typeof:f,type:r,key:x,ref:D!==void 0?D:null,props:p}}return Ru.Fragment=m,Ru.jsx=b,Ru.jsxs=b,Ru}var id;function J1(){return id||(id=1,hf.exports=w1()),hf.exports}var A=J1(),vf={exports:{}},J={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var cd;function k1(){if(cd)return J;cd=1;var f=Symbol.for("react.transitional.element"),m=Symbol.for("react.portal"),b=Symbol.for("react.fragment"),r=Symbol.for("react.strict_mode"),D=Symbol.for("react.profiler"),p=Symbol.for("react.consumer"),x=Symbol.for("react.context"),N=Symbol.for("react.forward_ref"),O=Symbol.for("react.suspense"),S=Symbol.for("react.memo"),R=Symbol.for("react.lazy"),Y=Symbol.iterator;function w(o){return o===null||typeof o!="object"?null:(o=Y&&o[Y]||o["@@iterator"],typeof o=="function"?o:null)}var P={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},Al=Object.assign,wl={};function Zl(o,_,Q){this.props=o,this.context=_,this.refs=wl,this.updater=Q||P}Zl.prototype.isReactComponent={},Zl.prototype.setState=function(o,_){if(typeof o!="object"&&typeof o!="function"&&o!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,o,_,"setState")},Zl.prototype.forceUpdate=function(o){this.updater.enqueueForceUpdate(this,o,"forceUpdate")};function al(){}al.prototype=Zl.prototype;function el(o,_,Q){this.props=o,this.context=_,this.refs=wl,this.updater=Q||P}var sl=el.prototype=new al;sl.constructor=el,Al(sl,Zl.prototype),sl.isPureReactComponent=!0;var bt=Array.isArray,il={H:null,A:null,T:null,S:null},Jl=Object.prototype.hasOwnProperty;function It(o,_,Q,C,H,ll){return Q=ll.ref,{$$typeof:f,type:o,key:_,ref:Q!==void 0?Q:null,props:ll}}function la(o,_){return It(o.type,_,void 0,void 0,void 0,o.props)}function X(o){return typeof o=="object"&&o!==null&&o.$$typeof===f}function cl(o){var _={"=":"=0",":":"=2"};return"$"+o.replace(/[=:]/g,function(Q){return _[Q]})}var nt=/\/+/g;function Ut(o,_){return typeof o=="object"&&o!==null&&o.key!=null?cl(""+o.key):_.toString(36)}function zt(){}function Rt(o){switch(o.status){case"fulfilled":return o.value;case"rejected":throw o.reason;default:switch(typeof o.status=="string"?o.then(zt,zt):(o.status="pending",o.then(function(_){o.status==="pending"&&(o.status="fulfilled",o.value=_)},function(_){o.status==="pending"&&(o.status="rejected",o.reason=_)})),o.status){case"fulfilled":return o.value;case"rejected":throw o.reason}}throw o}function kl(o,_,Q,C,H){var ll=typeof o;(ll==="undefined"||ll==="boolean")&&(o=null);var k=!1;if(o===null)k=!0;else switch(ll){case"bigint":case"string":case"number":k=!0;break;case"object":switch(o.$$typeof){case f:case m:k=!0;break;case R:return k=o._init,kl(k(o._payload),_,Q,C,H)}}if(k)return H=H(o),k=C===""?"."+Ut(o,0):C,bt(H)?(Q="",k!=null&&(Q=k.replace(nt,"$&/")+"/"),kl(H,_,Q,"",function(Ol){return Ol})):H!=null&&(X(H)&&(H=la(H,Q+(H.key==null||o&&o.key===H.key?"":(""+H.key).replace(nt,"$&/")+"/")+k)),_.push(H)),1;k=0;var Vl=C===""?".":C+":";if(bt(o))for(var fl=0;fl<o.length;fl++)C=o[fl],ll=Vl+Ut(C,fl),k+=kl(C,_,Q,ll,H);else if(fl=w(o),typeof fl=="function")for(o=fl.call(o),fl=0;!(C=o.next()).done;)C=C.value,ll=Vl+Ut(C,fl++),k+=kl(C,_,Q,ll,H);else if(ll==="object"){if(typeof o.then=="function")return kl(Rt(o),_,Q,C,H);throw _=String(o),Error("Objects are not valid as a React child (found: "+(_==="[object Object]"?"object with keys {"+Object.keys(o).join(", ")+"}":_)+"). If you meant to render a collection of children, use an array instead.")}return k}function U(o,_,Q){if(o==null)return o;var C=[],H=0;return kl(o,C,"","",function(ll){return _.call(Q,ll,H++)}),C}function K(o){if(o._status===-1){var _=o._result;_=_(),_.then(function(Q){(o._status===0||o._status===-1)&&(o._status=1,o._result=Q)},function(Q){(o._status===0||o._status===-1)&&(o._status=2,o._result=Q)}),o._status===-1&&(o._status=0,o._result=_)}if(o._status===1)return o._result.default;throw o._result}var Z=typeof reportError=="function"?reportError:function(o){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var _=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof o=="object"&&o!==null&&typeof o.message=="string"?String(o.message):String(o),error:o});if(!window.dispatchEvent(_))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",o);return}console.error(o)};function hl(){}return J.Children={map:U,forEach:function(o,_,Q){U(o,function(){_.apply(this,arguments)},Q)},count:function(o){var _=0;return U(o,function(){_++}),_},toArray:function(o){return U(o,function(_){return _})||[]},only:function(o){if(!X(o))throw Error("React.Children.only expected to receive a single React element child.");return o}},J.Component=Zl,J.Fragment=b,J.Profiler=D,J.PureComponent=el,J.StrictMode=r,J.Suspense=O,J.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=il,J.act=function(){throw Error("act(...) is not supported in production builds of React.")},J.cache=function(o){return function(){return o.apply(null,arguments)}},J.cloneElement=function(o,_,Q){if(o==null)throw Error("The argument must be a React element, but you passed "+o+".");var C=Al({},o.props),H=o.key,ll=void 0;if(_!=null)for(k in _.ref!==void 0&&(ll=void 0),_.key!==void 0&&(H=""+_.key),_)!Jl.call(_,k)||k==="key"||k==="__self"||k==="__source"||k==="ref"&&_.ref===void 0||(C[k]=_[k]);var k=arguments.length-2;if(k===1)C.children=Q;else if(1<k){for(var Vl=Array(k),fl=0;fl<k;fl++)Vl[fl]=arguments[fl+2];C.children=Vl}return It(o.type,H,void 0,void 0,ll,C)},J.createContext=function(o){return o={$$typeof:x,_currentValue:o,_currentValue2:o,_threadCount:0,Provider:null,Consumer:null},o.Provider=o,o.Consumer={$$typeof:p,_context:o},o},J.createElement=function(o,_,Q){var C,H={},ll=null;if(_!=null)for(C in _.key!==void 0&&(ll=""+_.key),_)Jl.call(_,C)&&C!=="key"&&C!=="__self"&&C!=="__source"&&(H[C]=_[C]);var k=arguments.length-2;if(k===1)H.children=Q;else if(1<k){for(var Vl=Array(k),fl=0;fl<k;fl++)Vl[fl]=arguments[fl+2];H.children=Vl}if(o&&o.defaultProps)for(C in k=o.defaultProps,k)H[C]===void 0&&(H[C]=k[C]);return It(o,ll,void 0,void 0,null,H)},J.createRef=function(){return{current:null}},J.forwardRef=function(o){return{$$typeof:N,render:o}},J.isValidElement=X,J.lazy=function(o){return{$$typeof:R,_payload:{_status:-1,_result:o},_init:K}},J.memo=function(o,_){return{$$typeof:S,type:o,compare:_===void 0?null:_}},J.startTransition=function(o){var _=il.T,Q={};il.T=Q;try{var C=o(),H=il.S;H!==null&&H(Q,C),typeof C=="object"&&C!==null&&typeof C.then=="function"&&C.then(hl,Z)}catch(ll){Z(ll)}finally{il.T=_}},J.unstable_useCacheRefresh=function(){return il.H.useCacheRefresh()},J.use=function(o){return il.H.use(o)},J.useActionState=function(o,_,Q){return il.H.useActionState(o,_,Q)},J.useCallback=function(o,_){return il.H.useCallback(o,_)},J.useContext=function(o){return il.H.useContext(o)},J.useDebugValue=function(){},J.useDeferredValue=function(o,_){return il.H.useDeferredValue(o,_)},J.useEffect=function(o,_){return il.H.useEffect(o,_)},J.useId=function(){return il.H.useId()},J.useImperativeHandle=function(o,_,Q){return il.H.useImperativeHandle(o,_,Q)},J.useInsertionEffect=function(o,_){return il.H.useInsertionEffect(o,_)},J.useLayoutEffect=function(o,_){return il.H.useLayoutEffect(o,_)},J.useMemo=function(o,_){return il.H.useMemo(o,_)},J.useOptimistic=function(o,_){return il.H.useOptimistic(o,_)},J.useReducer=function(o,_,Q){return il.H.useReducer(o,_,Q)},J.useRef=function(o){return il.H.useRef(o)},J.useState=function(o){return il.H.useState(o)},J.useSyncExternalStore=function(o,_,Q){return il.H.useSyncExternalStore(o,_,Q)},J.useTransition=function(){return il.H.useTransition()},J.version="19.0.0",J}var fd;function Ef(){return fd||(fd=1,vf.exports=k1()),vf.exports}var L=Ef(),yf={exports:{}},Hu={},mf={exports:{}},gf={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var sd;function $1(){return sd||(sd=1,function(f){function m(U,K){var Z=U.length;U.push(K);l:for(;0<Z;){var hl=Z-1>>>1,o=U[hl];if(0<D(o,K))U[hl]=K,U[Z]=o,Z=hl;else break l}}function b(U){return U.length===0?null:U[0]}function r(U){if(U.length===0)return null;var K=U[0],Z=U.pop();if(Z!==K){U[0]=Z;l:for(var hl=0,o=U.length,_=o>>>1;hl<_;){var Q=2*(hl+1)-1,C=U[Q],H=Q+1,ll=U[H];if(0>D(C,Z))H<o&&0>D(ll,C)?(U[hl]=ll,U[H]=Z,hl=H):(U[hl]=C,U[Q]=Z,hl=Q);else if(H<o&&0>D(ll,Z))U[hl]=ll,U[H]=Z,hl=H;else break l}}return K}function D(U,K){var Z=U.sortIndex-K.sortIndex;return Z!==0?Z:U.id-K.id}if(f.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var p=performance;f.unstable_now=function(){return p.now()}}else{var x=Date,N=x.now();f.unstable_now=function(){return x.now()-N}}var O=[],S=[],R=1,Y=null,w=3,P=!1,Al=!1,wl=!1,Zl=typeof setTimeout=="function"?setTimeout:null,al=typeof clearTimeout=="function"?clearTimeout:null,el=typeof setImmediate<"u"?setImmediate:null;function sl(U){for(var K=b(S);K!==null;){if(K.callback===null)r(S);else if(K.startTime<=U)r(S),K.sortIndex=K.expirationTime,m(O,K);else break;K=b(S)}}function bt(U){if(wl=!1,sl(U),!Al)if(b(O)!==null)Al=!0,Rt();else{var K=b(S);K!==null&&kl(bt,K.startTime-U)}}var il=!1,Jl=-1,It=5,la=-1;function X(){return!(f.unstable_now()-la<It)}function cl(){if(il){var U=f.unstable_now();la=U;var K=!0;try{l:{Al=!1,wl&&(wl=!1,al(Jl),Jl=-1),P=!0;var Z=w;try{t:{for(sl(U),Y=b(O);Y!==null&&!(Y.expirationTime>U&&X());){var hl=Y.callback;if(typeof hl=="function"){Y.callback=null,w=Y.priorityLevel;var o=hl(Y.expirationTime<=U);if(U=f.unstable_now(),typeof o=="function"){Y.callback=o,sl(U),K=!0;break t}Y===b(O)&&r(O),sl(U)}else r(O);Y=b(O)}if(Y!==null)K=!0;else{var _=b(S);_!==null&&kl(bt,_.startTime-U),K=!1}}break l}finally{Y=null,w=Z,P=!1}K=void 0}}finally{K?nt():il=!1}}}var nt;if(typeof el=="function")nt=function(){el(cl)};else if(typeof MessageChannel<"u"){var Ut=new MessageChannel,zt=Ut.port2;Ut.port1.onmessage=cl,nt=function(){zt.postMessage(null)}}else nt=function(){Zl(cl,0)};function Rt(){il||(il=!0,nt())}function kl(U,K){Jl=Zl(function(){U(f.unstable_now())},K)}f.unstable_IdlePriority=5,f.unstable_ImmediatePriority=1,f.unstable_LowPriority=4,f.unstable_NormalPriority=3,f.unstable_Profiling=null,f.unstable_UserBlockingPriority=2,f.unstable_cancelCallback=function(U){U.callback=null},f.unstable_continueExecution=function(){Al||P||(Al=!0,Rt())},f.unstable_forceFrameRate=function(U){0>U||125<U?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):It=0<U?Math.floor(1e3/U):5},f.unstable_getCurrentPriorityLevel=function(){return w},f.unstable_getFirstCallbackNode=function(){return b(O)},f.unstable_next=function(U){switch(w){case 1:case 2:case 3:var K=3;break;default:K=w}var Z=w;w=K;try{return U()}finally{w=Z}},f.unstable_pauseExecution=function(){},f.unstable_requestPaint=function(){},f.unstable_runWithPriority=function(U,K){switch(U){case 1:case 2:case 3:case 4:case 5:break;default:U=3}var Z=w;w=U;try{return K()}finally{w=Z}},f.unstable_scheduleCallback=function(U,K,Z){var hl=f.unstable_now();switch(typeof Z=="object"&&Z!==null?(Z=Z.delay,Z=typeof Z=="number"&&0<Z?hl+Z:hl):Z=hl,U){case 1:var o=-1;break;case 2:o=250;break;case 5:o=1073741823;break;case 4:o=1e4;break;default:o=5e3}return o=Z+o,U={id:R++,callback:K,priorityLevel:U,startTime:Z,expirationTime:o,sortIndex:-1},Z>hl?(U.sortIndex=Z,m(S,U),b(O)===null&&U===b(S)&&(wl?(al(Jl),Jl=-1):wl=!0,kl(bt,Z-hl))):(U.sortIndex=o,m(O,U),Al||P||(Al=!0,Rt())),U},f.unstable_shouldYield=X,f.unstable_wrapCallback=function(U){var K=w;return function(){var Z=w;w=K;try{return U.apply(this,arguments)}finally{w=Z}}}}(gf)),gf}var rd;function W1(){return rd||(rd=1,mf.exports=$1()),mf.exports}var bf={exports:{}},Xl={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var od;function F1(){if(od)return Xl;od=1;var f=Ef();function m(O){var S="https://react.dev/errors/"+O;if(1<arguments.length){S+="?args[]="+encodeURIComponent(arguments[1]);for(var R=2;R<arguments.length;R++)S+="&args[]="+encodeURIComponent(arguments[R])}return"Minified React error #"+O+"; visit "+S+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function b(){}var r={d:{f:b,r:function(){throw Error(m(522))},D:b,C:b,L:b,m:b,X:b,S:b,M:b},p:0,findDOMNode:null},D=Symbol.for("react.portal");function p(O,S,R){var Y=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:D,key:Y==null?null:""+Y,children:O,containerInfo:S,implementation:R}}var x=f.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function N(O,S){if(O==="font")return"";if(typeof S=="string")return S==="use-credentials"?S:""}return Xl.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=r,Xl.createPortal=function(O,S){var R=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!S||S.nodeType!==1&&S.nodeType!==9&&S.nodeType!==11)throw Error(m(299));return p(O,S,null,R)},Xl.flushSync=function(O){var S=x.T,R=r.p;try{if(x.T=null,r.p=2,O)return O()}finally{x.T=S,r.p=R,r.d.f()}},Xl.preconnect=function(O,S){typeof O=="string"&&(S?(S=S.crossOrigin,S=typeof S=="string"?S==="use-credentials"?S:"":void 0):S=null,r.d.C(O,S))},Xl.prefetchDNS=function(O){typeof O=="string"&&r.d.D(O)},Xl.preinit=function(O,S){if(typeof O=="string"&&S&&typeof S.as=="string"){var R=S.as,Y=N(R,S.crossOrigin),w=typeof S.integrity=="string"?S.integrity:void 0,P=typeof S.fetchPriority=="string"?S.fetchPriority:void 0;R==="style"?r.d.S(O,typeof S.precedence=="string"?S.precedence:void 0,{crossOrigin:Y,integrity:w,fetchPriority:P}):R==="script"&&r.d.X(O,{crossOrigin:Y,integrity:w,fetchPriority:P,nonce:typeof S.nonce=="string"?S.nonce:void 0})}},Xl.preinitModule=function(O,S){if(typeof O=="string")if(typeof S=="object"&&S!==null){if(S.as==null||S.as==="script"){var R=N(S.as,S.crossOrigin);r.d.M(O,{crossOrigin:R,integrity:typeof S.integrity=="string"?S.integrity:void 0,nonce:typeof S.nonce=="string"?S.nonce:void 0})}}else S==null&&r.d.M(O)},Xl.preload=function(O,S){if(typeof O=="string"&&typeof S=="object"&&S!==null&&typeof S.as=="string"){var R=S.as,Y=N(R,S.crossOrigin);r.d.L(O,R,{crossOrigin:Y,integrity:typeof S.integrity=="string"?S.integrity:void 0,nonce:typeof S.nonce=="string"?S.nonce:void 0,type:typeof S.type=="string"?S.type:void 0,fetchPriority:typeof S.fetchPriority=="string"?S.fetchPriority:void 0,referrerPolicy:typeof S.referrerPolicy=="string"?S.referrerPolicy:void 0,imageSrcSet:typeof S.imageSrcSet=="string"?S.imageSrcSet:void 0,imageSizes:typeof S.imageSizes=="string"?S.imageSizes:void 0,media:typeof S.media=="string"?S.media:void 0})}},Xl.preloadModule=function(O,S){if(typeof O=="string")if(S){var R=N(S.as,S.crossOrigin);r.d.m(O,{as:typeof S.as=="string"&&S.as!=="script"?S.as:void 0,crossOrigin:R,integrity:typeof S.integrity=="string"?S.integrity:void 0})}else r.d.m(O)},Xl.requestFormReset=function(O){r.d.r(O)},Xl.unstable_batchedUpdates=function(O,S){return O(S)},Xl.useFormState=function(O,S,R){return x.H.useFormState(O,S,R)},Xl.useFormStatus=function(){return x.H.useHostTransitionStatus()},Xl.version="19.0.0",Xl}var dd;function P1(){if(dd)return bf.exports;dd=1;function f(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(f)}catch(m){console.error(m)}}return f(),bf.exports=F1(),bf.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var hd;function I1(){if(hd)return Hu;hd=1;var f=W1(),m=Ef(),b=P1();function r(l){var t="https://react.dev/errors/"+l;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var a=2;a<arguments.length;a++)t+="&args[]="+encodeURIComponent(arguments[a])}return"Minified React error #"+l+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function D(l){return!(!l||l.nodeType!==1&&l.nodeType!==9&&l.nodeType!==11)}var p=Symbol.for("react.element"),x=Symbol.for("react.transitional.element"),N=Symbol.for("react.portal"),O=Symbol.for("react.fragment"),S=Symbol.for("react.strict_mode"),R=Symbol.for("react.profiler"),Y=Symbol.for("react.provider"),w=Symbol.for("react.consumer"),P=Symbol.for("react.context"),Al=Symbol.for("react.forward_ref"),wl=Symbol.for("react.suspense"),Zl=Symbol.for("react.suspense_list"),al=Symbol.for("react.memo"),el=Symbol.for("react.lazy"),sl=Symbol.for("react.offscreen"),bt=Symbol.for("react.memo_cache_sentinel"),il=Symbol.iterator;function Jl(l){return l===null||typeof l!="object"?null:(l=il&&l[il]||l["@@iterator"],typeof l=="function"?l:null)}var It=Symbol.for("react.client.reference");function la(l){if(l==null)return null;if(typeof l=="function")return l.$$typeof===It?null:l.displayName||l.name||null;if(typeof l=="string")return l;switch(l){case O:return"Fragment";case N:return"Portal";case R:return"Profiler";case S:return"StrictMode";case wl:return"Suspense";case Zl:return"SuspenseList"}if(typeof l=="object")switch(l.$$typeof){case P:return(l.displayName||"Context")+".Provider";case w:return(l._context.displayName||"Context")+".Consumer";case Al:var t=l.render;return l=l.displayName,l||(l=t.displayName||t.name||"",l=l!==""?"ForwardRef("+l+")":"ForwardRef"),l;case al:return t=l.displayName||null,t!==null?t:la(l.type)||"Memo";case el:t=l._payload,l=l._init;try{return la(l(t))}catch{}}return null}var X=m.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,cl=Object.assign,nt,Ut;function zt(l){if(nt===void 0)try{throw Error()}catch(a){var t=a.stack.trim().match(/\n( *(at )?)/);nt=t&&t[1]||"",Ut=-1<a.stack.indexOf(`
    at`)?" (<anonymous>)":-1<a.stack.indexOf("@")?"@unknown:0:0":""}return`
`+nt+l+Ut}var Rt=!1;function kl(l,t){if(!l||Rt)return"";Rt=!0;var a=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var e={DetermineComponentFrameRoot:function(){try{if(t){var M=function(){throw Error()};if(Object.defineProperty(M.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(M,[])}catch(E){var g=E}Reflect.construct(l,[],M)}else{try{M.call()}catch(E){g=E}l.call(M.prototype)}}else{try{throw Error()}catch(E){g=E}(M=l())&&typeof M.catch=="function"&&M.catch(function(){})}}catch(E){if(E&&g&&typeof E.stack=="string")return[E.stack,g.stack]}return[null,null]}};e.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var u=Object.getOwnPropertyDescriptor(e.DetermineComponentFrameRoot,"name");u&&u.configurable&&Object.defineProperty(e.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var n=e.DetermineComponentFrameRoot(),i=n[0],c=n[1];if(i&&c){var s=i.split(`
`),h=c.split(`
`);for(u=e=0;e<s.length&&!s[e].includes("DetermineComponentFrameRoot");)e++;for(;u<h.length&&!h[u].includes("DetermineComponentFrameRoot");)u++;if(e===s.length||u===h.length)for(e=s.length-1,u=h.length-1;1<=e&&0<=u&&s[e]!==h[u];)u--;for(;1<=e&&0<=u;e--,u--)if(s[e]!==h[u]){if(e!==1||u!==1)do if(e--,u--,0>u||s[e]!==h[u]){var T=`
`+s[e].replace(" at new "," at ");return l.displayName&&T.includes("<anonymous>")&&(T=T.replace("<anonymous>",l.displayName)),T}while(1<=e&&0<=u);break}}}finally{Rt=!1,Error.prepareStackTrace=a}return(a=l?l.displayName||l.name:"")?zt(a):""}function U(l){switch(l.tag){case 26:case 27:case 5:return zt(l.type);case 16:return zt("Lazy");case 13:return zt("Suspense");case 19:return zt("SuspenseList");case 0:case 15:return l=kl(l.type,!1),l;case 11:return l=kl(l.type.render,!1),l;case 1:return l=kl(l.type,!0),l;default:return""}}function K(l){try{var t="";do t+=U(l),l=l.return;while(l);return t}catch(a){return`
Error generating stack: `+a.message+`
`+a.stack}}function Z(l){var t=l,a=l;if(l.alternate)for(;t.return;)t=t.return;else{l=t;do t=l,t.flags&4098&&(a=t.return),l=t.return;while(l)}return t.tag===3?a:null}function hl(l){if(l.tag===13){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function o(l){if(Z(l)!==l)throw Error(r(188))}function _(l){var t=l.alternate;if(!t){if(t=Z(l),t===null)throw Error(r(188));return t!==l?null:l}for(var a=l,e=t;;){var u=a.return;if(u===null)break;var n=u.alternate;if(n===null){if(e=u.return,e!==null){a=e;continue}break}if(u.child===n.child){for(n=u.child;n;){if(n===a)return o(u),l;if(n===e)return o(u),t;n=n.sibling}throw Error(r(188))}if(a.return!==e.return)a=u,e=n;else{for(var i=!1,c=u.child;c;){if(c===a){i=!0,a=u,e=n;break}if(c===e){i=!0,e=u,a=n;break}c=c.sibling}if(!i){for(c=n.child;c;){if(c===a){i=!0,a=n,e=u;break}if(c===e){i=!0,e=n,a=u;break}c=c.sibling}if(!i)throw Error(r(189))}}if(a.alternate!==e)throw Error(r(190))}if(a.tag!==3)throw Error(r(188));return a.stateNode.current===a?l:t}function Q(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l;for(l=l.child;l!==null;){if(t=Q(l),t!==null)return t;l=l.sibling}return null}var C=Array.isArray,H=b.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,ll={pending:!1,data:null,method:null,action:null},k=[],Vl=-1;function fl(l){return{current:l}}function Ol(l){0>Vl||(l.current=k[Vl],k[Vl]=null,Vl--)}function ml(l,t){Vl++,k[Vl]=l.current,l.current=t}var At=fl(null),qe=fl(null),ta=fl(null),Bu=fl(null);function Yu(l,t){switch(ml(ta,t),ml(qe,l),ml(At,null),l=t.nodeType,l){case 9:case 11:t=(t=t.documentElement)&&(t=t.namespaceURI)?jo(t):0;break;default:if(l=l===8?t.parentNode:t,t=l.tagName,l=l.namespaceURI)l=jo(l),t=qo(l,t);else switch(t){case"svg":t=1;break;case"math":t=2;break;default:t=0}}Ol(At),ml(At,t)}function Pa(){Ol(At),Ol(qe),Ol(ta)}function ei(l){l.memoizedState!==null&&ml(Bu,l);var t=At.current,a=qo(t,l.type);t!==a&&(ml(qe,l),ml(At,a))}function Cu(l){qe.current===l&&(Ol(At),Ol(qe)),Bu.current===l&&(Ol(Bu),Du._currentValue=ll)}var ui=Object.prototype.hasOwnProperty,ni=f.unstable_scheduleCallback,ii=f.unstable_cancelCallback,Ad=f.unstable_shouldYield,Od=f.unstable_requestPaint,Ot=f.unstable_now,Md=f.unstable_getCurrentPriorityLevel,Tf=f.unstable_ImmediatePriority,zf=f.unstable_UserBlockingPriority,Gu=f.unstable_NormalPriority,Dd=f.unstable_LowPriority,Af=f.unstable_IdlePriority,_d=f.log,Nd=f.unstable_setDisableYieldValue,Be=null,Pl=null;function xd(l){if(Pl&&typeof Pl.onCommitFiberRoot=="function")try{Pl.onCommitFiberRoot(Be,l,void 0,(l.current.flags&128)===128)}catch{}}function aa(l){if(typeof _d=="function"&&Nd(l),Pl&&typeof Pl.setStrictMode=="function")try{Pl.setStrictMode(Be,l)}catch{}}var Il=Math.clz32?Math.clz32:Hd,Ud=Math.log,Rd=Math.LN2;function Hd(l){return l>>>=0,l===0?32:31-(Ud(l)/Rd|0)|0}var Xu=128,Qu=4194304;function Da(l){var t=l&42;if(t!==0)return t;switch(l&-l){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return l&4194176;case 4194304:case 8388608:case 16777216:case 33554432:return l&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return l}}function Zu(l,t){var a=l.pendingLanes;if(a===0)return 0;var e=0,u=l.suspendedLanes,n=l.pingedLanes,i=l.warmLanes;l=l.finishedLanes!==0;var c=a&134217727;return c!==0?(a=c&~u,a!==0?e=Da(a):(n&=c,n!==0?e=Da(n):l||(i=c&~i,i!==0&&(e=Da(i))))):(c=a&~u,c!==0?e=Da(c):n!==0?e=Da(n):l||(i=a&~i,i!==0&&(e=Da(i)))),e===0?0:t!==0&&t!==e&&!(t&u)&&(u=e&-e,i=t&-t,u>=i||u===32&&(i&4194176)!==0)?t:e}function Ye(l,t){return(l.pendingLanes&~(l.suspendedLanes&~l.pingedLanes)&t)===0}function jd(l,t){switch(l){case 1:case 2:case 4:case 8:return t+250;case 16:case 32:case 64:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function Of(){var l=Xu;return Xu<<=1,!(Xu&4194176)&&(Xu=128),l}function Mf(){var l=Qu;return Qu<<=1,!(Qu&62914560)&&(Qu=4194304),l}function ci(l){for(var t=[],a=0;31>a;a++)t.push(l);return t}function Ce(l,t){l.pendingLanes|=t,t!==268435456&&(l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0)}function qd(l,t,a,e,u,n){var i=l.pendingLanes;l.pendingLanes=a,l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0,l.expiredLanes&=a,l.entangledLanes&=a,l.errorRecoveryDisabledLanes&=a,l.shellSuspendCounter=0;var c=l.entanglements,s=l.expirationTimes,h=l.hiddenUpdates;for(a=i&~a;0<a;){var T=31-Il(a),M=1<<T;c[T]=0,s[T]=-1;var g=h[T];if(g!==null)for(h[T]=null,T=0;T<g.length;T++){var E=g[T];E!==null&&(E.lane&=-536870913)}a&=~M}e!==0&&Df(l,e,0),n!==0&&u===0&&l.tag!==0&&(l.suspendedLanes|=n&~(i&~t))}function Df(l,t,a){l.pendingLanes|=t,l.suspendedLanes&=~t;var e=31-Il(t);l.entangledLanes|=t,l.entanglements[e]=l.entanglements[e]|1073741824|a&4194218}function _f(l,t){var a=l.entangledLanes|=t;for(l=l.entanglements;a;){var e=31-Il(a),u=1<<e;u&t|l[e]&t&&(l[e]|=t),a&=~u}}function Nf(l){return l&=-l,2<l?8<l?l&134217727?32:268435456:8:2}function xf(){var l=H.p;return l!==0?l:(l=window.event,l===void 0?32:Io(l.type))}function Bd(l,t){var a=H.p;try{return H.p=l,t()}finally{H.p=a}}var ea=Math.random().toString(36).slice(2),Cl="__reactFiber$"+ea,$l="__reactProps$"+ea,Ia="__reactContainer$"+ea,fi="__reactEvents$"+ea,Yd="__reactListeners$"+ea,Cd="__reactHandles$"+ea,Uf="__reactResources$"+ea,Ge="__reactMarker$"+ea;function si(l){delete l[Cl],delete l[$l],delete l[fi],delete l[Yd],delete l[Cd]}function _a(l){var t=l[Cl];if(t)return t;for(var a=l.parentNode;a;){if(t=a[Ia]||a[Cl]){if(a=t.alternate,t.child!==null||a!==null&&a.child!==null)for(l=Co(l);l!==null;){if(a=l[Cl])return a;l=Co(l)}return t}l=a,a=l.parentNode}return null}function le(l){if(l=l[Cl]||l[Ia]){var t=l.tag;if(t===5||t===6||t===13||t===26||t===27||t===3)return l}return null}function Xe(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l.stateNode;throw Error(r(33))}function te(l){var t=l[Uf];return t||(t=l[Uf]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function Ul(l){l[Ge]=!0}var Rf=new Set,Hf={};function Na(l,t){ae(l,t),ae(l+"Capture",t)}function ae(l,t){for(Hf[l]=t,l=0;l<t.length;l++)Rf.add(t[l])}var Ht=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),Gd=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),jf={},qf={};function Xd(l){return ui.call(qf,l)?!0:ui.call(jf,l)?!1:Gd.test(l)?qf[l]=!0:(jf[l]=!0,!1)}function Vu(l,t,a){if(Xd(t))if(a===null)l.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":l.removeAttribute(t);return;case"boolean":var e=t.toLowerCase().slice(0,5);if(e!=="data-"&&e!=="aria-"){l.removeAttribute(t);return}}l.setAttribute(t,""+a)}}function Lu(l,t,a){if(a===null)l.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(t);return}l.setAttribute(t,""+a)}}function jt(l,t,a,e){if(e===null)l.removeAttribute(a);else{switch(typeof e){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(a);return}l.setAttributeNS(t,a,""+e)}}function it(l){switch(typeof l){case"bigint":case"boolean":case"number":case"string":case"undefined":return l;case"object":return l;default:return""}}function Bf(l){var t=l.type;return(l=l.nodeName)&&l.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function Qd(l){var t=Bf(l)?"checked":"value",a=Object.getOwnPropertyDescriptor(l.constructor.prototype,t),e=""+l[t];if(!l.hasOwnProperty(t)&&typeof a<"u"&&typeof a.get=="function"&&typeof a.set=="function"){var u=a.get,n=a.set;return Object.defineProperty(l,t,{configurable:!0,get:function(){return u.call(this)},set:function(i){e=""+i,n.call(this,i)}}),Object.defineProperty(l,t,{enumerable:a.enumerable}),{getValue:function(){return e},setValue:function(i){e=""+i},stopTracking:function(){l._valueTracker=null,delete l[t]}}}}function Ku(l){l._valueTracker||(l._valueTracker=Qd(l))}function Yf(l){if(!l)return!1;var t=l._valueTracker;if(!t)return!0;var a=t.getValue(),e="";return l&&(e=Bf(l)?l.checked?"true":"false":l.value),l=e,l!==a?(t.setValue(l),!0):!1}function wu(l){if(l=l||(typeof document<"u"?document:void 0),typeof l>"u")return null;try{return l.activeElement||l.body}catch{return l.body}}var Zd=/[\n"\\]/g;function ct(l){return l.replace(Zd,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function ri(l,t,a,e,u,n,i,c){l.name="",i!=null&&typeof i!="function"&&typeof i!="symbol"&&typeof i!="boolean"?l.type=i:l.removeAttribute("type"),t!=null?i==="number"?(t===0&&l.value===""||l.value!=t)&&(l.value=""+it(t)):l.value!==""+it(t)&&(l.value=""+it(t)):i!=="submit"&&i!=="reset"||l.removeAttribute("value"),t!=null?oi(l,i,it(t)):a!=null?oi(l,i,it(a)):e!=null&&l.removeAttribute("value"),u==null&&n!=null&&(l.defaultChecked=!!n),u!=null&&(l.checked=u&&typeof u!="function"&&typeof u!="symbol"),c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"?l.name=""+it(c):l.removeAttribute("name")}function Cf(l,t,a,e,u,n,i,c){if(n!=null&&typeof n!="function"&&typeof n!="symbol"&&typeof n!="boolean"&&(l.type=n),t!=null||a!=null){if(!(n!=="submit"&&n!=="reset"||t!=null))return;a=a!=null?""+it(a):"",t=t!=null?""+it(t):a,c||t===l.value||(l.value=t),l.defaultValue=t}e=e??u,e=typeof e!="function"&&typeof e!="symbol"&&!!e,l.checked=c?l.checked:!!e,l.defaultChecked=!!e,i!=null&&typeof i!="function"&&typeof i!="symbol"&&typeof i!="boolean"&&(l.name=i)}function oi(l,t,a){t==="number"&&wu(l.ownerDocument)===l||l.defaultValue===""+a||(l.defaultValue=""+a)}function ee(l,t,a,e){if(l=l.options,t){t={};for(var u=0;u<a.length;u++)t["$"+a[u]]=!0;for(a=0;a<l.length;a++)u=t.hasOwnProperty("$"+l[a].value),l[a].selected!==u&&(l[a].selected=u),u&&e&&(l[a].defaultSelected=!0)}else{for(a=""+it(a),t=null,u=0;u<l.length;u++){if(l[u].value===a){l[u].selected=!0,e&&(l[u].defaultSelected=!0);return}t!==null||l[u].disabled||(t=l[u])}t!==null&&(t.selected=!0)}}function Gf(l,t,a){if(t!=null&&(t=""+it(t),t!==l.value&&(l.value=t),a==null)){l.defaultValue!==t&&(l.defaultValue=t);return}l.defaultValue=a!=null?""+it(a):""}function Xf(l,t,a,e){if(t==null){if(e!=null){if(a!=null)throw Error(r(92));if(C(e)){if(1<e.length)throw Error(r(93));e=e[0]}a=e}a==null&&(a=""),t=a}a=it(t),l.defaultValue=a,e=l.textContent,e===a&&e!==""&&e!==null&&(l.value=e)}function ue(l,t){if(t){var a=l.firstChild;if(a&&a===l.lastChild&&a.nodeType===3){a.nodeValue=t;return}}l.textContent=t}var Vd=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function Qf(l,t,a){var e=t.indexOf("--")===0;a==null||typeof a=="boolean"||a===""?e?l.setProperty(t,""):t==="float"?l.cssFloat="":l[t]="":e?l.setProperty(t,a):typeof a!="number"||a===0||Vd.has(t)?t==="float"?l.cssFloat=a:l[t]=(""+a).trim():l[t]=a+"px"}function Zf(l,t,a){if(t!=null&&typeof t!="object")throw Error(r(62));if(l=l.style,a!=null){for(var e in a)!a.hasOwnProperty(e)||t!=null&&t.hasOwnProperty(e)||(e.indexOf("--")===0?l.setProperty(e,""):e==="float"?l.cssFloat="":l[e]="");for(var u in t)e=t[u],t.hasOwnProperty(u)&&a[u]!==e&&Qf(l,u,e)}else for(var n in t)t.hasOwnProperty(n)&&Qf(l,n,t[n])}function di(l){if(l.indexOf("-")===-1)return!1;switch(l){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var Ld=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),Kd=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Ju(l){return Kd.test(""+l)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":l}var hi=null;function vi(l){return l=l.target||l.srcElement||window,l.correspondingUseElement&&(l=l.correspondingUseElement),l.nodeType===3?l.parentNode:l}var ne=null,ie=null;function Vf(l){var t=le(l);if(t&&(l=t.stateNode)){var a=l[$l]||null;l:switch(l=t.stateNode,t.type){case"input":if(ri(l,a.value,a.defaultValue,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name),t=a.name,a.type==="radio"&&t!=null){for(a=l;a.parentNode;)a=a.parentNode;for(a=a.querySelectorAll('input[name="'+ct(""+t)+'"][type="radio"]'),t=0;t<a.length;t++){var e=a[t];if(e!==l&&e.form===l.form){var u=e[$l]||null;if(!u)throw Error(r(90));ri(e,u.value,u.defaultValue,u.defaultValue,u.checked,u.defaultChecked,u.type,u.name)}}for(t=0;t<a.length;t++)e=a[t],e.form===l.form&&Yf(e)}break l;case"textarea":Gf(l,a.value,a.defaultValue);break l;case"select":t=a.value,t!=null&&ee(l,!!a.multiple,t,!1)}}}var yi=!1;function Lf(l,t,a){if(yi)return l(t,a);yi=!0;try{var e=l(t);return e}finally{if(yi=!1,(ne!==null||ie!==null)&&(Un(),ne&&(t=ne,l=ie,ie=ne=null,Vf(t),l)))for(t=0;t<l.length;t++)Vf(l[t])}}function Qe(l,t){var a=l.stateNode;if(a===null)return null;var e=a[$l]||null;if(e===null)return null;a=e[t];l:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(e=!e.disabled)||(l=l.type,e=!(l==="button"||l==="input"||l==="select"||l==="textarea")),l=!e;break l;default:l=!1}if(l)return null;if(a&&typeof a!="function")throw Error(r(231,t,typeof a));return a}var mi=!1;if(Ht)try{var Ze={};Object.defineProperty(Ze,"passive",{get:function(){mi=!0}}),window.addEventListener("test",Ze,Ze),window.removeEventListener("test",Ze,Ze)}catch{mi=!1}var ua=null,gi=null,ku=null;function Kf(){if(ku)return ku;var l,t=gi,a=t.length,e,u="value"in ua?ua.value:ua.textContent,n=u.length;for(l=0;l<a&&t[l]===u[l];l++);var i=a-l;for(e=1;e<=i&&t[a-e]===u[n-e];e++);return ku=u.slice(l,1<e?1-e:void 0)}function $u(l){var t=l.keyCode;return"charCode"in l?(l=l.charCode,l===0&&t===13&&(l=13)):l=t,l===10&&(l=13),32<=l||l===13?l:0}function Wu(){return!0}function wf(){return!1}function Wl(l){function t(a,e,u,n,i){this._reactName=a,this._targetInst=u,this.type=e,this.nativeEvent=n,this.target=i,this.currentTarget=null;for(var c in l)l.hasOwnProperty(c)&&(a=l[c],this[c]=a?a(n):n[c]);return this.isDefaultPrevented=(n.defaultPrevented!=null?n.defaultPrevented:n.returnValue===!1)?Wu:wf,this.isPropagationStopped=wf,this}return cl(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var a=this.nativeEvent;a&&(a.preventDefault?a.preventDefault():typeof a.returnValue!="unknown"&&(a.returnValue=!1),this.isDefaultPrevented=Wu)},stopPropagation:function(){var a=this.nativeEvent;a&&(a.stopPropagation?a.stopPropagation():typeof a.cancelBubble!="unknown"&&(a.cancelBubble=!0),this.isPropagationStopped=Wu)},persist:function(){},isPersistent:Wu}),t}var xa={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(l){return l.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Fu=Wl(xa),Ve=cl({},xa,{view:0,detail:0}),wd=Wl(Ve),bi,Si,Le,Pu=cl({},Ve,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:Ei,button:0,buttons:0,relatedTarget:function(l){return l.relatedTarget===void 0?l.fromElement===l.srcElement?l.toElement:l.fromElement:l.relatedTarget},movementX:function(l){return"movementX"in l?l.movementX:(l!==Le&&(Le&&l.type==="mousemove"?(bi=l.screenX-Le.screenX,Si=l.screenY-Le.screenY):Si=bi=0,Le=l),bi)},movementY:function(l){return"movementY"in l?l.movementY:Si}}),Jf=Wl(Pu),Jd=cl({},Pu,{dataTransfer:0}),kd=Wl(Jd),$d=cl({},Ve,{relatedTarget:0}),pi=Wl($d),Wd=cl({},xa,{animationName:0,elapsedTime:0,pseudoElement:0}),Fd=Wl(Wd),Pd=cl({},xa,{clipboardData:function(l){return"clipboardData"in l?l.clipboardData:window.clipboardData}}),Id=Wl(Pd),l0=cl({},xa,{data:0}),kf=Wl(l0),t0={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},a0={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},e0={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function u0(l){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(l):(l=e0[l])?!!t[l]:!1}function Ei(){return u0}var n0=cl({},Ve,{key:function(l){if(l.key){var t=t0[l.key]||l.key;if(t!=="Unidentified")return t}return l.type==="keypress"?(l=$u(l),l===13?"Enter":String.fromCharCode(l)):l.type==="keydown"||l.type==="keyup"?a0[l.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:Ei,charCode:function(l){return l.type==="keypress"?$u(l):0},keyCode:function(l){return l.type==="keydown"||l.type==="keyup"?l.keyCode:0},which:function(l){return l.type==="keypress"?$u(l):l.type==="keydown"||l.type==="keyup"?l.keyCode:0}}),i0=Wl(n0),c0=cl({},Pu,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),$f=Wl(c0),f0=cl({},Ve,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:Ei}),s0=Wl(f0),r0=cl({},xa,{propertyName:0,elapsedTime:0,pseudoElement:0}),o0=Wl(r0),d0=cl({},Pu,{deltaX:function(l){return"deltaX"in l?l.deltaX:"wheelDeltaX"in l?-l.wheelDeltaX:0},deltaY:function(l){return"deltaY"in l?l.deltaY:"wheelDeltaY"in l?-l.wheelDeltaY:"wheelDelta"in l?-l.wheelDelta:0},deltaZ:0,deltaMode:0}),h0=Wl(d0),v0=cl({},xa,{newState:0,oldState:0}),y0=Wl(v0),m0=[9,13,27,32],Ti=Ht&&"CompositionEvent"in window,Ke=null;Ht&&"documentMode"in document&&(Ke=document.documentMode);var g0=Ht&&"TextEvent"in window&&!Ke,Wf=Ht&&(!Ti||Ke&&8<Ke&&11>=Ke),Ff=" ",Pf=!1;function If(l,t){switch(l){case"keyup":return m0.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function ls(l){return l=l.detail,typeof l=="object"&&"data"in l?l.data:null}var ce=!1;function b0(l,t){switch(l){case"compositionend":return ls(t);case"keypress":return t.which!==32?null:(Pf=!0,Ff);case"textInput":return l=t.data,l===Ff&&Pf?null:l;default:return null}}function S0(l,t){if(ce)return l==="compositionend"||!Ti&&If(l,t)?(l=Kf(),ku=gi=ua=null,ce=!1,l):null;switch(l){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return Wf&&t.locale!=="ko"?null:t.data;default:return null}}var p0={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function ts(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t==="input"?!!p0[l.type]:t==="textarea"}function as(l,t,a,e){ne?ie?ie.push(e):ie=[e]:ne=e,t=Bn(t,"onChange"),0<t.length&&(a=new Fu("onChange","change",null,a,e),l.push({event:a,listeners:t}))}var we=null,Je=null;function E0(l){No(l,0)}function Iu(l){var t=Xe(l);if(Yf(t))return l}function es(l,t){if(l==="change")return t}var us=!1;if(Ht){var zi;if(Ht){var Ai="oninput"in document;if(!Ai){var ns=document.createElement("div");ns.setAttribute("oninput","return;"),Ai=typeof ns.oninput=="function"}zi=Ai}else zi=!1;us=zi&&(!document.documentMode||9<document.documentMode)}function is(){we&&(we.detachEvent("onpropertychange",cs),Je=we=null)}function cs(l){if(l.propertyName==="value"&&Iu(Je)){var t=[];as(t,Je,l,vi(l)),Lf(E0,t)}}function T0(l,t,a){l==="focusin"?(is(),we=t,Je=a,we.attachEvent("onpropertychange",cs)):l==="focusout"&&is()}function z0(l){if(l==="selectionchange"||l==="keyup"||l==="keydown")return Iu(Je)}function A0(l,t){if(l==="click")return Iu(t)}function O0(l,t){if(l==="input"||l==="change")return Iu(t)}function M0(l,t){return l===t&&(l!==0||1/l===1/t)||l!==l&&t!==t}var lt=typeof Object.is=="function"?Object.is:M0;function ke(l,t){if(lt(l,t))return!0;if(typeof l!="object"||l===null||typeof t!="object"||t===null)return!1;var a=Object.keys(l),e=Object.keys(t);if(a.length!==e.length)return!1;for(e=0;e<a.length;e++){var u=a[e];if(!ui.call(t,u)||!lt(l[u],t[u]))return!1}return!0}function fs(l){for(;l&&l.firstChild;)l=l.firstChild;return l}function ss(l,t){var a=fs(l);l=0;for(var e;a;){if(a.nodeType===3){if(e=l+a.textContent.length,l<=t&&e>=t)return{node:a,offset:t-l};l=e}l:{for(;a;){if(a.nextSibling){a=a.nextSibling;break l}a=a.parentNode}a=void 0}a=fs(a)}}function rs(l,t){return l&&t?l===t?!0:l&&l.nodeType===3?!1:t&&t.nodeType===3?rs(l,t.parentNode):"contains"in l?l.contains(t):l.compareDocumentPosition?!!(l.compareDocumentPosition(t)&16):!1:!1}function os(l){l=l!=null&&l.ownerDocument!=null&&l.ownerDocument.defaultView!=null?l.ownerDocument.defaultView:window;for(var t=wu(l.document);t instanceof l.HTMLIFrameElement;){try{var a=typeof t.contentWindow.location.href=="string"}catch{a=!1}if(a)l=t.contentWindow;else break;t=wu(l.document)}return t}function Oi(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t&&(t==="input"&&(l.type==="text"||l.type==="search"||l.type==="tel"||l.type==="url"||l.type==="password")||t==="textarea"||l.contentEditable==="true")}function D0(l,t){var a=os(t);t=l.focusedElem;var e=l.selectionRange;if(a!==t&&t&&t.ownerDocument&&rs(t.ownerDocument.documentElement,t)){if(e!==null&&Oi(t)){if(l=e.start,a=e.end,a===void 0&&(a=l),"selectionStart"in t)t.selectionStart=l,t.selectionEnd=Math.min(a,t.value.length);else if(a=(l=t.ownerDocument||document)&&l.defaultView||window,a.getSelection){a=a.getSelection();var u=t.textContent.length,n=Math.min(e.start,u);e=e.end===void 0?n:Math.min(e.end,u),!a.extend&&n>e&&(u=e,e=n,n=u),u=ss(t,n);var i=ss(t,e);u&&i&&(a.rangeCount!==1||a.anchorNode!==u.node||a.anchorOffset!==u.offset||a.focusNode!==i.node||a.focusOffset!==i.offset)&&(l=l.createRange(),l.setStart(u.node,u.offset),a.removeAllRanges(),n>e?(a.addRange(l),a.extend(i.node,i.offset)):(l.setEnd(i.node,i.offset),a.addRange(l)))}}for(l=[],a=t;a=a.parentNode;)a.nodeType===1&&l.push({element:a,left:a.scrollLeft,top:a.scrollTop});for(typeof t.focus=="function"&&t.focus(),t=0;t<l.length;t++)a=l[t],a.element.scrollLeft=a.left,a.element.scrollTop=a.top}}var _0=Ht&&"documentMode"in document&&11>=document.documentMode,fe=null,Mi=null,$e=null,Di=!1;function ds(l,t,a){var e=a.window===a?a.document:a.nodeType===9?a:a.ownerDocument;Di||fe==null||fe!==wu(e)||(e=fe,"selectionStart"in e&&Oi(e)?e={start:e.selectionStart,end:e.selectionEnd}:(e=(e.ownerDocument&&e.ownerDocument.defaultView||window).getSelection(),e={anchorNode:e.anchorNode,anchorOffset:e.anchorOffset,focusNode:e.focusNode,focusOffset:e.focusOffset}),$e&&ke($e,e)||($e=e,e=Bn(Mi,"onSelect"),0<e.length&&(t=new Fu("onSelect","select",null,t,a),l.push({event:t,listeners:e}),t.target=fe)))}function Ua(l,t){var a={};return a[l.toLowerCase()]=t.toLowerCase(),a["Webkit"+l]="webkit"+t,a["Moz"+l]="moz"+t,a}var se={animationend:Ua("Animation","AnimationEnd"),animationiteration:Ua("Animation","AnimationIteration"),animationstart:Ua("Animation","AnimationStart"),transitionrun:Ua("Transition","TransitionRun"),transitionstart:Ua("Transition","TransitionStart"),transitioncancel:Ua("Transition","TransitionCancel"),transitionend:Ua("Transition","TransitionEnd")},_i={},hs={};Ht&&(hs=document.createElement("div").style,"AnimationEvent"in window||(delete se.animationend.animation,delete se.animationiteration.animation,delete se.animationstart.animation),"TransitionEvent"in window||delete se.transitionend.transition);function Ra(l){if(_i[l])return _i[l];if(!se[l])return l;var t=se[l],a;for(a in t)if(t.hasOwnProperty(a)&&a in hs)return _i[l]=t[a];return l}var vs=Ra("animationend"),ys=Ra("animationiteration"),ms=Ra("animationstart"),N0=Ra("transitionrun"),x0=Ra("transitionstart"),U0=Ra("transitioncancel"),gs=Ra("transitionend"),bs=new Map,Ss="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll scrollEnd toggle touchMove waiting wheel".split(" ");function St(l,t){bs.set(l,t),Na(t,[l])}var ft=[],re=0,Ni=0;function ln(){for(var l=re,t=Ni=re=0;t<l;){var a=ft[t];ft[t++]=null;var e=ft[t];ft[t++]=null;var u=ft[t];ft[t++]=null;var n=ft[t];if(ft[t++]=null,e!==null&&u!==null){var i=e.pending;i===null?u.next=u:(u.next=i.next,i.next=u),e.pending=u}n!==0&&ps(a,u,n)}}function tn(l,t,a,e){ft[re++]=l,ft[re++]=t,ft[re++]=a,ft[re++]=e,Ni|=e,l.lanes|=e,l=l.alternate,l!==null&&(l.lanes|=e)}function xi(l,t,a,e){return tn(l,t,a,e),an(l)}function na(l,t){return tn(l,null,null,t),an(l)}function ps(l,t,a){l.lanes|=a;var e=l.alternate;e!==null&&(e.lanes|=a);for(var u=!1,n=l.return;n!==null;)n.childLanes|=a,e=n.alternate,e!==null&&(e.childLanes|=a),n.tag===22&&(l=n.stateNode,l===null||l._visibility&1||(u=!0)),l=n,n=n.return;u&&t!==null&&l.tag===3&&(n=l.stateNode,u=31-Il(a),n=n.hiddenUpdates,l=n[u],l===null?n[u]=[t]:l.push(t),t.lane=a|536870912)}function an(l){if(50<pu)throw pu=0,Bc=null,Error(r(185));for(var t=l.return;t!==null;)l=t,t=l.return;return l.tag===3?l.stateNode:null}var oe={},Es=new WeakMap;function st(l,t){if(typeof l=="object"&&l!==null){var a=Es.get(l);return a!==void 0?a:(t={value:l,source:t,stack:K(t)},Es.set(l,t),t)}return{value:l,source:t,stack:K(t)}}var de=[],he=0,en=null,un=0,rt=[],ot=0,Ha=null,qt=1,Bt="";function ja(l,t){de[he++]=un,de[he++]=en,en=l,un=t}function Ts(l,t,a){rt[ot++]=qt,rt[ot++]=Bt,rt[ot++]=Ha,Ha=l;var e=qt;l=Bt;var u=32-Il(e)-1;e&=~(1<<u),a+=1;var n=32-Il(t)+u;if(30<n){var i=u-u%5;n=(e&(1<<i)-1).toString(32),e>>=i,u-=i,qt=1<<32-Il(t)+u|a<<u|e,Bt=n+l}else qt=1<<n|a<<u|e,Bt=l}function Ui(l){l.return!==null&&(ja(l,1),Ts(l,1,0))}function Ri(l){for(;l===en;)en=de[--he],de[he]=null,un=de[--he],de[he]=null;for(;l===Ha;)Ha=rt[--ot],rt[ot]=null,Bt=rt[--ot],rt[ot]=null,qt=rt[--ot],rt[ot]=null}var Ll=null,ql=null,ul=!1,pt=null,Mt=!1,Hi=Error(r(519));function qa(l){var t=Error(r(418,""));throw Pe(st(t,l)),Hi}function zs(l){var t=l.stateNode,a=l.type,e=l.memoizedProps;switch(t[Cl]=l,t[$l]=e,a){case"dialog":I("cancel",t),I("close",t);break;case"iframe":case"object":case"embed":I("load",t);break;case"video":case"audio":for(a=0;a<Tu.length;a++)I(Tu[a],t);break;case"source":I("error",t);break;case"img":case"image":case"link":I("error",t),I("load",t);break;case"details":I("toggle",t);break;case"input":I("invalid",t),Cf(t,e.value,e.defaultValue,e.checked,e.defaultChecked,e.type,e.name,!0),Ku(t);break;case"select":I("invalid",t);break;case"textarea":I("invalid",t),Xf(t,e.value,e.defaultValue,e.children),Ku(t)}a=e.children,typeof a!="string"&&typeof a!="number"&&typeof a!="bigint"||t.textContent===""+a||e.suppressHydrationWarning===!0||Ho(t.textContent,a)?(e.popover!=null&&(I("beforetoggle",t),I("toggle",t)),e.onScroll!=null&&I("scroll",t),e.onScrollEnd!=null&&I("scrollend",t),e.onClick!=null&&(t.onclick=Yn),t=!0):t=!1,t||qa(l)}function As(l){for(Ll=l.return;Ll;)switch(Ll.tag){case 3:case 27:Mt=!0;return;case 5:case 13:Mt=!1;return;default:Ll=Ll.return}}function We(l){if(l!==Ll)return!1;if(!ul)return As(l),ul=!0,!1;var t=!1,a;if((a=l.tag!==3&&l.tag!==27)&&((a=l.tag===5)&&(a=l.type,a=!(a!=="form"&&a!=="button")||Ic(l.type,l.memoizedProps)),a=!a),a&&(t=!0),t&&ql&&qa(l),As(l),l.tag===13){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(r(317));l:{for(l=l.nextSibling,t=0;l;){if(l.nodeType===8)if(a=l.data,a==="/$"){if(t===0){ql=Tt(l.nextSibling);break l}t--}else a!=="$"&&a!=="$!"&&a!=="$?"||t++;l=l.nextSibling}ql=null}}else ql=Ll?Tt(l.stateNode.nextSibling):null;return!0}function Fe(){ql=Ll=null,ul=!1}function Pe(l){pt===null?pt=[l]:pt.push(l)}var Ie=Error(r(460)),Os=Error(r(474)),ji={then:function(){}};function Ms(l){return l=l.status,l==="fulfilled"||l==="rejected"}function nn(){}function Ds(l,t,a){switch(a=l[a],a===void 0?l.push(t):a!==t&&(t.then(nn,nn),t=a),t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,l===Ie?Error(r(483)):l;default:if(typeof t.status=="string")t.then(nn,nn);else{if(l=vl,l!==null&&100<l.shellSuspendCounter)throw Error(r(482));l=t,l.status="pending",l.then(function(e){if(t.status==="pending"){var u=t;u.status="fulfilled",u.value=e}},function(e){if(t.status==="pending"){var u=t;u.status="rejected",u.reason=e}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,l===Ie?Error(r(483)):l}throw lu=t,Ie}}var lu=null;function _s(){if(lu===null)throw Error(r(459));var l=lu;return lu=null,l}var ve=null,tu=0;function cn(l){var t=tu;return tu+=1,ve===null&&(ve=[]),Ds(ve,l,t)}function au(l,t){t=t.props.ref,l.ref=t!==void 0?t:null}function fn(l,t){throw t.$$typeof===p?Error(r(525)):(l=Object.prototype.toString.call(t),Error(r(31,l==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":l)))}function Ns(l){var t=l._init;return t(l._payload)}function xs(l){function t(v,d){if(l){var y=v.deletions;y===null?(v.deletions=[d],v.flags|=16):y.push(d)}}function a(v,d){if(!l)return null;for(;d!==null;)t(v,d),d=d.sibling;return null}function e(v){for(var d=new Map;v!==null;)v.key!==null?d.set(v.key,v):d.set(v.index,v),v=v.sibling;return d}function u(v,d){return v=ga(v,d),v.index=0,v.sibling=null,v}function n(v,d,y){return v.index=y,l?(y=v.alternate,y!==null?(y=y.index,y<d?(v.flags|=33554434,d):y):(v.flags|=33554434,d)):(v.flags|=1048576,d)}function i(v){return l&&v.alternate===null&&(v.flags|=33554434),v}function c(v,d,y,z){return d===null||d.tag!==6?(d=_c(y,v.mode,z),d.return=v,d):(d=u(d,y),d.return=v,d)}function s(v,d,y,z){var j=y.type;return j===O?T(v,d,y.props.children,z,y.key):d!==null&&(d.elementType===j||typeof j=="object"&&j!==null&&j.$$typeof===el&&Ns(j)===d.type)?(d=u(d,y.props),au(d,y),d.return=v,d):(d=Mn(y.type,y.key,y.props,null,v.mode,z),au(d,y),d.return=v,d)}function h(v,d,y,z){return d===null||d.tag!==4||d.stateNode.containerInfo!==y.containerInfo||d.stateNode.implementation!==y.implementation?(d=Nc(y,v.mode,z),d.return=v,d):(d=u(d,y.children||[]),d.return=v,d)}function T(v,d,y,z,j){return d===null||d.tag!==7?(d=Ka(y,v.mode,z,j),d.return=v,d):(d=u(d,y),d.return=v,d)}function M(v,d,y){if(typeof d=="string"&&d!==""||typeof d=="number"||typeof d=="bigint")return d=_c(""+d,v.mode,y),d.return=v,d;if(typeof d=="object"&&d!==null){switch(d.$$typeof){case x:return y=Mn(d.type,d.key,d.props,null,v.mode,y),au(y,d),y.return=v,y;case N:return d=Nc(d,v.mode,y),d.return=v,d;case el:var z=d._init;return d=z(d._payload),M(v,d,y)}if(C(d)||Jl(d))return d=Ka(d,v.mode,y,null),d.return=v,d;if(typeof d.then=="function")return M(v,cn(d),y);if(d.$$typeof===P)return M(v,zn(v,d),y);fn(v,d)}return null}function g(v,d,y,z){var j=d!==null?d.key:null;if(typeof y=="string"&&y!==""||typeof y=="number"||typeof y=="bigint")return j!==null?null:c(v,d,""+y,z);if(typeof y=="object"&&y!==null){switch(y.$$typeof){case x:return y.key===j?s(v,d,y,z):null;case N:return y.key===j?h(v,d,y,z):null;case el:return j=y._init,y=j(y._payload),g(v,d,y,z)}if(C(y)||Jl(y))return j!==null?null:T(v,d,y,z,null);if(typeof y.then=="function")return g(v,d,cn(y),z);if(y.$$typeof===P)return g(v,d,zn(v,y),z);fn(v,y)}return null}function E(v,d,y,z,j){if(typeof z=="string"&&z!==""||typeof z=="number"||typeof z=="bigint")return v=v.get(y)||null,c(d,v,""+z,j);if(typeof z=="object"&&z!==null){switch(z.$$typeof){case x:return v=v.get(z.key===null?y:z.key)||null,s(d,v,z,j);case N:return v=v.get(z.key===null?y:z.key)||null,h(d,v,z,j);case el:var W=z._init;return z=W(z._payload),E(v,d,y,z,j)}if(C(z)||Jl(z))return v=v.get(y)||null,T(d,v,z,j,null);if(typeof z.then=="function")return E(v,d,y,cn(z),j);if(z.$$typeof===P)return E(v,d,y,zn(d,z),j);fn(d,z)}return null}function q(v,d,y,z){for(var j=null,W=null,B=d,G=d=0,jl=null;B!==null&&G<y.length;G++){B.index>G?(jl=B,B=null):jl=B.sibling;var nl=g(v,B,y[G],z);if(nl===null){B===null&&(B=jl);break}l&&B&&nl.alternate===null&&t(v,B),d=n(nl,d,G),W===null?j=nl:W.sibling=nl,W=nl,B=jl}if(G===y.length)return a(v,B),ul&&ja(v,G),j;if(B===null){for(;G<y.length;G++)B=M(v,y[G],z),B!==null&&(d=n(B,d,G),W===null?j=B:W.sibling=B,W=B);return ul&&ja(v,G),j}for(B=e(B);G<y.length;G++)jl=E(B,v,G,y[G],z),jl!==null&&(l&&jl.alternate!==null&&B.delete(jl.key===null?G:jl.key),d=n(jl,d,G),W===null?j=jl:W.sibling=jl,W=jl);return l&&B.forEach(function(Aa){return t(v,Aa)}),ul&&ja(v,G),j}function V(v,d,y,z){if(y==null)throw Error(r(151));for(var j=null,W=null,B=d,G=d=0,jl=null,nl=y.next();B!==null&&!nl.done;G++,nl=y.next()){B.index>G?(jl=B,B=null):jl=B.sibling;var Aa=g(v,B,nl.value,z);if(Aa===null){B===null&&(B=jl);break}l&&B&&Aa.alternate===null&&t(v,B),d=n(Aa,d,G),W===null?j=Aa:W.sibling=Aa,W=Aa,B=jl}if(nl.done)return a(v,B),ul&&ja(v,G),j;if(B===null){for(;!nl.done;G++,nl=y.next())nl=M(v,nl.value,z),nl!==null&&(d=n(nl,d,G),W===null?j=nl:W.sibling=nl,W=nl);return ul&&ja(v,G),j}for(B=e(B);!nl.done;G++,nl=y.next())nl=E(B,v,G,nl.value,z),nl!==null&&(l&&nl.alternate!==null&&B.delete(nl.key===null?G:nl.key),d=n(nl,d,G),W===null?j=nl:W.sibling=nl,W=nl);return l&&B.forEach(function(K1){return t(v,K1)}),ul&&ja(v,G),j}function Tl(v,d,y,z){if(typeof y=="object"&&y!==null&&y.type===O&&y.key===null&&(y=y.props.children),typeof y=="object"&&y!==null){switch(y.$$typeof){case x:l:{for(var j=y.key;d!==null;){if(d.key===j){if(j=y.type,j===O){if(d.tag===7){a(v,d.sibling),z=u(d,y.props.children),z.return=v,v=z;break l}}else if(d.elementType===j||typeof j=="object"&&j!==null&&j.$$typeof===el&&Ns(j)===d.type){a(v,d.sibling),z=u(d,y.props),au(z,y),z.return=v,v=z;break l}a(v,d);break}else t(v,d);d=d.sibling}y.type===O?(z=Ka(y.props.children,v.mode,z,y.key),z.return=v,v=z):(z=Mn(y.type,y.key,y.props,null,v.mode,z),au(z,y),z.return=v,v=z)}return i(v);case N:l:{for(j=y.key;d!==null;){if(d.key===j)if(d.tag===4&&d.stateNode.containerInfo===y.containerInfo&&d.stateNode.implementation===y.implementation){a(v,d.sibling),z=u(d,y.children||[]),z.return=v,v=z;break l}else{a(v,d);break}else t(v,d);d=d.sibling}z=Nc(y,v.mode,z),z.return=v,v=z}return i(v);case el:return j=y._init,y=j(y._payload),Tl(v,d,y,z)}if(C(y))return q(v,d,y,z);if(Jl(y)){if(j=Jl(y),typeof j!="function")throw Error(r(150));return y=j.call(y),V(v,d,y,z)}if(typeof y.then=="function")return Tl(v,d,cn(y),z);if(y.$$typeof===P)return Tl(v,d,zn(v,y),z);fn(v,y)}return typeof y=="string"&&y!==""||typeof y=="number"||typeof y=="bigint"?(y=""+y,d!==null&&d.tag===6?(a(v,d.sibling),z=u(d,y),z.return=v,v=z):(a(v,d),z=_c(y,v.mode,z),z.return=v,v=z),i(v)):a(v,d)}return function(v,d,y,z){try{tu=0;var j=Tl(v,d,y,z);return ve=null,j}catch(B){if(B===Ie)throw B;var W=yt(29,B,null,v.mode);return W.lanes=z,W.return=v,W}finally{}}}var Ba=xs(!0),Us=xs(!1),ye=fl(null),sn=fl(0);function Rs(l,t){l=Jt,ml(sn,l),ml(ye,t),Jt=l|t.baseLanes}function qi(){ml(sn,Jt),ml(ye,ye.current)}function Bi(){Jt=sn.current,Ol(ye),Ol(sn)}var dt=fl(null),Dt=null;function ia(l){var t=l.alternate;ml(Nl,Nl.current&1),ml(dt,l),Dt===null&&(t===null||ye.current!==null||t.memoizedState!==null)&&(Dt=l)}function Hs(l){if(l.tag===22){if(ml(Nl,Nl.current),ml(dt,l),Dt===null){var t=l.alternate;t!==null&&t.memoizedState!==null&&(Dt=l)}}else ca()}function ca(){ml(Nl,Nl.current),ml(dt,dt.current)}function Yt(l){Ol(dt),Dt===l&&(Dt=null),Ol(Nl)}var Nl=fl(0);function rn(l){for(var t=l;t!==null;){if(t.tag===13){var a=t.memoizedState;if(a!==null&&(a=a.dehydrated,a===null||a.data==="$?"||a.data==="$!"))return t}else if(t.tag===19&&t.memoizedProps.revealOrder!==void 0){if(t.flags&128)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}var R0=typeof AbortController<"u"?AbortController:function(){var l=[],t=this.signal={aborted:!1,addEventListener:function(a,e){l.push(e)}};this.abort=function(){t.aborted=!0,l.forEach(function(a){return a()})}},H0=f.unstable_scheduleCallback,j0=f.unstable_NormalPriority,xl={$$typeof:P,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Yi(){return{controller:new R0,data:new Map,refCount:0}}function eu(l){l.refCount--,l.refCount===0&&H0(j0,function(){l.controller.abort()})}var uu=null,Ci=0,me=0,ge=null;function q0(l,t){if(uu===null){var a=uu=[];Ci=0,me=Lc(),ge={status:"pending",value:void 0,then:function(e){a.push(e)}}}return Ci++,t.then(js,js),t}function js(){if(--Ci===0&&uu!==null){ge!==null&&(ge.status="fulfilled");var l=uu;uu=null,me=0,ge=null;for(var t=0;t<l.length;t++)(0,l[t])()}}function B0(l,t){var a=[],e={status:"pending",value:null,reason:null,then:function(u){a.push(u)}};return l.then(function(){e.status="fulfilled",e.value=t;for(var u=0;u<a.length;u++)(0,a[u])(t)},function(u){for(e.status="rejected",e.reason=u,u=0;u<a.length;u++)(0,a[u])(void 0)}),e}var qs=X.S;X.S=function(l,t){typeof t=="object"&&t!==null&&typeof t.then=="function"&&q0(l,t),qs!==null&&qs(l,t)};var Ya=fl(null);function Gi(){var l=Ya.current;return l!==null?l:vl.pooledCache}function on(l,t){t===null?ml(Ya,Ya.current):ml(Ya,t.pool)}function Bs(){var l=Gi();return l===null?null:{parent:xl._currentValue,pool:l}}var fa=0,$=null,rl=null,Ml=null,dn=!1,be=!1,Ca=!1,hn=0,nu=0,Se=null,Y0=0;function zl(){throw Error(r(321))}function Xi(l,t){if(t===null)return!1;for(var a=0;a<t.length&&a<l.length;a++)if(!lt(l[a],t[a]))return!1;return!0}function Qi(l,t,a,e,u,n){return fa=n,$=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,X.H=l===null||l.memoizedState===null?Ga:sa,Ca=!1,n=a(e,u),Ca=!1,be&&(n=Cs(t,a,e,u)),Ys(l),n}function Ys(l){X.H=_t;var t=rl!==null&&rl.next!==null;if(fa=0,Ml=rl=$=null,dn=!1,nu=0,Se=null,t)throw Error(r(300));l===null||Rl||(l=l.dependencies,l!==null&&Tn(l)&&(Rl=!0))}function Cs(l,t,a,e){$=l;var u=0;do{if(be&&(Se=null),nu=0,be=!1,25<=u)throw Error(r(301));if(u+=1,Ml=rl=null,l.updateQueue!=null){var n=l.updateQueue;n.lastEffect=null,n.events=null,n.stores=null,n.memoCache!=null&&(n.memoCache.index=0)}X.H=Xa,n=t(a,e)}while(be);return n}function C0(){var l=X.H,t=l.useState()[0];return t=typeof t.then=="function"?iu(t):t,l=l.useState()[0],(rl!==null?rl.memoizedState:null)!==l&&($.flags|=1024),t}function Zi(){var l=hn!==0;return hn=0,l}function Vi(l,t,a){t.updateQueue=l.updateQueue,t.flags&=-2053,l.lanes&=~a}function Li(l){if(dn){for(l=l.memoizedState;l!==null;){var t=l.queue;t!==null&&(t.pending=null),l=l.next}dn=!1}fa=0,Ml=rl=$=null,be=!1,nu=hn=0,Se=null}function Fl(){var l={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Ml===null?$.memoizedState=Ml=l:Ml=Ml.next=l,Ml}function Dl(){if(rl===null){var l=$.alternate;l=l!==null?l.memoizedState:null}else l=rl.next;var t=Ml===null?$.memoizedState:Ml.next;if(t!==null)Ml=t,rl=l;else{if(l===null)throw $.alternate===null?Error(r(467)):Error(r(310));rl=l,l={memoizedState:rl.memoizedState,baseState:rl.baseState,baseQueue:rl.baseQueue,queue:rl.queue,next:null},Ml===null?$.memoizedState=Ml=l:Ml=Ml.next=l}return Ml}var vn;vn=function(){return{lastEffect:null,events:null,stores:null,memoCache:null}};function iu(l){var t=nu;return nu+=1,Se===null&&(Se=[]),l=Ds(Se,l,t),t=$,(Ml===null?t.memoizedState:Ml.next)===null&&(t=t.alternate,X.H=t===null||t.memoizedState===null?Ga:sa),l}function yn(l){if(l!==null&&typeof l=="object"){if(typeof l.then=="function")return iu(l);if(l.$$typeof===P)return Gl(l)}throw Error(r(438,String(l)))}function Ki(l){var t=null,a=$.updateQueue;if(a!==null&&(t=a.memoCache),t==null){var e=$.alternate;e!==null&&(e=e.updateQueue,e!==null&&(e=e.memoCache,e!=null&&(t={data:e.data.map(function(u){return u.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),a===null&&(a=vn(),$.updateQueue=a),a.memoCache=t,a=t.data[t.index],a===void 0)for(a=t.data[t.index]=Array(l),e=0;e<l;e++)a[e]=bt;return t.index++,a}function Ct(l,t){return typeof t=="function"?t(l):t}function mn(l){var t=Dl();return wi(t,rl,l)}function wi(l,t,a){var e=l.queue;if(e===null)throw Error(r(311));e.lastRenderedReducer=a;var u=l.baseQueue,n=e.pending;if(n!==null){if(u!==null){var i=u.next;u.next=n.next,n.next=i}t.baseQueue=u=n,e.pending=null}if(n=l.baseState,u===null)l.memoizedState=n;else{t=u.next;var c=i=null,s=null,h=t,T=!1;do{var M=h.lane&-536870913;if(M!==h.lane?(tl&M)===M:(fa&M)===M){var g=h.revertLane;if(g===0)s!==null&&(s=s.next={lane:0,revertLane:0,action:h.action,hasEagerState:h.hasEagerState,eagerState:h.eagerState,next:null}),M===me&&(T=!0);else if((fa&g)===g){h=h.next,g===me&&(T=!0);continue}else M={lane:0,revertLane:h.revertLane,action:h.action,hasEagerState:h.hasEagerState,eagerState:h.eagerState,next:null},s===null?(c=s=M,i=n):s=s.next=M,$.lanes|=g,ba|=g;M=h.action,Ca&&a(n,M),n=h.hasEagerState?h.eagerState:a(n,M)}else g={lane:M,revertLane:h.revertLane,action:h.action,hasEagerState:h.hasEagerState,eagerState:h.eagerState,next:null},s===null?(c=s=g,i=n):s=s.next=g,$.lanes|=M,ba|=M;h=h.next}while(h!==null&&h!==t);if(s===null?i=n:s.next=c,!lt(n,l.memoizedState)&&(Rl=!0,T&&(a=ge,a!==null)))throw a;l.memoizedState=n,l.baseState=i,l.baseQueue=s,e.lastRenderedState=n}return u===null&&(e.lanes=0),[l.memoizedState,e.dispatch]}function Ji(l){var t=Dl(),a=t.queue;if(a===null)throw Error(r(311));a.lastRenderedReducer=l;var e=a.dispatch,u=a.pending,n=t.memoizedState;if(u!==null){a.pending=null;var i=u=u.next;do n=l(n,i.action),i=i.next;while(i!==u);lt(n,t.memoizedState)||(Rl=!0),t.memoizedState=n,t.baseQueue===null&&(t.baseState=n),a.lastRenderedState=n}return[n,e]}function Gs(l,t,a){var e=$,u=Dl(),n=ul;if(n){if(a===void 0)throw Error(r(407));a=a()}else a=t();var i=!lt((rl||u).memoizedState,a);if(i&&(u.memoizedState=a,Rl=!0),u=u.queue,Wi(Zs.bind(null,e,u,l),[l]),u.getSnapshot!==t||i||Ml!==null&&Ml.memoizedState.tag&1){if(e.flags|=2048,pe(9,Qs.bind(null,e,u,a,t),{destroy:void 0},null),vl===null)throw Error(r(349));n||fa&60||Xs(e,t,a)}return a}function Xs(l,t,a){l.flags|=16384,l={getSnapshot:t,value:a},t=$.updateQueue,t===null?(t=vn(),$.updateQueue=t,t.stores=[l]):(a=t.stores,a===null?t.stores=[l]:a.push(l))}function Qs(l,t,a,e){t.value=a,t.getSnapshot=e,Vs(t)&&Ls(l)}function Zs(l,t,a){return a(function(){Vs(t)&&Ls(l)})}function Vs(l){var t=l.getSnapshot;l=l.value;try{var a=t();return!lt(l,a)}catch{return!0}}function Ls(l){var t=na(l,2);t!==null&&Kl(t,l,2)}function ki(l){var t=Fl();if(typeof l=="function"){var a=l;if(l=a(),Ca){aa(!0);try{a()}finally{aa(!1)}}}return t.memoizedState=t.baseState=l,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Ct,lastRenderedState:l},t}function Ks(l,t,a,e){return l.baseState=a,wi(l,rl,typeof e=="function"?e:Ct)}function G0(l,t,a,e,u){if(Sn(l))throw Error(r(485));if(l=t.action,l!==null){var n={payload:u,action:l,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(i){n.listeners.push(i)}};X.T!==null?a(!0):n.isTransition=!1,e(n),a=t.pending,a===null?(n.next=t.pending=n,ws(t,n)):(n.next=a.next,t.pending=a.next=n)}}function ws(l,t){var a=t.action,e=t.payload,u=l.state;if(t.isTransition){var n=X.T,i={};X.T=i;try{var c=a(u,e),s=X.S;s!==null&&s(i,c),Js(l,t,c)}catch(h){$i(l,t,h)}finally{X.T=n}}else try{n=a(u,e),Js(l,t,n)}catch(h){$i(l,t,h)}}function Js(l,t,a){a!==null&&typeof a=="object"&&typeof a.then=="function"?a.then(function(e){ks(l,t,e)},function(e){return $i(l,t,e)}):ks(l,t,a)}function ks(l,t,a){t.status="fulfilled",t.value=a,$s(t),l.state=a,t=l.pending,t!==null&&(a=t.next,a===t?l.pending=null:(a=a.next,t.next=a,ws(l,a)))}function $i(l,t,a){var e=l.pending;if(l.pending=null,e!==null){e=e.next;do t.status="rejected",t.reason=a,$s(t),t=t.next;while(t!==e)}l.action=null}function $s(l){l=l.listeners;for(var t=0;t<l.length;t++)(0,l[t])()}function Ws(l,t){return t}function Fs(l,t){if(ul){var a=vl.formState;if(a!==null){l:{var e=$;if(ul){if(ql){t:{for(var u=ql,n=Mt;u.nodeType!==8;){if(!n){u=null;break t}if(u=Tt(u.nextSibling),u===null){u=null;break t}}n=u.data,u=n==="F!"||n==="F"?u:null}if(u){ql=Tt(u.nextSibling),e=u.data==="F!";break l}}qa(e)}e=!1}e&&(t=a[0])}}return a=Fl(),a.memoizedState=a.baseState=t,e={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Ws,lastRenderedState:t},a.queue=e,a=yr.bind(null,$,e),e.dispatch=a,e=ki(!1),n=tc.bind(null,$,!1,e.queue),e=Fl(),u={state:t,dispatch:null,action:l,pending:null},e.queue=u,a=G0.bind(null,$,u,n,a),u.dispatch=a,e.memoizedState=l,[t,a,!1]}function Ps(l){var t=Dl();return Is(t,rl,l)}function Is(l,t,a){t=wi(l,t,Ws)[0],l=mn(Ct)[0],t=typeof t=="object"&&t!==null&&typeof t.then=="function"?iu(t):t;var e=Dl(),u=e.queue,n=u.dispatch;return a!==e.memoizedState&&($.flags|=2048,pe(9,X0.bind(null,u,a),{destroy:void 0},null)),[t,n,l]}function X0(l,t){l.action=t}function lr(l){var t=Dl(),a=rl;if(a!==null)return Is(t,a,l);Dl(),t=t.memoizedState,a=Dl();var e=a.queue.dispatch;return a.memoizedState=l,[t,e,!1]}function pe(l,t,a,e){return l={tag:l,create:t,inst:a,deps:e,next:null},t=$.updateQueue,t===null&&(t=vn(),$.updateQueue=t),a=t.lastEffect,a===null?t.lastEffect=l.next=l:(e=a.next,a.next=l,l.next=e,t.lastEffect=l),l}function tr(){return Dl().memoizedState}function gn(l,t,a,e){var u=Fl();$.flags|=l,u.memoizedState=pe(1|t,a,{destroy:void 0},e===void 0?null:e)}function bn(l,t,a,e){var u=Dl();e=e===void 0?null:e;var n=u.memoizedState.inst;rl!==null&&e!==null&&Xi(e,rl.memoizedState.deps)?u.memoizedState=pe(t,a,n,e):($.flags|=l,u.memoizedState=pe(1|t,a,n,e))}function ar(l,t){gn(8390656,8,l,t)}function Wi(l,t){bn(2048,8,l,t)}function er(l,t){return bn(4,2,l,t)}function ur(l,t){return bn(4,4,l,t)}function nr(l,t){if(typeof t=="function"){l=l();var a=t(l);return function(){typeof a=="function"?a():t(null)}}if(t!=null)return l=l(),t.current=l,function(){t.current=null}}function ir(l,t,a){a=a!=null?a.concat([l]):null,bn(4,4,nr.bind(null,t,l),a)}function Fi(){}function cr(l,t){var a=Dl();t=t===void 0?null:t;var e=a.memoizedState;return t!==null&&Xi(t,e[1])?e[0]:(a.memoizedState=[l,t],l)}function fr(l,t){var a=Dl();t=t===void 0?null:t;var e=a.memoizedState;if(t!==null&&Xi(t,e[1]))return e[0];if(e=l(),Ca){aa(!0);try{l()}finally{aa(!1)}}return a.memoizedState=[e,t],e}function Pi(l,t,a){return a===void 0||fa&1073741824?l.memoizedState=t:(l.memoizedState=a,l=ro(),$.lanes|=l,ba|=l,a)}function sr(l,t,a,e){return lt(a,t)?a:ye.current!==null?(l=Pi(l,a,e),lt(l,t)||(Rl=!0),l):fa&42?(l=ro(),$.lanes|=l,ba|=l,t):(Rl=!0,l.memoizedState=a)}function rr(l,t,a,e,u){var n=H.p;H.p=n!==0&&8>n?n:8;var i=X.T,c={};X.T=c,tc(l,!1,t,a);try{var s=u(),h=X.S;if(h!==null&&h(c,s),s!==null&&typeof s=="object"&&typeof s.then=="function"){var T=B0(s,e);cu(l,t,T,ut(l))}else cu(l,t,e,ut(l))}catch(M){cu(l,t,{then:function(){},status:"rejected",reason:M},ut())}finally{H.p=n,X.T=i}}function Q0(){}function Ii(l,t,a,e){if(l.tag!==5)throw Error(r(476));var u=or(l).queue;rr(l,u,t,ll,a===null?Q0:function(){return dr(l),a(e)})}function or(l){var t=l.memoizedState;if(t!==null)return t;t={memoizedState:ll,baseState:ll,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Ct,lastRenderedState:ll},next:null};var a={};return t.next={memoizedState:a,baseState:a,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Ct,lastRenderedState:a},next:null},l.memoizedState=t,l=l.alternate,l!==null&&(l.memoizedState=t),t}function dr(l){var t=or(l).next.queue;cu(l,t,{},ut())}function lc(){return Gl(Du)}function hr(){return Dl().memoizedState}function vr(){return Dl().memoizedState}function Z0(l){for(var t=l.return;t!==null;){switch(t.tag){case 24:case 3:var a=ut();l=da(a);var e=ha(t,l,a);e!==null&&(Kl(e,t,a),ru(e,t,a)),t={cache:Yi()},l.payload=t;return}t=t.return}}function V0(l,t,a){var e=ut();a={lane:e,revertLane:0,action:a,hasEagerState:!1,eagerState:null,next:null},Sn(l)?mr(t,a):(a=xi(l,t,a,e),a!==null&&(Kl(a,l,e),gr(a,t,e)))}function yr(l,t,a){var e=ut();cu(l,t,a,e)}function cu(l,t,a,e){var u={lane:e,revertLane:0,action:a,hasEagerState:!1,eagerState:null,next:null};if(Sn(l))mr(t,u);else{var n=l.alternate;if(l.lanes===0&&(n===null||n.lanes===0)&&(n=t.lastRenderedReducer,n!==null))try{var i=t.lastRenderedState,c=n(i,a);if(u.hasEagerState=!0,u.eagerState=c,lt(c,i))return tn(l,t,u,0),vl===null&&ln(),!1}catch{}finally{}if(a=xi(l,t,u,e),a!==null)return Kl(a,l,e),gr(a,t,e),!0}return!1}function tc(l,t,a,e){if(e={lane:2,revertLane:Lc(),action:e,hasEagerState:!1,eagerState:null,next:null},Sn(l)){if(t)throw Error(r(479))}else t=xi(l,a,e,2),t!==null&&Kl(t,l,2)}function Sn(l){var t=l.alternate;return l===$||t!==null&&t===$}function mr(l,t){be=dn=!0;var a=l.pending;a===null?t.next=t:(t.next=a.next,a.next=t),l.pending=t}function gr(l,t,a){if(a&4194176){var e=t.lanes;e&=l.pendingLanes,a|=e,t.lanes=a,_f(l,a)}}var _t={readContext:Gl,use:yn,useCallback:zl,useContext:zl,useEffect:zl,useImperativeHandle:zl,useLayoutEffect:zl,useInsertionEffect:zl,useMemo:zl,useReducer:zl,useRef:zl,useState:zl,useDebugValue:zl,useDeferredValue:zl,useTransition:zl,useSyncExternalStore:zl,useId:zl};_t.useCacheRefresh=zl,_t.useMemoCache=zl,_t.useHostTransitionStatus=zl,_t.useFormState=zl,_t.useActionState=zl,_t.useOptimistic=zl;var Ga={readContext:Gl,use:yn,useCallback:function(l,t){return Fl().memoizedState=[l,t===void 0?null:t],l},useContext:Gl,useEffect:ar,useImperativeHandle:function(l,t,a){a=a!=null?a.concat([l]):null,gn(4194308,4,nr.bind(null,t,l),a)},useLayoutEffect:function(l,t){return gn(4194308,4,l,t)},useInsertionEffect:function(l,t){gn(4,2,l,t)},useMemo:function(l,t){var a=Fl();t=t===void 0?null:t;var e=l();if(Ca){aa(!0);try{l()}finally{aa(!1)}}return a.memoizedState=[e,t],e},useReducer:function(l,t,a){var e=Fl();if(a!==void 0){var u=a(t);if(Ca){aa(!0);try{a(t)}finally{aa(!1)}}}else u=t;return e.memoizedState=e.baseState=u,l={pending:null,lanes:0,dispatch:null,lastRenderedReducer:l,lastRenderedState:u},e.queue=l,l=l.dispatch=V0.bind(null,$,l),[e.memoizedState,l]},useRef:function(l){var t=Fl();return l={current:l},t.memoizedState=l},useState:function(l){l=ki(l);var t=l.queue,a=yr.bind(null,$,t);return t.dispatch=a,[l.memoizedState,a]},useDebugValue:Fi,useDeferredValue:function(l,t){var a=Fl();return Pi(a,l,t)},useTransition:function(){var l=ki(!1);return l=rr.bind(null,$,l.queue,!0,!1),Fl().memoizedState=l,[!1,l]},useSyncExternalStore:function(l,t,a){var e=$,u=Fl();if(ul){if(a===void 0)throw Error(r(407));a=a()}else{if(a=t(),vl===null)throw Error(r(349));tl&60||Xs(e,t,a)}u.memoizedState=a;var n={value:a,getSnapshot:t};return u.queue=n,ar(Zs.bind(null,e,n,l),[l]),e.flags|=2048,pe(9,Qs.bind(null,e,n,a,t),{destroy:void 0},null),a},useId:function(){var l=Fl(),t=vl.identifierPrefix;if(ul){var a=Bt,e=qt;a=(e&~(1<<32-Il(e)-1)).toString(32)+a,t=":"+t+"R"+a,a=hn++,0<a&&(t+="H"+a.toString(32)),t+=":"}else a=Y0++,t=":"+t+"r"+a.toString(32)+":";return l.memoizedState=t},useCacheRefresh:function(){return Fl().memoizedState=Z0.bind(null,$)}};Ga.useMemoCache=Ki,Ga.useHostTransitionStatus=lc,Ga.useFormState=Fs,Ga.useActionState=Fs,Ga.useOptimistic=function(l){var t=Fl();t.memoizedState=t.baseState=l;var a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=a,t=tc.bind(null,$,!0,a),a.dispatch=t,[l,t]};var sa={readContext:Gl,use:yn,useCallback:cr,useContext:Gl,useEffect:Wi,useImperativeHandle:ir,useInsertionEffect:er,useLayoutEffect:ur,useMemo:fr,useReducer:mn,useRef:tr,useState:function(){return mn(Ct)},useDebugValue:Fi,useDeferredValue:function(l,t){var a=Dl();return sr(a,rl.memoizedState,l,t)},useTransition:function(){var l=mn(Ct)[0],t=Dl().memoizedState;return[typeof l=="boolean"?l:iu(l),t]},useSyncExternalStore:Gs,useId:hr};sa.useCacheRefresh=vr,sa.useMemoCache=Ki,sa.useHostTransitionStatus=lc,sa.useFormState=Ps,sa.useActionState=Ps,sa.useOptimistic=function(l,t){var a=Dl();return Ks(a,rl,l,t)};var Xa={readContext:Gl,use:yn,useCallback:cr,useContext:Gl,useEffect:Wi,useImperativeHandle:ir,useInsertionEffect:er,useLayoutEffect:ur,useMemo:fr,useReducer:Ji,useRef:tr,useState:function(){return Ji(Ct)},useDebugValue:Fi,useDeferredValue:function(l,t){var a=Dl();return rl===null?Pi(a,l,t):sr(a,rl.memoizedState,l,t)},useTransition:function(){var l=Ji(Ct)[0],t=Dl().memoizedState;return[typeof l=="boolean"?l:iu(l),t]},useSyncExternalStore:Gs,useId:hr};Xa.useCacheRefresh=vr,Xa.useMemoCache=Ki,Xa.useHostTransitionStatus=lc,Xa.useFormState=lr,Xa.useActionState=lr,Xa.useOptimistic=function(l,t){var a=Dl();return rl!==null?Ks(a,rl,l,t):(a.baseState=l,[l,a.queue.dispatch])};function ac(l,t,a,e){t=l.memoizedState,a=a(e,t),a=a==null?t:cl({},t,a),l.memoizedState=a,l.lanes===0&&(l.updateQueue.baseState=a)}var ec={isMounted:function(l){return(l=l._reactInternals)?Z(l)===l:!1},enqueueSetState:function(l,t,a){l=l._reactInternals;var e=ut(),u=da(e);u.payload=t,a!=null&&(u.callback=a),t=ha(l,u,e),t!==null&&(Kl(t,l,e),ru(t,l,e))},enqueueReplaceState:function(l,t,a){l=l._reactInternals;var e=ut(),u=da(e);u.tag=1,u.payload=t,a!=null&&(u.callback=a),t=ha(l,u,e),t!==null&&(Kl(t,l,e),ru(t,l,e))},enqueueForceUpdate:function(l,t){l=l._reactInternals;var a=ut(),e=da(a);e.tag=2,t!=null&&(e.callback=t),t=ha(l,e,a),t!==null&&(Kl(t,l,a),ru(t,l,a))}};function br(l,t,a,e,u,n,i){return l=l.stateNode,typeof l.shouldComponentUpdate=="function"?l.shouldComponentUpdate(e,n,i):t.prototype&&t.prototype.isPureReactComponent?!ke(a,e)||!ke(u,n):!0}function Sr(l,t,a,e){l=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(a,e),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(a,e),t.state!==l&&ec.enqueueReplaceState(t,t.state,null)}function Qa(l,t){var a=t;if("ref"in t){a={};for(var e in t)e!=="ref"&&(a[e]=t[e])}if(l=l.defaultProps){a===t&&(a=cl({},a));for(var u in l)a[u]===void 0&&(a[u]=l[u])}return a}var pn=typeof reportError=="function"?reportError:function(l){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof l=="object"&&l!==null&&typeof l.message=="string"?String(l.message):String(l),error:l});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",l);return}console.error(l)};function pr(l){pn(l)}function Er(l){console.error(l)}function Tr(l){pn(l)}function En(l,t){try{var a=l.onUncaughtError;a(t.value,{componentStack:t.stack})}catch(e){setTimeout(function(){throw e})}}function zr(l,t,a){try{var e=l.onCaughtError;e(a.value,{componentStack:a.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(u){setTimeout(function(){throw u})}}function uc(l,t,a){return a=da(a),a.tag=3,a.payload={element:null},a.callback=function(){En(l,t)},a}function Ar(l){return l=da(l),l.tag=3,l}function Or(l,t,a,e){var u=a.type.getDerivedStateFromError;if(typeof u=="function"){var n=e.value;l.payload=function(){return u(n)},l.callback=function(){zr(t,a,e)}}var i=a.stateNode;i!==null&&typeof i.componentDidCatch=="function"&&(l.callback=function(){zr(t,a,e),typeof u!="function"&&(Sa===null?Sa=new Set([this]):Sa.add(this));var c=e.stack;this.componentDidCatch(e.value,{componentStack:c!==null?c:""})})}function L0(l,t,a,e,u){if(a.flags|=32768,e!==null&&typeof e=="object"&&typeof e.then=="function"){if(t=a.alternate,t!==null&&su(t,a,u,!0),a=dt.current,a!==null){switch(a.tag){case 13:return Dt===null?Gc():a.alternate===null&&El===0&&(El=3),a.flags&=-257,a.flags|=65536,a.lanes=u,e===ji?a.flags|=16384:(t=a.updateQueue,t===null?a.updateQueue=new Set([e]):t.add(e),Qc(l,e,u)),!1;case 22:return a.flags|=65536,e===ji?a.flags|=16384:(t=a.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([e])},a.updateQueue=t):(a=t.retryQueue,a===null?t.retryQueue=new Set([e]):a.add(e)),Qc(l,e,u)),!1}throw Error(r(435,a.tag))}return Qc(l,e,u),Gc(),!1}if(ul)return t=dt.current,t!==null?(!(t.flags&65536)&&(t.flags|=256),t.flags|=65536,t.lanes=u,e!==Hi&&(l=Error(r(422),{cause:e}),Pe(st(l,a)))):(e!==Hi&&(t=Error(r(423),{cause:e}),Pe(st(t,a))),l=l.current.alternate,l.flags|=65536,u&=-u,l.lanes|=u,e=st(e,a),u=uc(l.stateNode,e,u),Sc(l,u),El!==4&&(El=2)),!1;var n=Error(r(520),{cause:e});if(n=st(n,a),bu===null?bu=[n]:bu.push(n),El!==4&&(El=2),t===null)return!0;e=st(e,a),a=t;do{switch(a.tag){case 3:return a.flags|=65536,l=u&-u,a.lanes|=l,l=uc(a.stateNode,e,l),Sc(a,l),!1;case 1:if(t=a.type,n=a.stateNode,(a.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||n!==null&&typeof n.componentDidCatch=="function"&&(Sa===null||!Sa.has(n))))return a.flags|=65536,u&=-u,a.lanes|=u,u=Ar(u),Or(u,l,a,e),Sc(a,u),!1}a=a.return}while(a!==null);return!1}var Mr=Error(r(461)),Rl=!1;function Bl(l,t,a,e){t.child=l===null?Us(t,null,a,e):Ba(t,l.child,a,e)}function Dr(l,t,a,e,u){a=a.render;var n=t.ref;if("ref"in e){var i={};for(var c in e)c!=="ref"&&(i[c]=e[c])}else i=e;return Va(t),e=Qi(l,t,a,i,n,u),c=Zi(),l!==null&&!Rl?(Vi(l,t,u),Gt(l,t,u)):(ul&&c&&Ui(t),t.flags|=1,Bl(l,t,e,u),t.child)}function _r(l,t,a,e,u){if(l===null){var n=a.type;return typeof n=="function"&&!Dc(n)&&n.defaultProps===void 0&&a.compare===null?(t.tag=15,t.type=n,Nr(l,t,n,e,u)):(l=Mn(a.type,null,e,t,t.mode,u),l.ref=t.ref,l.return=t,t.child=l)}if(n=l.child,!hc(l,u)){var i=n.memoizedProps;if(a=a.compare,a=a!==null?a:ke,a(i,e)&&l.ref===t.ref)return Gt(l,t,u)}return t.flags|=1,l=ga(n,e),l.ref=t.ref,l.return=t,t.child=l}function Nr(l,t,a,e,u){if(l!==null){var n=l.memoizedProps;if(ke(n,e)&&l.ref===t.ref)if(Rl=!1,t.pendingProps=e=n,hc(l,u))l.flags&131072&&(Rl=!0);else return t.lanes=l.lanes,Gt(l,t,u)}return nc(l,t,a,e,u)}function xr(l,t,a){var e=t.pendingProps,u=e.children,n=(t.stateNode._pendingVisibility&2)!==0,i=l!==null?l.memoizedState:null;if(fu(l,t),e.mode==="hidden"||n){if(t.flags&128){if(e=i!==null?i.baseLanes|a:a,l!==null){for(u=t.child=l.child,n=0;u!==null;)n=n|u.lanes|u.childLanes,u=u.sibling;t.childLanes=n&~e}else t.childLanes=0,t.child=null;return Ur(l,t,e,a)}if(a&536870912)t.memoizedState={baseLanes:0,cachePool:null},l!==null&&on(t,i!==null?i.cachePool:null),i!==null?Rs(t,i):qi(),Hs(t);else return t.lanes=t.childLanes=536870912,Ur(l,t,i!==null?i.baseLanes|a:a,a)}else i!==null?(on(t,i.cachePool),Rs(t,i),ca(),t.memoizedState=null):(l!==null&&on(t,null),qi(),ca());return Bl(l,t,u,a),t.child}function Ur(l,t,a,e){var u=Gi();return u=u===null?null:{parent:xl._currentValue,pool:u},t.memoizedState={baseLanes:a,cachePool:u},l!==null&&on(t,null),qi(),Hs(t),l!==null&&su(l,t,e,!0),null}function fu(l,t){var a=t.ref;if(a===null)l!==null&&l.ref!==null&&(t.flags|=2097664);else{if(typeof a!="function"&&typeof a!="object")throw Error(r(284));(l===null||l.ref!==a)&&(t.flags|=2097664)}}function nc(l,t,a,e,u){return Va(t),a=Qi(l,t,a,e,void 0,u),e=Zi(),l!==null&&!Rl?(Vi(l,t,u),Gt(l,t,u)):(ul&&e&&Ui(t),t.flags|=1,Bl(l,t,a,u),t.child)}function Rr(l,t,a,e,u,n){return Va(t),t.updateQueue=null,a=Cs(t,e,a,u),Ys(l),e=Zi(),l!==null&&!Rl?(Vi(l,t,n),Gt(l,t,n)):(ul&&e&&Ui(t),t.flags|=1,Bl(l,t,a,n),t.child)}function Hr(l,t,a,e,u){if(Va(t),t.stateNode===null){var n=oe,i=a.contextType;typeof i=="object"&&i!==null&&(n=Gl(i)),n=new a(e,n),t.memoizedState=n.state!==null&&n.state!==void 0?n.state:null,n.updater=ec,t.stateNode=n,n._reactInternals=t,n=t.stateNode,n.props=e,n.state=t.memoizedState,n.refs={},gc(t),i=a.contextType,n.context=typeof i=="object"&&i!==null?Gl(i):oe,n.state=t.memoizedState,i=a.getDerivedStateFromProps,typeof i=="function"&&(ac(t,a,i,e),n.state=t.memoizedState),typeof a.getDerivedStateFromProps=="function"||typeof n.getSnapshotBeforeUpdate=="function"||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(i=n.state,typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount(),i!==n.state&&ec.enqueueReplaceState(n,n.state,null),du(t,e,n,u),ou(),n.state=t.memoizedState),typeof n.componentDidMount=="function"&&(t.flags|=4194308),e=!0}else if(l===null){n=t.stateNode;var c=t.memoizedProps,s=Qa(a,c);n.props=s;var h=n.context,T=a.contextType;i=oe,typeof T=="object"&&T!==null&&(i=Gl(T));var M=a.getDerivedStateFromProps;T=typeof M=="function"||typeof n.getSnapshotBeforeUpdate=="function",c=t.pendingProps!==c,T||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(c||h!==i)&&Sr(t,n,e,i),oa=!1;var g=t.memoizedState;n.state=g,du(t,e,n,u),ou(),h=t.memoizedState,c||g!==h||oa?(typeof M=="function"&&(ac(t,a,M,e),h=t.memoizedState),(s=oa||br(t,a,s,e,g,h,i))?(T||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount()),typeof n.componentDidMount=="function"&&(t.flags|=4194308)):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=e,t.memoizedState=h),n.props=e,n.state=h,n.context=i,e=s):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),e=!1)}else{n=t.stateNode,bc(l,t),i=t.memoizedProps,T=Qa(a,i),n.props=T,M=t.pendingProps,g=n.context,h=a.contextType,s=oe,typeof h=="object"&&h!==null&&(s=Gl(h)),c=a.getDerivedStateFromProps,(h=typeof c=="function"||typeof n.getSnapshotBeforeUpdate=="function")||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(i!==M||g!==s)&&Sr(t,n,e,s),oa=!1,g=t.memoizedState,n.state=g,du(t,e,n,u),ou();var E=t.memoizedState;i!==M||g!==E||oa||l!==null&&l.dependencies!==null&&Tn(l.dependencies)?(typeof c=="function"&&(ac(t,a,c,e),E=t.memoizedState),(T=oa||br(t,a,T,e,g,E,s)||l!==null&&l.dependencies!==null&&Tn(l.dependencies))?(h||typeof n.UNSAFE_componentWillUpdate!="function"&&typeof n.componentWillUpdate!="function"||(typeof n.componentWillUpdate=="function"&&n.componentWillUpdate(e,E,s),typeof n.UNSAFE_componentWillUpdate=="function"&&n.UNSAFE_componentWillUpdate(e,E,s)),typeof n.componentDidUpdate=="function"&&(t.flags|=4),typeof n.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof n.componentDidUpdate!="function"||i===l.memoizedProps&&g===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||i===l.memoizedProps&&g===l.memoizedState||(t.flags|=1024),t.memoizedProps=e,t.memoizedState=E),n.props=e,n.state=E,n.context=s,e=T):(typeof n.componentDidUpdate!="function"||i===l.memoizedProps&&g===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||i===l.memoizedProps&&g===l.memoizedState||(t.flags|=1024),e=!1)}return n=e,fu(l,t),e=(t.flags&128)!==0,n||e?(n=t.stateNode,a=e&&typeof a.getDerivedStateFromError!="function"?null:n.render(),t.flags|=1,l!==null&&e?(t.child=Ba(t,l.child,null,u),t.child=Ba(t,null,a,u)):Bl(l,t,a,u),t.memoizedState=n.state,l=t.child):l=Gt(l,t,u),l}function jr(l,t,a,e){return Fe(),t.flags|=256,Bl(l,t,a,e),t.child}var ic={dehydrated:null,treeContext:null,retryLane:0};function cc(l){return{baseLanes:l,cachePool:Bs()}}function fc(l,t,a){return l=l!==null?l.childLanes&~a:0,t&&(l|=mt),l}function qr(l,t,a){var e=t.pendingProps,u=!1,n=(t.flags&128)!==0,i;if((i=n)||(i=l!==null&&l.memoizedState===null?!1:(Nl.current&2)!==0),i&&(u=!0,t.flags&=-129),i=(t.flags&32)!==0,t.flags&=-33,l===null){if(ul){if(u?ia(t):ca(),ul){var c=ql,s;if(s=c){l:{for(s=c,c=Mt;s.nodeType!==8;){if(!c){c=null;break l}if(s=Tt(s.nextSibling),s===null){c=null;break l}}c=s}c!==null?(t.memoizedState={dehydrated:c,treeContext:Ha!==null?{id:qt,overflow:Bt}:null,retryLane:536870912},s=yt(18,null,null,0),s.stateNode=c,s.return=t,t.child=s,Ll=t,ql=null,s=!0):s=!1}s||qa(t)}if(c=t.memoizedState,c!==null&&(c=c.dehydrated,c!==null))return c.data==="$!"?t.lanes=16:t.lanes=536870912,null;Yt(t)}return c=e.children,e=e.fallback,u?(ca(),u=t.mode,c=rc({mode:"hidden",children:c},u),e=Ka(e,u,a,null),c.return=t,e.return=t,c.sibling=e,t.child=c,u=t.child,u.memoizedState=cc(a),u.childLanes=fc(l,i,a),t.memoizedState=ic,e):(ia(t),sc(t,c))}if(s=l.memoizedState,s!==null&&(c=s.dehydrated,c!==null)){if(n)t.flags&256?(ia(t),t.flags&=-257,t=oc(l,t,a)):t.memoizedState!==null?(ca(),t.child=l.child,t.flags|=128,t=null):(ca(),u=e.fallback,c=t.mode,e=rc({mode:"visible",children:e.children},c),u=Ka(u,c,a,null),u.flags|=2,e.return=t,u.return=t,e.sibling=u,t.child=e,Ba(t,l.child,null,a),e=t.child,e.memoizedState=cc(a),e.childLanes=fc(l,i,a),t.memoizedState=ic,t=u);else if(ia(t),c.data==="$!"){if(i=c.nextSibling&&c.nextSibling.dataset,i)var h=i.dgst;i=h,e=Error(r(419)),e.stack="",e.digest=i,Pe({value:e,source:null,stack:null}),t=oc(l,t,a)}else if(Rl||su(l,t,a,!1),i=(a&l.childLanes)!==0,Rl||i){if(i=vl,i!==null){if(e=a&-a,e&42)e=1;else switch(e){case 2:e=1;break;case 8:e=4;break;case 32:e=16;break;case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:e=64;break;case 268435456:e=134217728;break;default:e=0}if(e=e&(i.suspendedLanes|a)?0:e,e!==0&&e!==s.retryLane)throw s.retryLane=e,na(l,e),Kl(i,l,e),Mr}c.data==="$?"||Gc(),t=oc(l,t,a)}else c.data==="$?"?(t.flags|=128,t.child=l.child,t=n1.bind(null,l),c._reactRetry=t,t=null):(l=s.treeContext,ql=Tt(c.nextSibling),Ll=t,ul=!0,pt=null,Mt=!1,l!==null&&(rt[ot++]=qt,rt[ot++]=Bt,rt[ot++]=Ha,qt=l.id,Bt=l.overflow,Ha=t),t=sc(t,e.children),t.flags|=4096);return t}return u?(ca(),u=e.fallback,c=t.mode,s=l.child,h=s.sibling,e=ga(s,{mode:"hidden",children:e.children}),e.subtreeFlags=s.subtreeFlags&31457280,h!==null?u=ga(h,u):(u=Ka(u,c,a,null),u.flags|=2),u.return=t,e.return=t,e.sibling=u,t.child=e,e=u,u=t.child,c=l.child.memoizedState,c===null?c=cc(a):(s=c.cachePool,s!==null?(h=xl._currentValue,s=s.parent!==h?{parent:h,pool:h}:s):s=Bs(),c={baseLanes:c.baseLanes|a,cachePool:s}),u.memoizedState=c,u.childLanes=fc(l,i,a),t.memoizedState=ic,e):(ia(t),a=l.child,l=a.sibling,a=ga(a,{mode:"visible",children:e.children}),a.return=t,a.sibling=null,l!==null&&(i=t.deletions,i===null?(t.deletions=[l],t.flags|=16):i.push(l)),t.child=a,t.memoizedState=null,a)}function sc(l,t){return t=rc({mode:"visible",children:t},l.mode),t.return=l,l.child=t}function rc(l,t){return co(l,t,0,null)}function oc(l,t,a){return Ba(t,l.child,null,a),l=sc(t,t.pendingProps.children),l.flags|=2,t.memoizedState=null,l}function Br(l,t,a){l.lanes|=t;var e=l.alternate;e!==null&&(e.lanes|=t),yc(l.return,t,a)}function dc(l,t,a,e,u){var n=l.memoizedState;n===null?l.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:e,tail:a,tailMode:u}:(n.isBackwards=t,n.rendering=null,n.renderingStartTime=0,n.last=e,n.tail=a,n.tailMode=u)}function Yr(l,t,a){var e=t.pendingProps,u=e.revealOrder,n=e.tail;if(Bl(l,t,e.children,a),e=Nl.current,e&2)e=e&1|2,t.flags|=128;else{if(l!==null&&l.flags&128)l:for(l=t.child;l!==null;){if(l.tag===13)l.memoizedState!==null&&Br(l,a,t);else if(l.tag===19)Br(l,a,t);else if(l.child!==null){l.child.return=l,l=l.child;continue}if(l===t)break l;for(;l.sibling===null;){if(l.return===null||l.return===t)break l;l=l.return}l.sibling.return=l.return,l=l.sibling}e&=1}switch(ml(Nl,e),u){case"forwards":for(a=t.child,u=null;a!==null;)l=a.alternate,l!==null&&rn(l)===null&&(u=a),a=a.sibling;a=u,a===null?(u=t.child,t.child=null):(u=a.sibling,a.sibling=null),dc(t,!1,u,a,n);break;case"backwards":for(a=null,u=t.child,t.child=null;u!==null;){if(l=u.alternate,l!==null&&rn(l)===null){t.child=u;break}l=u.sibling,u.sibling=a,a=u,u=l}dc(t,!0,a,null,n);break;case"together":dc(t,!1,null,null,void 0);break;default:t.memoizedState=null}return t.child}function Gt(l,t,a){if(l!==null&&(t.dependencies=l.dependencies),ba|=t.lanes,!(a&t.childLanes))if(l!==null){if(su(l,t,a,!1),(a&t.childLanes)===0)return null}else return null;if(l!==null&&t.child!==l.child)throw Error(r(153));if(t.child!==null){for(l=t.child,a=ga(l,l.pendingProps),t.child=a,a.return=t;l.sibling!==null;)l=l.sibling,a=a.sibling=ga(l,l.pendingProps),a.return=t;a.sibling=null}return t.child}function hc(l,t){return l.lanes&t?!0:(l=l.dependencies,!!(l!==null&&Tn(l)))}function K0(l,t,a){switch(t.tag){case 3:Yu(t,t.stateNode.containerInfo),ra(t,xl,l.memoizedState.cache),Fe();break;case 27:case 5:ei(t);break;case 4:Yu(t,t.stateNode.containerInfo);break;case 10:ra(t,t.type,t.memoizedProps.value);break;case 13:var e=t.memoizedState;if(e!==null)return e.dehydrated!==null?(ia(t),t.flags|=128,null):a&t.child.childLanes?qr(l,t,a):(ia(t),l=Gt(l,t,a),l!==null?l.sibling:null);ia(t);break;case 19:var u=(l.flags&128)!==0;if(e=(a&t.childLanes)!==0,e||(su(l,t,a,!1),e=(a&t.childLanes)!==0),u){if(e)return Yr(l,t,a);t.flags|=128}if(u=t.memoizedState,u!==null&&(u.rendering=null,u.tail=null,u.lastEffect=null),ml(Nl,Nl.current),e)break;return null;case 22:case 23:return t.lanes=0,xr(l,t,a);case 24:ra(t,xl,l.memoizedState.cache)}return Gt(l,t,a)}function Cr(l,t,a){if(l!==null)if(l.memoizedProps!==t.pendingProps)Rl=!0;else{if(!hc(l,a)&&!(t.flags&128))return Rl=!1,K0(l,t,a);Rl=!!(l.flags&131072)}else Rl=!1,ul&&t.flags&1048576&&Ts(t,un,t.index);switch(t.lanes=0,t.tag){case 16:l:{l=t.pendingProps;var e=t.elementType,u=e._init;if(e=u(e._payload),t.type=e,typeof e=="function")Dc(e)?(l=Qa(e,l),t.tag=1,t=Hr(null,t,e,l,a)):(t.tag=0,t=nc(null,t,e,l,a));else{if(e!=null){if(u=e.$$typeof,u===Al){t.tag=11,t=Dr(null,t,e,l,a);break l}else if(u===al){t.tag=14,t=_r(null,t,e,l,a);break l}}throw t=la(e)||e,Error(r(306,t,""))}}return t;case 0:return nc(l,t,t.type,t.pendingProps,a);case 1:return e=t.type,u=Qa(e,t.pendingProps),Hr(l,t,e,u,a);case 3:l:{if(Yu(t,t.stateNode.containerInfo),l===null)throw Error(r(387));var n=t.pendingProps;u=t.memoizedState,e=u.element,bc(l,t),du(t,n,null,a);var i=t.memoizedState;if(n=i.cache,ra(t,xl,n),n!==u.cache&&mc(t,[xl],a,!0),ou(),n=i.element,u.isDehydrated)if(u={element:n,isDehydrated:!1,cache:i.cache},t.updateQueue.baseState=u,t.memoizedState=u,t.flags&256){t=jr(l,t,n,a);break l}else if(n!==e){e=st(Error(r(424)),t),Pe(e),t=jr(l,t,n,a);break l}else for(ql=Tt(t.stateNode.containerInfo.firstChild),Ll=t,ul=!0,pt=null,Mt=!0,a=Us(t,null,n,a),t.child=a;a;)a.flags=a.flags&-3|4096,a=a.sibling;else{if(Fe(),n===e){t=Gt(l,t,a);break l}Bl(l,t,n,a)}t=t.child}return t;case 26:return fu(l,t),l===null?(a=Zo(t.type,null,t.pendingProps,null))?t.memoizedState=a:ul||(a=t.type,l=t.pendingProps,e=Cn(ta.current).createElement(a),e[Cl]=t,e[$l]=l,Yl(e,a,l),Ul(e),t.stateNode=e):t.memoizedState=Zo(t.type,l.memoizedProps,t.pendingProps,l.memoizedState),null;case 27:return ei(t),l===null&&ul&&(e=t.stateNode=Go(t.type,t.pendingProps,ta.current),Ll=t,Mt=!0,ql=Tt(e.firstChild)),e=t.pendingProps.children,l!==null||ul?Bl(l,t,e,a):t.child=Ba(t,null,e,a),fu(l,t),t.child;case 5:return l===null&&ul&&((u=e=ql)&&(e=E1(e,t.type,t.pendingProps,Mt),e!==null?(t.stateNode=e,Ll=t,ql=Tt(e.firstChild),Mt=!1,u=!0):u=!1),u||qa(t)),ei(t),u=t.type,n=t.pendingProps,i=l!==null?l.memoizedProps:null,e=n.children,Ic(u,n)?e=null:i!==null&&Ic(u,i)&&(t.flags|=32),t.memoizedState!==null&&(u=Qi(l,t,C0,null,null,a),Du._currentValue=u),fu(l,t),Bl(l,t,e,a),t.child;case 6:return l===null&&ul&&((l=a=ql)&&(a=T1(a,t.pendingProps,Mt),a!==null?(t.stateNode=a,Ll=t,ql=null,l=!0):l=!1),l||qa(t)),null;case 13:return qr(l,t,a);case 4:return Yu(t,t.stateNode.containerInfo),e=t.pendingProps,l===null?t.child=Ba(t,null,e,a):Bl(l,t,e,a),t.child;case 11:return Dr(l,t,t.type,t.pendingProps,a);case 7:return Bl(l,t,t.pendingProps,a),t.child;case 8:return Bl(l,t,t.pendingProps.children,a),t.child;case 12:return Bl(l,t,t.pendingProps.children,a),t.child;case 10:return e=t.pendingProps,ra(t,t.type,e.value),Bl(l,t,e.children,a),t.child;case 9:return u=t.type._context,e=t.pendingProps.children,Va(t),u=Gl(u),e=e(u),t.flags|=1,Bl(l,t,e,a),t.child;case 14:return _r(l,t,t.type,t.pendingProps,a);case 15:return Nr(l,t,t.type,t.pendingProps,a);case 19:return Yr(l,t,a);case 22:return xr(l,t,a);case 24:return Va(t),e=Gl(xl),l===null?(u=Gi(),u===null&&(u=vl,n=Yi(),u.pooledCache=n,n.refCount++,n!==null&&(u.pooledCacheLanes|=a),u=n),t.memoizedState={parent:e,cache:u},gc(t),ra(t,xl,u)):(l.lanes&a&&(bc(l,t),du(t,null,null,a),ou()),u=l.memoizedState,n=t.memoizedState,u.parent!==e?(u={parent:e,cache:e},t.memoizedState=u,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=u),ra(t,xl,e)):(e=n.cache,ra(t,xl,e),e!==u.cache&&mc(t,[xl],a,!0))),Bl(l,t,t.pendingProps.children,a),t.child;case 29:throw t.pendingProps}throw Error(r(156,t.tag))}var vc=fl(null),Za=null,Xt=null;function ra(l,t,a){ml(vc,t._currentValue),t._currentValue=a}function Qt(l){l._currentValue=vc.current,Ol(vc)}function yc(l,t,a){for(;l!==null;){var e=l.alternate;if((l.childLanes&t)!==t?(l.childLanes|=t,e!==null&&(e.childLanes|=t)):e!==null&&(e.childLanes&t)!==t&&(e.childLanes|=t),l===a)break;l=l.return}}function mc(l,t,a,e){var u=l.child;for(u!==null&&(u.return=l);u!==null;){var n=u.dependencies;if(n!==null){var i=u.child;n=n.firstContext;l:for(;n!==null;){var c=n;n=u;for(var s=0;s<t.length;s++)if(c.context===t[s]){n.lanes|=a,c=n.alternate,c!==null&&(c.lanes|=a),yc(n.return,a,l),e||(i=null);break l}n=c.next}}else if(u.tag===18){if(i=u.return,i===null)throw Error(r(341));i.lanes|=a,n=i.alternate,n!==null&&(n.lanes|=a),yc(i,a,l),i=null}else i=u.child;if(i!==null)i.return=u;else for(i=u;i!==null;){if(i===l){i=null;break}if(u=i.sibling,u!==null){u.return=i.return,i=u;break}i=i.return}u=i}}function su(l,t,a,e){l=null;for(var u=t,n=!1;u!==null;){if(!n){if(u.flags&524288)n=!0;else if(u.flags&262144)break}if(u.tag===10){var i=u.alternate;if(i===null)throw Error(r(387));if(i=i.memoizedProps,i!==null){var c=u.type;lt(u.pendingProps.value,i.value)||(l!==null?l.push(c):l=[c])}}else if(u===Bu.current){if(i=u.alternate,i===null)throw Error(r(387));i.memoizedState.memoizedState!==u.memoizedState.memoizedState&&(l!==null?l.push(Du):l=[Du])}u=u.return}l!==null&&mc(t,l,a,e),t.flags|=262144}function Tn(l){for(l=l.firstContext;l!==null;){if(!lt(l.context._currentValue,l.memoizedValue))return!0;l=l.next}return!1}function Va(l){Za=l,Xt=null,l=l.dependencies,l!==null&&(l.firstContext=null)}function Gl(l){return Gr(Za,l)}function zn(l,t){return Za===null&&Va(l),Gr(l,t)}function Gr(l,t){var a=t._currentValue;if(t={context:t,memoizedValue:a,next:null},Xt===null){if(l===null)throw Error(r(308));Xt=t,l.dependencies={lanes:0,firstContext:t},l.flags|=524288}else Xt=Xt.next=t;return a}var oa=!1;function gc(l){l.updateQueue={baseState:l.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function bc(l,t){l=l.updateQueue,t.updateQueue===l&&(t.updateQueue={baseState:l.baseState,firstBaseUpdate:l.firstBaseUpdate,lastBaseUpdate:l.lastBaseUpdate,shared:l.shared,callbacks:null})}function da(l){return{lane:l,tag:0,payload:null,callback:null,next:null}}function ha(l,t,a){var e=l.updateQueue;if(e===null)return null;if(e=e.shared,Sl&2){var u=e.pending;return u===null?t.next=t:(t.next=u.next,u.next=t),e.pending=t,t=an(l),ps(l,null,a),t}return tn(l,e,t,a),an(l)}function ru(l,t,a){if(t=t.updateQueue,t!==null&&(t=t.shared,(a&4194176)!==0)){var e=t.lanes;e&=l.pendingLanes,a|=e,t.lanes=a,_f(l,a)}}function Sc(l,t){var a=l.updateQueue,e=l.alternate;if(e!==null&&(e=e.updateQueue,a===e)){var u=null,n=null;if(a=a.firstBaseUpdate,a!==null){do{var i={lane:a.lane,tag:a.tag,payload:a.payload,callback:null,next:null};n===null?u=n=i:n=n.next=i,a=a.next}while(a!==null);n===null?u=n=t:n=n.next=t}else u=n=t;a={baseState:e.baseState,firstBaseUpdate:u,lastBaseUpdate:n,shared:e.shared,callbacks:e.callbacks},l.updateQueue=a;return}l=a.lastBaseUpdate,l===null?a.firstBaseUpdate=t:l.next=t,a.lastBaseUpdate=t}var pc=!1;function ou(){if(pc){var l=ge;if(l!==null)throw l}}function du(l,t,a,e){pc=!1;var u=l.updateQueue;oa=!1;var n=u.firstBaseUpdate,i=u.lastBaseUpdate,c=u.shared.pending;if(c!==null){u.shared.pending=null;var s=c,h=s.next;s.next=null,i===null?n=h:i.next=h,i=s;var T=l.alternate;T!==null&&(T=T.updateQueue,c=T.lastBaseUpdate,c!==i&&(c===null?T.firstBaseUpdate=h:c.next=h,T.lastBaseUpdate=s))}if(n!==null){var M=u.baseState;i=0,T=h=s=null,c=n;do{var g=c.lane&-536870913,E=g!==c.lane;if(E?(tl&g)===g:(e&g)===g){g!==0&&g===me&&(pc=!0),T!==null&&(T=T.next={lane:0,tag:c.tag,payload:c.payload,callback:null,next:null});l:{var q=l,V=c;g=t;var Tl=a;switch(V.tag){case 1:if(q=V.payload,typeof q=="function"){M=q.call(Tl,M,g);break l}M=q;break l;case 3:q.flags=q.flags&-65537|128;case 0:if(q=V.payload,g=typeof q=="function"?q.call(Tl,M,g):q,g==null)break l;M=cl({},M,g);break l;case 2:oa=!0}}g=c.callback,g!==null&&(l.flags|=64,E&&(l.flags|=8192),E=u.callbacks,E===null?u.callbacks=[g]:E.push(g))}else E={lane:g,tag:c.tag,payload:c.payload,callback:c.callback,next:null},T===null?(h=T=E,s=M):T=T.next=E,i|=g;if(c=c.next,c===null){if(c=u.shared.pending,c===null)break;E=c,c=E.next,E.next=null,u.lastBaseUpdate=E,u.shared.pending=null}}while(!0);T===null&&(s=M),u.baseState=s,u.firstBaseUpdate=h,u.lastBaseUpdate=T,n===null&&(u.shared.lanes=0),ba|=i,l.lanes=i,l.memoizedState=M}}function Xr(l,t){if(typeof l!="function")throw Error(r(191,l));l.call(t)}function Qr(l,t){var a=l.callbacks;if(a!==null)for(l.callbacks=null,l=0;l<a.length;l++)Xr(a[l],t)}function hu(l,t){try{var a=t.updateQueue,e=a!==null?a.lastEffect:null;if(e!==null){var u=e.next;a=u;do{if((a.tag&l)===l){e=void 0;var n=a.create,i=a.inst;e=n(),i.destroy=e}a=a.next}while(a!==u)}}catch(c){dl(t,t.return,c)}}function va(l,t,a){try{var e=t.updateQueue,u=e!==null?e.lastEffect:null;if(u!==null){var n=u.next;e=n;do{if((e.tag&l)===l){var i=e.inst,c=i.destroy;if(c!==void 0){i.destroy=void 0,u=t;var s=a;try{c()}catch(h){dl(u,s,h)}}}e=e.next}while(e!==n)}}catch(h){dl(t,t.return,h)}}function Zr(l){var t=l.updateQueue;if(t!==null){var a=l.stateNode;try{Qr(t,a)}catch(e){dl(l,l.return,e)}}}function Vr(l,t,a){a.props=Qa(l.type,l.memoizedProps),a.state=l.memoizedState;try{a.componentWillUnmount()}catch(e){dl(l,t,e)}}function La(l,t){try{var a=l.ref;if(a!==null){var e=l.stateNode;switch(l.tag){case 26:case 27:case 5:var u=e;break;default:u=e}typeof a=="function"?l.refCleanup=a(u):a.current=u}}catch(n){dl(l,t,n)}}function tt(l,t){var a=l.ref,e=l.refCleanup;if(a!==null)if(typeof e=="function")try{e()}catch(u){dl(l,t,u)}finally{l.refCleanup=null,l=l.alternate,l!=null&&(l.refCleanup=null)}else if(typeof a=="function")try{a(null)}catch(u){dl(l,t,u)}else a.current=null}function Lr(l){var t=l.type,a=l.memoizedProps,e=l.stateNode;try{l:switch(t){case"button":case"input":case"select":case"textarea":a.autoFocus&&e.focus();break l;case"img":a.src?e.src=a.src:a.srcSet&&(e.srcset=a.srcSet)}}catch(u){dl(l,l.return,u)}}function Kr(l,t,a){try{var e=l.stateNode;m1(e,l.type,a,t),e[$l]=t}catch(u){dl(l,l.return,u)}}function wr(l){return l.tag===5||l.tag===3||l.tag===26||l.tag===27||l.tag===4}function Ec(l){l:for(;;){for(;l.sibling===null;){if(l.return===null||wr(l.return))return null;l=l.return}for(l.sibling.return=l.return,l=l.sibling;l.tag!==5&&l.tag!==6&&l.tag!==27&&l.tag!==18;){if(l.flags&2||l.child===null||l.tag===4)continue l;l.child.return=l,l=l.child}if(!(l.flags&2))return l.stateNode}}function Tc(l,t,a){var e=l.tag;if(e===5||e===6)l=l.stateNode,t?a.nodeType===8?a.parentNode.insertBefore(l,t):a.insertBefore(l,t):(a.nodeType===8?(t=a.parentNode,t.insertBefore(l,a)):(t=a,t.appendChild(l)),a=a._reactRootContainer,a!=null||t.onclick!==null||(t.onclick=Yn));else if(e!==4&&e!==27&&(l=l.child,l!==null))for(Tc(l,t,a),l=l.sibling;l!==null;)Tc(l,t,a),l=l.sibling}function An(l,t,a){var e=l.tag;if(e===5||e===6)l=l.stateNode,t?a.insertBefore(l,t):a.appendChild(l);else if(e!==4&&e!==27&&(l=l.child,l!==null))for(An(l,t,a),l=l.sibling;l!==null;)An(l,t,a),l=l.sibling}var Zt=!1,pl=!1,zc=!1,Jr=typeof WeakSet=="function"?WeakSet:Set,Hl=null,kr=!1;function w0(l,t){if(l=l.containerInfo,Fc=Ln,l=os(l),Oi(l)){if("selectionStart"in l)var a={start:l.selectionStart,end:l.selectionEnd};else l:{a=(a=l.ownerDocument)&&a.defaultView||window;var e=a.getSelection&&a.getSelection();if(e&&e.rangeCount!==0){a=e.anchorNode;var u=e.anchorOffset,n=e.focusNode;e=e.focusOffset;try{a.nodeType,n.nodeType}catch{a=null;break l}var i=0,c=-1,s=-1,h=0,T=0,M=l,g=null;t:for(;;){for(var E;M!==a||u!==0&&M.nodeType!==3||(c=i+u),M!==n||e!==0&&M.nodeType!==3||(s=i+e),M.nodeType===3&&(i+=M.nodeValue.length),(E=M.firstChild)!==null;)g=M,M=E;for(;;){if(M===l)break t;if(g===a&&++h===u&&(c=i),g===n&&++T===e&&(s=i),(E=M.nextSibling)!==null)break;M=g,g=M.parentNode}M=E}a=c===-1||s===-1?null:{start:c,end:s}}else a=null}a=a||{start:0,end:0}}else a=null;for(Pc={focusedElem:l,selectionRange:a},Ln=!1,Hl=t;Hl!==null;)if(t=Hl,l=t.child,(t.subtreeFlags&1028)!==0&&l!==null)l.return=t,Hl=l;else for(;Hl!==null;){switch(t=Hl,n=t.alternate,l=t.flags,t.tag){case 0:break;case 11:case 15:break;case 1:if(l&1024&&n!==null){l=void 0,a=t,u=n.memoizedProps,n=n.memoizedState,e=a.stateNode;try{var q=Qa(a.type,u,a.elementType===a.type);l=e.getSnapshotBeforeUpdate(q,n),e.__reactInternalSnapshotBeforeUpdate=l}catch(V){dl(a,a.return,V)}}break;case 3:if(l&1024){if(l=t.stateNode.containerInfo,a=l.nodeType,a===9)af(l);else if(a===1)switch(l.nodeName){case"HEAD":case"HTML":case"BODY":af(l);break;default:l.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if(l&1024)throw Error(r(163))}if(l=t.sibling,l!==null){l.return=t.return,Hl=l;break}Hl=t.return}return q=kr,kr=!1,q}function $r(l,t,a){var e=a.flags;switch(a.tag){case 0:case 11:case 15:Lt(l,a),e&4&&hu(5,a);break;case 1:if(Lt(l,a),e&4)if(l=a.stateNode,t===null)try{l.componentDidMount()}catch(c){dl(a,a.return,c)}else{var u=Qa(a.type,t.memoizedProps);t=t.memoizedState;try{l.componentDidUpdate(u,t,l.__reactInternalSnapshotBeforeUpdate)}catch(c){dl(a,a.return,c)}}e&64&&Zr(a),e&512&&La(a,a.return);break;case 3:if(Lt(l,a),e&64&&(e=a.updateQueue,e!==null)){if(l=null,a.child!==null)switch(a.child.tag){case 27:case 5:l=a.child.stateNode;break;case 1:l=a.child.stateNode}try{Qr(e,l)}catch(c){dl(a,a.return,c)}}break;case 26:Lt(l,a),e&512&&La(a,a.return);break;case 27:case 5:Lt(l,a),t===null&&e&4&&Lr(a),e&512&&La(a,a.return);break;case 12:Lt(l,a);break;case 13:Lt(l,a),e&4&&Pr(l,a);break;case 22:if(u=a.memoizedState!==null||Zt,!u){t=t!==null&&t.memoizedState!==null||pl;var n=Zt,i=pl;Zt=u,(pl=t)&&!i?ya(l,a,(a.subtreeFlags&8772)!==0):Lt(l,a),Zt=n,pl=i}e&512&&(a.memoizedProps.mode==="manual"?La(a,a.return):tt(a,a.return));break;default:Lt(l,a)}}function Wr(l){var t=l.alternate;t!==null&&(l.alternate=null,Wr(t)),l.child=null,l.deletions=null,l.sibling=null,l.tag===5&&(t=l.stateNode,t!==null&&si(t)),l.stateNode=null,l.return=null,l.dependencies=null,l.memoizedProps=null,l.memoizedState=null,l.pendingProps=null,l.stateNode=null,l.updateQueue=null}var _l=null,at=!1;function Vt(l,t,a){for(a=a.child;a!==null;)Fr(l,t,a),a=a.sibling}function Fr(l,t,a){if(Pl&&typeof Pl.onCommitFiberUnmount=="function")try{Pl.onCommitFiberUnmount(Be,a)}catch{}switch(a.tag){case 26:pl||tt(a,t),Vt(l,t,a),a.memoizedState?a.memoizedState.count--:a.stateNode&&(a=a.stateNode,a.parentNode.removeChild(a));break;case 27:pl||tt(a,t);var e=_l,u=at;for(_l=a.stateNode,Vt(l,t,a),a=a.stateNode,t=a.attributes;t.length;)a.removeAttributeNode(t[0]);si(a),_l=e,at=u;break;case 5:pl||tt(a,t);case 6:u=_l;var n=at;if(_l=null,Vt(l,t,a),_l=u,at=n,_l!==null)if(at)try{l=_l,e=a.stateNode,l.nodeType===8?l.parentNode.removeChild(e):l.removeChild(e)}catch(i){dl(a,t,i)}else try{_l.removeChild(a.stateNode)}catch(i){dl(a,t,i)}break;case 18:_l!==null&&(at?(t=_l,a=a.stateNode,t.nodeType===8?tf(t.parentNode,a):t.nodeType===1&&tf(t,a),Uu(t)):tf(_l,a.stateNode));break;case 4:e=_l,u=at,_l=a.stateNode.containerInfo,at=!0,Vt(l,t,a),_l=e,at=u;break;case 0:case 11:case 14:case 15:pl||va(2,a,t),pl||va(4,a,t),Vt(l,t,a);break;case 1:pl||(tt(a,t),e=a.stateNode,typeof e.componentWillUnmount=="function"&&Vr(a,t,e)),Vt(l,t,a);break;case 21:Vt(l,t,a);break;case 22:pl||tt(a,t),pl=(e=pl)||a.memoizedState!==null,Vt(l,t,a),pl=e;break;default:Vt(l,t,a)}}function Pr(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null&&(l=l.dehydrated,l!==null))))try{Uu(l)}catch(a){dl(t,t.return,a)}}function J0(l){switch(l.tag){case 13:case 19:var t=l.stateNode;return t===null&&(t=l.stateNode=new Jr),t;case 22:return l=l.stateNode,t=l._retryCache,t===null&&(t=l._retryCache=new Jr),t;default:throw Error(r(435,l.tag))}}function Ac(l,t){var a=J0(l);t.forEach(function(e){var u=i1.bind(null,l,e);a.has(e)||(a.add(e),e.then(u,u))})}function ht(l,t){var a=t.deletions;if(a!==null)for(var e=0;e<a.length;e++){var u=a[e],n=l,i=t,c=i;l:for(;c!==null;){switch(c.tag){case 27:case 5:_l=c.stateNode,at=!1;break l;case 3:_l=c.stateNode.containerInfo,at=!0;break l;case 4:_l=c.stateNode.containerInfo,at=!0;break l}c=c.return}if(_l===null)throw Error(r(160));Fr(n,i,u),_l=null,at=!1,n=u.alternate,n!==null&&(n.return=null),u.return=null}if(t.subtreeFlags&13878)for(t=t.child;t!==null;)Ir(t,l),t=t.sibling}var Et=null;function Ir(l,t){var a=l.alternate,e=l.flags;switch(l.tag){case 0:case 11:case 14:case 15:ht(t,l),vt(l),e&4&&(va(3,l,l.return),hu(3,l),va(5,l,l.return));break;case 1:ht(t,l),vt(l),e&512&&(pl||a===null||tt(a,a.return)),e&64&&Zt&&(l=l.updateQueue,l!==null&&(e=l.callbacks,e!==null&&(a=l.shared.hiddenCallbacks,l.shared.hiddenCallbacks=a===null?e:a.concat(e))));break;case 26:var u=Et;if(ht(t,l),vt(l),e&512&&(pl||a===null||tt(a,a.return)),e&4){var n=a!==null?a.memoizedState:null;if(e=l.memoizedState,a===null)if(e===null)if(l.stateNode===null){l:{e=l.type,a=l.memoizedProps,u=u.ownerDocument||u;t:switch(e){case"title":n=u.getElementsByTagName("title")[0],(!n||n[Ge]||n[Cl]||n.namespaceURI==="http://www.w3.org/2000/svg"||n.hasAttribute("itemprop"))&&(n=u.createElement(e),u.head.insertBefore(n,u.querySelector("head > title"))),Yl(n,e,a),n[Cl]=l,Ul(n),e=n;break l;case"link":var i=Ko("link","href",u).get(e+(a.href||""));if(i){for(var c=0;c<i.length;c++)if(n=i[c],n.getAttribute("href")===(a.href==null?null:a.href)&&n.getAttribute("rel")===(a.rel==null?null:a.rel)&&n.getAttribute("title")===(a.title==null?null:a.title)&&n.getAttribute("crossorigin")===(a.crossOrigin==null?null:a.crossOrigin)){i.splice(c,1);break t}}n=u.createElement(e),Yl(n,e,a),u.head.appendChild(n);break;case"meta":if(i=Ko("meta","content",u).get(e+(a.content||""))){for(c=0;c<i.length;c++)if(n=i[c],n.getAttribute("content")===(a.content==null?null:""+a.content)&&n.getAttribute("name")===(a.name==null?null:a.name)&&n.getAttribute("property")===(a.property==null?null:a.property)&&n.getAttribute("http-equiv")===(a.httpEquiv==null?null:a.httpEquiv)&&n.getAttribute("charset")===(a.charSet==null?null:a.charSet)){i.splice(c,1);break t}}n=u.createElement(e),Yl(n,e,a),u.head.appendChild(n);break;default:throw Error(r(468,e))}n[Cl]=l,Ul(n),e=n}l.stateNode=e}else wo(u,l.type,l.stateNode);else l.stateNode=Lo(u,e,l.memoizedProps);else n!==e?(n===null?a.stateNode!==null&&(a=a.stateNode,a.parentNode.removeChild(a)):n.count--,e===null?wo(u,l.type,l.stateNode):Lo(u,e,l.memoizedProps)):e===null&&l.stateNode!==null&&Kr(l,l.memoizedProps,a.memoizedProps)}break;case 27:if(e&4&&l.alternate===null){u=l.stateNode,n=l.memoizedProps;try{for(var s=u.firstChild;s;){var h=s.nextSibling,T=s.nodeName;s[Ge]||T==="HEAD"||T==="BODY"||T==="SCRIPT"||T==="STYLE"||T==="LINK"&&s.rel.toLowerCase()==="stylesheet"||u.removeChild(s),s=h}for(var M=l.type,g=u.attributes;g.length;)u.removeAttributeNode(g[0]);Yl(u,M,n),u[Cl]=l,u[$l]=n}catch(q){dl(l,l.return,q)}}case 5:if(ht(t,l),vt(l),e&512&&(pl||a===null||tt(a,a.return)),l.flags&32){u=l.stateNode;try{ue(u,"")}catch(q){dl(l,l.return,q)}}e&4&&l.stateNode!=null&&(u=l.memoizedProps,Kr(l,u,a!==null?a.memoizedProps:u)),e&1024&&(zc=!0);break;case 6:if(ht(t,l),vt(l),e&4){if(l.stateNode===null)throw Error(r(162));e=l.memoizedProps,a=l.stateNode;try{a.nodeValue=e}catch(q){dl(l,l.return,q)}}break;case 3:if(Qn=null,u=Et,Et=Gn(t.containerInfo),ht(t,l),Et=u,vt(l),e&4&&a!==null&&a.memoizedState.isDehydrated)try{Uu(t.containerInfo)}catch(q){dl(l,l.return,q)}zc&&(zc=!1,lo(l));break;case 4:e=Et,Et=Gn(l.stateNode.containerInfo),ht(t,l),vt(l),Et=e;break;case 12:ht(t,l),vt(l);break;case 13:ht(t,l),vt(l),l.child.flags&8192&&l.memoizedState!==null!=(a!==null&&a.memoizedState!==null)&&(Hc=Ot()),e&4&&(e=l.updateQueue,e!==null&&(l.updateQueue=null,Ac(l,e)));break;case 22:if(e&512&&(pl||a===null||tt(a,a.return)),s=l.memoizedState!==null,h=a!==null&&a.memoizedState!==null,T=Zt,M=pl,Zt=T||s,pl=M||h,ht(t,l),pl=M,Zt=T,vt(l),t=l.stateNode,t._current=l,t._visibility&=-3,t._visibility|=t._pendingVisibility&2,e&8192&&(t._visibility=s?t._visibility&-2:t._visibility|1,s&&(t=Zt||pl,a===null||h||t||Ee(l)),l.memoizedProps===null||l.memoizedProps.mode!=="manual"))l:for(a=null,t=l;;){if(t.tag===5||t.tag===26||t.tag===27){if(a===null){h=a=t;try{if(u=h.stateNode,s)n=u.style,typeof n.setProperty=="function"?n.setProperty("display","none","important"):n.display="none";else{i=h.stateNode,c=h.memoizedProps.style;var E=c!=null&&c.hasOwnProperty("display")?c.display:null;i.style.display=E==null||typeof E=="boolean"?"":(""+E).trim()}}catch(q){dl(h,h.return,q)}}}else if(t.tag===6){if(a===null){h=t;try{h.stateNode.nodeValue=s?"":h.memoizedProps}catch(q){dl(h,h.return,q)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===l)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break l;for(;t.sibling===null;){if(t.return===null||t.return===l)break l;a===t&&(a=null),t=t.return}a===t&&(a=null),t.sibling.return=t.return,t=t.sibling}e&4&&(e=l.updateQueue,e!==null&&(a=e.retryQueue,a!==null&&(e.retryQueue=null,Ac(l,a))));break;case 19:ht(t,l),vt(l),e&4&&(e=l.updateQueue,e!==null&&(l.updateQueue=null,Ac(l,e)));break;case 21:break;default:ht(t,l),vt(l)}}function vt(l){var t=l.flags;if(t&2){try{if(l.tag!==27){l:{for(var a=l.return;a!==null;){if(wr(a)){var e=a;break l}a=a.return}throw Error(r(160))}switch(e.tag){case 27:var u=e.stateNode,n=Ec(l);An(l,n,u);break;case 5:var i=e.stateNode;e.flags&32&&(ue(i,""),e.flags&=-33);var c=Ec(l);An(l,c,i);break;case 3:case 4:var s=e.stateNode.containerInfo,h=Ec(l);Tc(l,h,s);break;default:throw Error(r(161))}}}catch(T){dl(l,l.return,T)}l.flags&=-3}t&4096&&(l.flags&=-4097)}function lo(l){if(l.subtreeFlags&1024)for(l=l.child;l!==null;){var t=l;lo(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),l=l.sibling}}function Lt(l,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)$r(l,t.alternate,t),t=t.sibling}function Ee(l){for(l=l.child;l!==null;){var t=l;switch(t.tag){case 0:case 11:case 14:case 15:va(4,t,t.return),Ee(t);break;case 1:tt(t,t.return);var a=t.stateNode;typeof a.componentWillUnmount=="function"&&Vr(t,t.return,a),Ee(t);break;case 26:case 27:case 5:tt(t,t.return),Ee(t);break;case 22:tt(t,t.return),t.memoizedState===null&&Ee(t);break;default:Ee(t)}l=l.sibling}}function ya(l,t,a){for(a=a&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var e=t.alternate,u=l,n=t,i=n.flags;switch(n.tag){case 0:case 11:case 15:ya(u,n,a),hu(4,n);break;case 1:if(ya(u,n,a),e=n,u=e.stateNode,typeof u.componentDidMount=="function")try{u.componentDidMount()}catch(h){dl(e,e.return,h)}if(e=n,u=e.updateQueue,u!==null){var c=e.stateNode;try{var s=u.shared.hiddenCallbacks;if(s!==null)for(u.shared.hiddenCallbacks=null,u=0;u<s.length;u++)Xr(s[u],c)}catch(h){dl(e,e.return,h)}}a&&i&64&&Zr(n),La(n,n.return);break;case 26:case 27:case 5:ya(u,n,a),a&&e===null&&i&4&&Lr(n),La(n,n.return);break;case 12:ya(u,n,a);break;case 13:ya(u,n,a),a&&i&4&&Pr(u,n);break;case 22:n.memoizedState===null&&ya(u,n,a),La(n,n.return);break;default:ya(u,n,a)}t=t.sibling}}function Oc(l,t){var a=null;l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(a=l.memoizedState.cachePool.pool),l=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(l=t.memoizedState.cachePool.pool),l!==a&&(l!=null&&l.refCount++,a!=null&&eu(a))}function Mc(l,t){l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&eu(l))}function ma(l,t,a,e){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)to(l,t,a,e),t=t.sibling}function to(l,t,a,e){var u=t.flags;switch(t.tag){case 0:case 11:case 15:ma(l,t,a,e),u&2048&&hu(9,t);break;case 3:ma(l,t,a,e),u&2048&&(l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&eu(l)));break;case 12:if(u&2048){ma(l,t,a,e),l=t.stateNode;try{var n=t.memoizedProps,i=n.id,c=n.onPostCommit;typeof c=="function"&&c(i,t.alternate===null?"mount":"update",l.passiveEffectDuration,-0)}catch(s){dl(t,t.return,s)}}else ma(l,t,a,e);break;case 23:break;case 22:n=t.stateNode,t.memoizedState!==null?n._visibility&4?ma(l,t,a,e):vu(l,t):n._visibility&4?ma(l,t,a,e):(n._visibility|=4,Te(l,t,a,e,(t.subtreeFlags&10256)!==0)),u&2048&&Oc(t.alternate,t);break;case 24:ma(l,t,a,e),u&2048&&Mc(t.alternate,t);break;default:ma(l,t,a,e)}}function Te(l,t,a,e,u){for(u=u&&(t.subtreeFlags&10256)!==0,t=t.child;t!==null;){var n=l,i=t,c=a,s=e,h=i.flags;switch(i.tag){case 0:case 11:case 15:Te(n,i,c,s,u),hu(8,i);break;case 23:break;case 22:var T=i.stateNode;i.memoizedState!==null?T._visibility&4?Te(n,i,c,s,u):vu(n,i):(T._visibility|=4,Te(n,i,c,s,u)),u&&h&2048&&Oc(i.alternate,i);break;case 24:Te(n,i,c,s,u),u&&h&2048&&Mc(i.alternate,i);break;default:Te(n,i,c,s,u)}t=t.sibling}}function vu(l,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var a=l,e=t,u=e.flags;switch(e.tag){case 22:vu(a,e),u&2048&&Oc(e.alternate,e);break;case 24:vu(a,e),u&2048&&Mc(e.alternate,e);break;default:vu(a,e)}t=t.sibling}}var yu=8192;function ze(l){if(l.subtreeFlags&yu)for(l=l.child;l!==null;)ao(l),l=l.sibling}function ao(l){switch(l.tag){case 26:ze(l),l.flags&yu&&l.memoizedState!==null&&q1(Et,l.memoizedState,l.memoizedProps);break;case 5:ze(l);break;case 3:case 4:var t=Et;Et=Gn(l.stateNode.containerInfo),ze(l),Et=t;break;case 22:l.memoizedState===null&&(t=l.alternate,t!==null&&t.memoizedState!==null?(t=yu,yu=16777216,ze(l),yu=t):ze(l));break;default:ze(l)}}function eo(l){var t=l.alternate;if(t!==null&&(l=t.child,l!==null)){t.child=null;do t=l.sibling,l.sibling=null,l=t;while(l!==null)}}function mu(l){var t=l.deletions;if(l.flags&16){if(t!==null)for(var a=0;a<t.length;a++){var e=t[a];Hl=e,no(e,l)}eo(l)}if(l.subtreeFlags&10256)for(l=l.child;l!==null;)uo(l),l=l.sibling}function uo(l){switch(l.tag){case 0:case 11:case 15:mu(l),l.flags&2048&&va(9,l,l.return);break;case 3:mu(l);break;case 12:mu(l);break;case 22:var t=l.stateNode;l.memoizedState!==null&&t._visibility&4&&(l.return===null||l.return.tag!==13)?(t._visibility&=-5,On(l)):mu(l);break;default:mu(l)}}function On(l){var t=l.deletions;if(l.flags&16){if(t!==null)for(var a=0;a<t.length;a++){var e=t[a];Hl=e,no(e,l)}eo(l)}for(l=l.child;l!==null;){switch(t=l,t.tag){case 0:case 11:case 15:va(8,t,t.return),On(t);break;case 22:a=t.stateNode,a._visibility&4&&(a._visibility&=-5,On(t));break;default:On(t)}l=l.sibling}}function no(l,t){for(;Hl!==null;){var a=Hl;switch(a.tag){case 0:case 11:case 15:va(8,a,t);break;case 23:case 22:if(a.memoizedState!==null&&a.memoizedState.cachePool!==null){var e=a.memoizedState.cachePool.pool;e!=null&&e.refCount++}break;case 24:eu(a.memoizedState.cache)}if(e=a.child,e!==null)e.return=a,Hl=e;else l:for(a=l;Hl!==null;){e=Hl;var u=e.sibling,n=e.return;if(Wr(e),e===a){Hl=null;break l}if(u!==null){u.return=n,Hl=u;break l}Hl=n}}}function k0(l,t,a,e){this.tag=l,this.key=a,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=e,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function yt(l,t,a,e){return new k0(l,t,a,e)}function Dc(l){return l=l.prototype,!(!l||!l.isReactComponent)}function ga(l,t){var a=l.alternate;return a===null?(a=yt(l.tag,t,l.key,l.mode),a.elementType=l.elementType,a.type=l.type,a.stateNode=l.stateNode,a.alternate=l,l.alternate=a):(a.pendingProps=t,a.type=l.type,a.flags=0,a.subtreeFlags=0,a.deletions=null),a.flags=l.flags&31457280,a.childLanes=l.childLanes,a.lanes=l.lanes,a.child=l.child,a.memoizedProps=l.memoizedProps,a.memoizedState=l.memoizedState,a.updateQueue=l.updateQueue,t=l.dependencies,a.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},a.sibling=l.sibling,a.index=l.index,a.ref=l.ref,a.refCleanup=l.refCleanup,a}function io(l,t){l.flags&=31457282;var a=l.alternate;return a===null?(l.childLanes=0,l.lanes=t,l.child=null,l.subtreeFlags=0,l.memoizedProps=null,l.memoizedState=null,l.updateQueue=null,l.dependencies=null,l.stateNode=null):(l.childLanes=a.childLanes,l.lanes=a.lanes,l.child=a.child,l.subtreeFlags=0,l.deletions=null,l.memoizedProps=a.memoizedProps,l.memoizedState=a.memoizedState,l.updateQueue=a.updateQueue,l.type=a.type,t=a.dependencies,l.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),l}function Mn(l,t,a,e,u,n){var i=0;if(e=l,typeof l=="function")Dc(l)&&(i=1);else if(typeof l=="string")i=H1(l,a,At.current)?26:l==="html"||l==="head"||l==="body"?27:5;else l:switch(l){case O:return Ka(a.children,u,n,t);case S:i=8,u|=24;break;case R:return l=yt(12,a,t,u|2),l.elementType=R,l.lanes=n,l;case wl:return l=yt(13,a,t,u),l.elementType=wl,l.lanes=n,l;case Zl:return l=yt(19,a,t,u),l.elementType=Zl,l.lanes=n,l;case sl:return co(a,u,n,t);default:if(typeof l=="object"&&l!==null)switch(l.$$typeof){case Y:case P:i=10;break l;case w:i=9;break l;case Al:i=11;break l;case al:i=14;break l;case el:i=16,e=null;break l}i=29,a=Error(r(130,l===null?"null":typeof l,"")),e=null}return t=yt(i,a,t,u),t.elementType=l,t.type=e,t.lanes=n,t}function Ka(l,t,a,e){return l=yt(7,l,e,t),l.lanes=a,l}function co(l,t,a,e){l=yt(22,l,e,t),l.elementType=sl,l.lanes=a;var u={_visibility:1,_pendingVisibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null,_current:null,detach:function(){var n=u._current;if(n===null)throw Error(r(456));if(!(u._pendingVisibility&2)){var i=na(n,2);i!==null&&(u._pendingVisibility|=2,Kl(i,n,2))}},attach:function(){var n=u._current;if(n===null)throw Error(r(456));if(u._pendingVisibility&2){var i=na(n,2);i!==null&&(u._pendingVisibility&=-3,Kl(i,n,2))}}};return l.stateNode=u,l}function _c(l,t,a){return l=yt(6,l,null,t),l.lanes=a,l}function Nc(l,t,a){return t=yt(4,l.children!==null?l.children:[],l.key,t),t.lanes=a,t.stateNode={containerInfo:l.containerInfo,pendingChildren:null,implementation:l.implementation},t}function Kt(l){l.flags|=4}function fo(l,t){if(t.type!=="stylesheet"||t.state.loading&4)l.flags&=-16777217;else if(l.flags|=16777216,!Jo(t)){if(t=dt.current,t!==null&&((tl&4194176)===tl?Dt!==null:(tl&62914560)!==tl&&!(tl&536870912)||t!==Dt))throw lu=ji,Os;l.flags|=8192}}function Dn(l,t){t!==null&&(l.flags|=4),l.flags&16384&&(t=l.tag!==22?Mf():536870912,l.lanes|=t,Oe|=t)}function gu(l,t){if(!ul)switch(l.tailMode){case"hidden":t=l.tail;for(var a=null;t!==null;)t.alternate!==null&&(a=t),t=t.sibling;a===null?l.tail=null:a.sibling=null;break;case"collapsed":a=l.tail;for(var e=null;a!==null;)a.alternate!==null&&(e=a),a=a.sibling;e===null?t||l.tail===null?l.tail=null:l.tail.sibling=null:e.sibling=null}}function bl(l){var t=l.alternate!==null&&l.alternate.child===l.child,a=0,e=0;if(t)for(var u=l.child;u!==null;)a|=u.lanes|u.childLanes,e|=u.subtreeFlags&31457280,e|=u.flags&31457280,u.return=l,u=u.sibling;else for(u=l.child;u!==null;)a|=u.lanes|u.childLanes,e|=u.subtreeFlags,e|=u.flags,u.return=l,u=u.sibling;return l.subtreeFlags|=e,l.childLanes=a,t}function $0(l,t,a){var e=t.pendingProps;switch(Ri(t),t.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return bl(t),null;case 1:return bl(t),null;case 3:return a=t.stateNode,e=null,l!==null&&(e=l.memoizedState.cache),t.memoizedState.cache!==e&&(t.flags|=2048),Qt(xl),Pa(),a.pendingContext&&(a.context=a.pendingContext,a.pendingContext=null),(l===null||l.child===null)&&(We(t)?Kt(t):l===null||l.memoizedState.isDehydrated&&!(t.flags&256)||(t.flags|=1024,pt!==null&&(Yc(pt),pt=null))),bl(t),null;case 26:return a=t.memoizedState,l===null?(Kt(t),a!==null?(bl(t),fo(t,a)):(bl(t),t.flags&=-16777217)):a?a!==l.memoizedState?(Kt(t),bl(t),fo(t,a)):(bl(t),t.flags&=-16777217):(l.memoizedProps!==e&&Kt(t),bl(t),t.flags&=-16777217),null;case 27:Cu(t),a=ta.current;var u=t.type;if(l!==null&&t.stateNode!=null)l.memoizedProps!==e&&Kt(t);else{if(!e){if(t.stateNode===null)throw Error(r(166));return bl(t),null}l=At.current,We(t)?zs(t):(l=Go(u,e,a),t.stateNode=l,Kt(t))}return bl(t),null;case 5:if(Cu(t),a=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==e&&Kt(t);else{if(!e){if(t.stateNode===null)throw Error(r(166));return bl(t),null}if(l=At.current,We(t))zs(t);else{switch(u=Cn(ta.current),l){case 1:l=u.createElementNS("http://www.w3.org/2000/svg",a);break;case 2:l=u.createElementNS("http://www.w3.org/1998/Math/MathML",a);break;default:switch(a){case"svg":l=u.createElementNS("http://www.w3.org/2000/svg",a);break;case"math":l=u.createElementNS("http://www.w3.org/1998/Math/MathML",a);break;case"script":l=u.createElement("div"),l.innerHTML="<script><\/script>",l=l.removeChild(l.firstChild);break;case"select":l=typeof e.is=="string"?u.createElement("select",{is:e.is}):u.createElement("select"),e.multiple?l.multiple=!0:e.size&&(l.size=e.size);break;default:l=typeof e.is=="string"?u.createElement(a,{is:e.is}):u.createElement(a)}}l[Cl]=t,l[$l]=e;l:for(u=t.child;u!==null;){if(u.tag===5||u.tag===6)l.appendChild(u.stateNode);else if(u.tag!==4&&u.tag!==27&&u.child!==null){u.child.return=u,u=u.child;continue}if(u===t)break l;for(;u.sibling===null;){if(u.return===null||u.return===t)break l;u=u.return}u.sibling.return=u.return,u=u.sibling}t.stateNode=l;l:switch(Yl(l,a,e),a){case"button":case"input":case"select":case"textarea":l=!!e.autoFocus;break l;case"img":l=!0;break l;default:l=!1}l&&Kt(t)}}return bl(t),t.flags&=-16777217,null;case 6:if(l&&t.stateNode!=null)l.memoizedProps!==e&&Kt(t);else{if(typeof e!="string"&&t.stateNode===null)throw Error(r(166));if(l=ta.current,We(t)){if(l=t.stateNode,a=t.memoizedProps,e=null,u=Ll,u!==null)switch(u.tag){case 27:case 5:e=u.memoizedProps}l[Cl]=t,l=!!(l.nodeValue===a||e!==null&&e.suppressHydrationWarning===!0||Ho(l.nodeValue,a)),l||qa(t)}else l=Cn(l).createTextNode(e),l[Cl]=t,t.stateNode=l}return bl(t),null;case 13:if(e=t.memoizedState,l===null||l.memoizedState!==null&&l.memoizedState.dehydrated!==null){if(u=We(t),e!==null&&e.dehydrated!==null){if(l===null){if(!u)throw Error(r(318));if(u=t.memoizedState,u=u!==null?u.dehydrated:null,!u)throw Error(r(317));u[Cl]=t}else Fe(),!(t.flags&128)&&(t.memoizedState=null),t.flags|=4;bl(t),u=!1}else pt!==null&&(Yc(pt),pt=null),u=!0;if(!u)return t.flags&256?(Yt(t),t):(Yt(t),null)}if(Yt(t),t.flags&128)return t.lanes=a,t;if(a=e!==null,l=l!==null&&l.memoizedState!==null,a){e=t.child,u=null,e.alternate!==null&&e.alternate.memoizedState!==null&&e.alternate.memoizedState.cachePool!==null&&(u=e.alternate.memoizedState.cachePool.pool);var n=null;e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(n=e.memoizedState.cachePool.pool),n!==u&&(e.flags|=2048)}return a!==l&&a&&(t.child.flags|=8192),Dn(t,t.updateQueue),bl(t),null;case 4:return Pa(),l===null&&kc(t.stateNode.containerInfo),bl(t),null;case 10:return Qt(t.type),bl(t),null;case 19:if(Ol(Nl),u=t.memoizedState,u===null)return bl(t),null;if(e=(t.flags&128)!==0,n=u.rendering,n===null)if(e)gu(u,!1);else{if(El!==0||l!==null&&l.flags&128)for(l=t.child;l!==null;){if(n=rn(l),n!==null){for(t.flags|=128,gu(u,!1),l=n.updateQueue,t.updateQueue=l,Dn(t,l),t.subtreeFlags=0,l=a,a=t.child;a!==null;)io(a,l),a=a.sibling;return ml(Nl,Nl.current&1|2),t.child}l=l.sibling}u.tail!==null&&Ot()>_n&&(t.flags|=128,e=!0,gu(u,!1),t.lanes=4194304)}else{if(!e)if(l=rn(n),l!==null){if(t.flags|=128,e=!0,l=l.updateQueue,t.updateQueue=l,Dn(t,l),gu(u,!0),u.tail===null&&u.tailMode==="hidden"&&!n.alternate&&!ul)return bl(t),null}else 2*Ot()-u.renderingStartTime>_n&&a!==536870912&&(t.flags|=128,e=!0,gu(u,!1),t.lanes=4194304);u.isBackwards?(n.sibling=t.child,t.child=n):(l=u.last,l!==null?l.sibling=n:t.child=n,u.last=n)}return u.tail!==null?(t=u.tail,u.rendering=t,u.tail=t.sibling,u.renderingStartTime=Ot(),t.sibling=null,l=Nl.current,ml(Nl,e?l&1|2:l&1),t):(bl(t),null);case 22:case 23:return Yt(t),Bi(),e=t.memoizedState!==null,l!==null?l.memoizedState!==null!==e&&(t.flags|=8192):e&&(t.flags|=8192),e?a&536870912&&!(t.flags&128)&&(bl(t),t.subtreeFlags&6&&(t.flags|=8192)):bl(t),a=t.updateQueue,a!==null&&Dn(t,a.retryQueue),a=null,l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(a=l.memoizedState.cachePool.pool),e=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(e=t.memoizedState.cachePool.pool),e!==a&&(t.flags|=2048),l!==null&&Ol(Ya),null;case 24:return a=null,l!==null&&(a=l.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),Qt(xl),bl(t),null;case 25:return null}throw Error(r(156,t.tag))}function W0(l,t){switch(Ri(t),t.tag){case 1:return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 3:return Qt(xl),Pa(),l=t.flags,l&65536&&!(l&128)?(t.flags=l&-65537|128,t):null;case 26:case 27:case 5:return Cu(t),null;case 13:if(Yt(t),l=t.memoizedState,l!==null&&l.dehydrated!==null){if(t.alternate===null)throw Error(r(340));Fe()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 19:return Ol(Nl),null;case 4:return Pa(),null;case 10:return Qt(t.type),null;case 22:case 23:return Yt(t),Bi(),l!==null&&Ol(Ya),l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 24:return Qt(xl),null;case 25:return null;default:return null}}function so(l,t){switch(Ri(t),t.tag){case 3:Qt(xl),Pa();break;case 26:case 27:case 5:Cu(t);break;case 4:Pa();break;case 13:Yt(t);break;case 19:Ol(Nl);break;case 10:Qt(t.type);break;case 22:case 23:Yt(t),Bi(),l!==null&&Ol(Ya);break;case 24:Qt(xl)}}var F0={getCacheForType:function(l){var t=Gl(xl),a=t.data.get(l);return a===void 0&&(a=l(),t.data.set(l,a)),a}},P0=typeof WeakMap=="function"?WeakMap:Map,Sl=0,vl=null,F=null,tl=0,yl=0,et=null,wt=!1,Ae=!1,xc=!1,Jt=0,El=0,ba=0,wa=0,Uc=0,mt=0,Oe=0,bu=null,Nt=null,Rc=!1,Hc=0,_n=1/0,Nn=null,Sa=null,xn=!1,Ja=null,Su=0,jc=0,qc=null,pu=0,Bc=null;function ut(){if(Sl&2&&tl!==0)return tl&-tl;if(X.T!==null){var l=me;return l!==0?l:Lc()}return xf()}function ro(){mt===0&&(mt=!(tl&536870912)||ul?Of():536870912);var l=dt.current;return l!==null&&(l.flags|=32),mt}function Kl(l,t,a){(l===vl&&yl===2||l.cancelPendingCommit!==null)&&(Me(l,0),kt(l,tl,mt,!1)),Ce(l,a),(!(Sl&2)||l!==vl)&&(l===vl&&(!(Sl&2)&&(wa|=a),El===4&&kt(l,tl,mt,!1)),xt(l))}function oo(l,t,a){if(Sl&6)throw Error(r(327));var e=!a&&(t&60)===0&&(t&l.expiredLanes)===0||Ye(l,t),u=e?t1(l,t):Xc(l,t,!0),n=e;do{if(u===0){Ae&&!e&&kt(l,t,0,!1);break}else if(u===6)kt(l,t,0,!wt);else{if(a=l.current.alternate,n&&!I0(a)){u=Xc(l,t,!1),n=!1;continue}if(u===2){if(n=t,l.errorRecoveryDisabledLanes&n)var i=0;else i=l.pendingLanes&-536870913,i=i!==0?i:i&536870912?536870912:0;if(i!==0){t=i;l:{var c=l;u=bu;var s=c.current.memoizedState.isDehydrated;if(s&&(Me(c,i).flags|=256),i=Xc(c,i,!1),i!==2){if(xc&&!s){c.errorRecoveryDisabledLanes|=n,wa|=n,u=4;break l}n=Nt,Nt=u,n!==null&&Yc(n)}u=i}if(n=!1,u!==2)continue}}if(u===1){Me(l,0),kt(l,t,0,!0);break}l:{switch(e=l,u){case 0:case 1:throw Error(r(345));case 4:if((t&4194176)===t){kt(e,t,mt,!wt);break l}break;case 2:Nt=null;break;case 3:case 5:break;default:throw Error(r(329))}if(e.finishedWork=a,e.finishedLanes=t,(t&62914560)===t&&(n=Hc+300-Ot(),10<n)){if(kt(e,t,mt,!wt),Zu(e,0)!==0)break l;e.timeoutHandle=Bo(ho.bind(null,e,a,Nt,Nn,Rc,t,mt,wa,Oe,wt,2,-0,0),n);break l}ho(e,a,Nt,Nn,Rc,t,mt,wa,Oe,wt,0,-0,0)}}break}while(!0);xt(l)}function Yc(l){Nt===null?Nt=l:Nt.push.apply(Nt,l)}function ho(l,t,a,e,u,n,i,c,s,h,T,M,g){var E=t.subtreeFlags;if((E&8192||(E&16785408)===16785408)&&(Mu={stylesheets:null,count:0,unsuspend:j1},ao(t),t=B1(),t!==null)){l.cancelPendingCommit=t(po.bind(null,l,a,e,u,i,c,s,1,M,g)),kt(l,n,i,!h);return}po(l,a,e,u,i,c,s,T,M,g)}function I0(l){for(var t=l;;){var a=t.tag;if((a===0||a===11||a===15)&&t.flags&16384&&(a=t.updateQueue,a!==null&&(a=a.stores,a!==null)))for(var e=0;e<a.length;e++){var u=a[e],n=u.getSnapshot;u=u.value;try{if(!lt(n(),u))return!1}catch{return!1}}if(a=t.child,t.subtreeFlags&16384&&a!==null)a.return=t,t=a;else{if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function kt(l,t,a,e){t&=~Uc,t&=~wa,l.suspendedLanes|=t,l.pingedLanes&=~t,e&&(l.warmLanes|=t),e=l.expirationTimes;for(var u=t;0<u;){var n=31-Il(u),i=1<<n;e[n]=-1,u&=~i}a!==0&&Df(l,a,t)}function Un(){return Sl&6?!0:(Eu(0),!1)}function Cc(){if(F!==null){if(yl===0)var l=F.return;else l=F,Xt=Za=null,Li(l),ve=null,tu=0,l=F;for(;l!==null;)so(l.alternate,l),l=l.return;F=null}}function Me(l,t){l.finishedWork=null,l.finishedLanes=0;var a=l.timeoutHandle;a!==-1&&(l.timeoutHandle=-1,b1(a)),a=l.cancelPendingCommit,a!==null&&(l.cancelPendingCommit=null,a()),Cc(),vl=l,F=a=ga(l.current,null),tl=t,yl=0,et=null,wt=!1,Ae=Ye(l,t),xc=!1,Oe=mt=Uc=wa=ba=El=0,Nt=bu=null,Rc=!1,t&8&&(t|=t&32);var e=l.entangledLanes;if(e!==0)for(l=l.entanglements,e&=t;0<e;){var u=31-Il(e),n=1<<u;t|=l[u],e&=~n}return Jt=t,ln(),a}function vo(l,t){$=null,X.H=_t,t===Ie?(t=_s(),yl=3):t===Os?(t=_s(),yl=4):yl=t===Mr?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,et=t,F===null&&(El=1,En(l,st(t,l.current)))}function yo(){var l=X.H;return X.H=_t,l===null?_t:l}function mo(){var l=X.A;return X.A=F0,l}function Gc(){El=4,wt||(tl&4194176)!==tl&&dt.current!==null||(Ae=!0),!(ba&134217727)&&!(wa&134217727)||vl===null||kt(vl,tl,mt,!1)}function Xc(l,t,a){var e=Sl;Sl|=2;var u=yo(),n=mo();(vl!==l||tl!==t)&&(Nn=null,Me(l,t)),t=!1;var i=El;l:do try{if(yl!==0&&F!==null){var c=F,s=et;switch(yl){case 8:Cc(),i=6;break l;case 3:case 2:case 6:dt.current===null&&(t=!0);var h=yl;if(yl=0,et=null,De(l,c,s,h),a&&Ae){i=0;break l}break;default:h=yl,yl=0,et=null,De(l,c,s,h)}}l1(),i=El;break}catch(T){vo(l,T)}while(!0);return t&&l.shellSuspendCounter++,Xt=Za=null,Sl=e,X.H=u,X.A=n,F===null&&(vl=null,tl=0,ln()),i}function l1(){for(;F!==null;)go(F)}function t1(l,t){var a=Sl;Sl|=2;var e=yo(),u=mo();vl!==l||tl!==t?(Nn=null,_n=Ot()+500,Me(l,t)):Ae=Ye(l,t);l:do try{if(yl!==0&&F!==null){t=F;var n=et;t:switch(yl){case 1:yl=0,et=null,De(l,t,n,1);break;case 2:if(Ms(n)){yl=0,et=null,bo(t);break}t=function(){yl===2&&vl===l&&(yl=7),xt(l)},n.then(t,t);break l;case 3:yl=7;break l;case 4:yl=5;break l;case 7:Ms(n)?(yl=0,et=null,bo(t)):(yl=0,et=null,De(l,t,n,7));break;case 5:var i=null;switch(F.tag){case 26:i=F.memoizedState;case 5:case 27:var c=F;if(!i||Jo(i)){yl=0,et=null;var s=c.sibling;if(s!==null)F=s;else{var h=c.return;h!==null?(F=h,Rn(h)):F=null}break t}}yl=0,et=null,De(l,t,n,5);break;case 6:yl=0,et=null,De(l,t,n,6);break;case 8:Cc(),El=6;break l;default:throw Error(r(462))}}a1();break}catch(T){vo(l,T)}while(!0);return Xt=Za=null,X.H=e,X.A=u,Sl=a,F!==null?0:(vl=null,tl=0,ln(),El)}function a1(){for(;F!==null&&!Ad();)go(F)}function go(l){var t=Cr(l.alternate,l,Jt);l.memoizedProps=l.pendingProps,t===null?Rn(l):F=t}function bo(l){var t=l,a=t.alternate;switch(t.tag){case 15:case 0:t=Rr(a,t,t.pendingProps,t.type,void 0,tl);break;case 11:t=Rr(a,t,t.pendingProps,t.type.render,t.ref,tl);break;case 5:Li(t);default:so(a,t),t=F=io(t,Jt),t=Cr(a,t,Jt)}l.memoizedProps=l.pendingProps,t===null?Rn(l):F=t}function De(l,t,a,e){Xt=Za=null,Li(t),ve=null,tu=0;var u=t.return;try{if(L0(l,u,t,a,tl)){El=1,En(l,st(a,l.current)),F=null;return}}catch(n){if(u!==null)throw F=u,n;El=1,En(l,st(a,l.current)),F=null;return}t.flags&32768?(ul||e===1?l=!0:Ae||tl&536870912?l=!1:(wt=l=!0,(e===2||e===3||e===6)&&(e=dt.current,e!==null&&e.tag===13&&(e.flags|=16384))),So(t,l)):Rn(t)}function Rn(l){var t=l;do{if(t.flags&32768){So(t,wt);return}l=t.return;var a=$0(t.alternate,t,Jt);if(a!==null){F=a;return}if(t=t.sibling,t!==null){F=t;return}F=t=l}while(t!==null);El===0&&(El=5)}function So(l,t){do{var a=W0(l.alternate,l);if(a!==null){a.flags&=32767,F=a;return}if(a=l.return,a!==null&&(a.flags|=32768,a.subtreeFlags=0,a.deletions=null),!t&&(l=l.sibling,l!==null)){F=l;return}F=l=a}while(l!==null);El=6,F=null}function po(l,t,a,e,u,n,i,c,s,h){var T=X.T,M=H.p;try{H.p=2,X.T=null,e1(l,t,a,e,M,u,n,i,c,s,h)}finally{X.T=T,H.p=M}}function e1(l,t,a,e,u,n,i,c){do _e();while(Ja!==null);if(Sl&6)throw Error(r(327));var s=l.finishedWork;if(e=l.finishedLanes,s===null)return null;if(l.finishedWork=null,l.finishedLanes=0,s===l.current)throw Error(r(177));l.callbackNode=null,l.callbackPriority=0,l.cancelPendingCommit=null;var h=s.lanes|s.childLanes;if(h|=Ni,qd(l,e,h,n,i,c),l===vl&&(F=vl=null,tl=0),!(s.subtreeFlags&10256)&&!(s.flags&10256)||xn||(xn=!0,jc=h,qc=a,c1(Gu,function(){return _e(),null})),a=(s.flags&15990)!==0,s.subtreeFlags&15990||a?(a=X.T,X.T=null,n=H.p,H.p=2,i=Sl,Sl|=4,w0(l,s),Ir(s,l),D0(Pc,l.containerInfo),Ln=!!Fc,Pc=Fc=null,l.current=s,$r(l,s.alternate,s),Od(),Sl=i,H.p=n,X.T=a):l.current=s,xn?(xn=!1,Ja=l,Su=e):Eo(l,h),h=l.pendingLanes,h===0&&(Sa=null),xd(s.stateNode),xt(l),t!==null)for(u=l.onRecoverableError,s=0;s<t.length;s++)h=t[s],u(h.value,{componentStack:h.stack});return Su&3&&_e(),h=l.pendingLanes,e&4194218&&h&42?l===Bc?pu++:(pu=0,Bc=l):pu=0,Eu(0),null}function Eo(l,t){(l.pooledCacheLanes&=t)===0&&(t=l.pooledCache,t!=null&&(l.pooledCache=null,eu(t)))}function _e(){if(Ja!==null){var l=Ja,t=jc;jc=0;var a=Nf(Su),e=X.T,u=H.p;try{if(H.p=32>a?32:a,X.T=null,Ja===null)var n=!1;else{a=qc,qc=null;var i=Ja,c=Su;if(Ja=null,Su=0,Sl&6)throw Error(r(331));var s=Sl;if(Sl|=4,uo(i.current),to(i,i.current,c,a),Sl=s,Eu(0,!1),Pl&&typeof Pl.onPostCommitFiberRoot=="function")try{Pl.onPostCommitFiberRoot(Be,i)}catch{}n=!0}return n}finally{H.p=u,X.T=e,Eo(l,t)}}return!1}function To(l,t,a){t=st(a,t),t=uc(l.stateNode,t,2),l=ha(l,t,2),l!==null&&(Ce(l,2),xt(l))}function dl(l,t,a){if(l.tag===3)To(l,l,a);else for(;t!==null;){if(t.tag===3){To(t,l,a);break}else if(t.tag===1){var e=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof e.componentDidCatch=="function"&&(Sa===null||!Sa.has(e))){l=st(a,l),a=Ar(2),e=ha(t,a,2),e!==null&&(Or(a,e,t,l),Ce(e,2),xt(e));break}}t=t.return}}function Qc(l,t,a){var e=l.pingCache;if(e===null){e=l.pingCache=new P0;var u=new Set;e.set(t,u)}else u=e.get(t),u===void 0&&(u=new Set,e.set(t,u));u.has(a)||(xc=!0,u.add(a),l=u1.bind(null,l,t,a),t.then(l,l))}function u1(l,t,a){var e=l.pingCache;e!==null&&e.delete(t),l.pingedLanes|=l.suspendedLanes&a,l.warmLanes&=~a,vl===l&&(tl&a)===a&&(El===4||El===3&&(tl&62914560)===tl&&300>Ot()-Hc?!(Sl&2)&&Me(l,0):Uc|=a,Oe===tl&&(Oe=0)),xt(l)}function zo(l,t){t===0&&(t=Mf()),l=na(l,t),l!==null&&(Ce(l,t),xt(l))}function n1(l){var t=l.memoizedState,a=0;t!==null&&(a=t.retryLane),zo(l,a)}function i1(l,t){var a=0;switch(l.tag){case 13:var e=l.stateNode,u=l.memoizedState;u!==null&&(a=u.retryLane);break;case 19:e=l.stateNode;break;case 22:e=l.stateNode._retryCache;break;default:throw Error(r(314))}e!==null&&e.delete(t),zo(l,a)}function c1(l,t){return ni(l,t)}var Hn=null,Ne=null,Zc=!1,jn=!1,Vc=!1,ka=0;function xt(l){l!==Ne&&l.next===null&&(Ne===null?Hn=Ne=l:Ne=Ne.next=l),jn=!0,Zc||(Zc=!0,s1(f1))}function Eu(l,t){if(!Vc&&jn){Vc=!0;do for(var a=!1,e=Hn;e!==null;){if(l!==0){var u=e.pendingLanes;if(u===0)var n=0;else{var i=e.suspendedLanes,c=e.pingedLanes;n=(1<<31-Il(42|l)+1)-1,n&=u&~(i&~c),n=n&201326677?n&201326677|1:n?n|2:0}n!==0&&(a=!0,Mo(e,n))}else n=tl,n=Zu(e,e===vl?n:0),!(n&3)||Ye(e,n)||(a=!0,Mo(e,n));e=e.next}while(a);Vc=!1}}function f1(){jn=Zc=!1;var l=0;ka!==0&&(g1()&&(l=ka),ka=0);for(var t=Ot(),a=null,e=Hn;e!==null;){var u=e.next,n=Ao(e,t);n===0?(e.next=null,a===null?Hn=u:a.next=u,u===null&&(Ne=a)):(a=e,(l!==0||n&3)&&(jn=!0)),e=u}Eu(l)}function Ao(l,t){for(var a=l.suspendedLanes,e=l.pingedLanes,u=l.expirationTimes,n=l.pendingLanes&-62914561;0<n;){var i=31-Il(n),c=1<<i,s=u[i];s===-1?(!(c&a)||c&e)&&(u[i]=jd(c,t)):s<=t&&(l.expiredLanes|=c),n&=~c}if(t=vl,a=tl,a=Zu(l,l===t?a:0),e=l.callbackNode,a===0||l===t&&yl===2||l.cancelPendingCommit!==null)return e!==null&&e!==null&&ii(e),l.callbackNode=null,l.callbackPriority=0;if(!(a&3)||Ye(l,a)){if(t=a&-a,t===l.callbackPriority)return t;switch(e!==null&&ii(e),Nf(a)){case 2:case 8:a=zf;break;case 32:a=Gu;break;case 268435456:a=Af;break;default:a=Gu}return e=Oo.bind(null,l),a=ni(a,e),l.callbackPriority=t,l.callbackNode=a,t}return e!==null&&e!==null&&ii(e),l.callbackPriority=2,l.callbackNode=null,2}function Oo(l,t){var a=l.callbackNode;if(_e()&&l.callbackNode!==a)return null;var e=tl;return e=Zu(l,l===vl?e:0),e===0?null:(oo(l,e,t),Ao(l,Ot()),l.callbackNode!=null&&l.callbackNode===a?Oo.bind(null,l):null)}function Mo(l,t){if(_e())return null;oo(l,t,!0)}function s1(l){S1(function(){Sl&6?ni(Tf,l):l()})}function Lc(){return ka===0&&(ka=Of()),ka}function Do(l){return l==null||typeof l=="symbol"||typeof l=="boolean"?null:typeof l=="function"?l:Ju(""+l)}function _o(l,t){var a=t.ownerDocument.createElement("input");return a.name=t.name,a.value=t.value,l.id&&a.setAttribute("form",l.id),t.parentNode.insertBefore(a,t),l=new FormData(l),a.parentNode.removeChild(a),l}function r1(l,t,a,e,u){if(t==="submit"&&a&&a.stateNode===u){var n=Do((u[$l]||null).action),i=e.submitter;i&&(t=(t=i[$l]||null)?Do(t.formAction):i.getAttribute("formAction"),t!==null&&(n=t,i=null));var c=new Fu("action","action",null,e,u);l.push({event:c,listeners:[{instance:null,listener:function(){if(e.defaultPrevented){if(ka!==0){var s=i?_o(u,i):new FormData(u);Ii(a,{pending:!0,data:s,method:u.method,action:n},null,s)}}else typeof n=="function"&&(c.preventDefault(),s=i?_o(u,i):new FormData(u),Ii(a,{pending:!0,data:s,method:u.method,action:n},n,s))},currentTarget:u}]})}}for(var Kc=0;Kc<Ss.length;Kc++){var wc=Ss[Kc],o1=wc.toLowerCase(),d1=wc[0].toUpperCase()+wc.slice(1);St(o1,"on"+d1)}St(vs,"onAnimationEnd"),St(ys,"onAnimationIteration"),St(ms,"onAnimationStart"),St("dblclick","onDoubleClick"),St("focusin","onFocus"),St("focusout","onBlur"),St(N0,"onTransitionRun"),St(x0,"onTransitionStart"),St(U0,"onTransitionCancel"),St(gs,"onTransitionEnd"),ae("onMouseEnter",["mouseout","mouseover"]),ae("onMouseLeave",["mouseout","mouseover"]),ae("onPointerEnter",["pointerout","pointerover"]),ae("onPointerLeave",["pointerout","pointerover"]),Na("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),Na("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),Na("onBeforeInput",["compositionend","keypress","textInput","paste"]),Na("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),Na("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),Na("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var Tu="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),h1=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(Tu));function No(l,t){t=(t&4)!==0;for(var a=0;a<l.length;a++){var e=l[a],u=e.event;e=e.listeners;l:{var n=void 0;if(t)for(var i=e.length-1;0<=i;i--){var c=e[i],s=c.instance,h=c.currentTarget;if(c=c.listener,s!==n&&u.isPropagationStopped())break l;n=c,u.currentTarget=h;try{n(u)}catch(T){pn(T)}u.currentTarget=null,n=s}else for(i=0;i<e.length;i++){if(c=e[i],s=c.instance,h=c.currentTarget,c=c.listener,s!==n&&u.isPropagationStopped())break l;n=c,u.currentTarget=h;try{n(u)}catch(T){pn(T)}u.currentTarget=null,n=s}}}}function I(l,t){var a=t[fi];a===void 0&&(a=t[fi]=new Set);var e=l+"__bubble";a.has(e)||(xo(t,l,2,!1),a.add(e))}function Jc(l,t,a){var e=0;t&&(e|=4),xo(a,l,e,t)}var qn="_reactListening"+Math.random().toString(36).slice(2);function kc(l){if(!l[qn]){l[qn]=!0,Rf.forEach(function(a){a!=="selectionchange"&&(h1.has(a)||Jc(a,!1,l),Jc(a,!0,l))});var t=l.nodeType===9?l:l.ownerDocument;t===null||t[qn]||(t[qn]=!0,Jc("selectionchange",!1,t))}}function xo(l,t,a,e){switch(Io(t)){case 2:var u=G1;break;case 8:u=X1;break;default:u=ff}a=u.bind(null,t,a,l),u=void 0,!mi||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(u=!0),e?u!==void 0?l.addEventListener(t,a,{capture:!0,passive:u}):l.addEventListener(t,a,!0):u!==void 0?l.addEventListener(t,a,{passive:u}):l.addEventListener(t,a,!1)}function $c(l,t,a,e,u){var n=e;if(!(t&1)&&!(t&2)&&e!==null)l:for(;;){if(e===null)return;var i=e.tag;if(i===3||i===4){var c=e.stateNode.containerInfo;if(c===u||c.nodeType===8&&c.parentNode===u)break;if(i===4)for(i=e.return;i!==null;){var s=i.tag;if((s===3||s===4)&&(s=i.stateNode.containerInfo,s===u||s.nodeType===8&&s.parentNode===u))return;i=i.return}for(;c!==null;){if(i=_a(c),i===null)return;if(s=i.tag,s===5||s===6||s===26||s===27){e=n=i;continue l}c=c.parentNode}}e=e.return}Lf(function(){var h=n,T=vi(a),M=[];l:{var g=bs.get(l);if(g!==void 0){var E=Fu,q=l;switch(l){case"keypress":if($u(a)===0)break l;case"keydown":case"keyup":E=i0;break;case"focusin":q="focus",E=pi;break;case"focusout":q="blur",E=pi;break;case"beforeblur":case"afterblur":E=pi;break;case"click":if(a.button===2)break l;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":E=Jf;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":E=kd;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":E=s0;break;case vs:case ys:case ms:E=Fd;break;case gs:E=o0;break;case"scroll":case"scrollend":E=wd;break;case"wheel":E=h0;break;case"copy":case"cut":case"paste":E=Id;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":E=$f;break;case"toggle":case"beforetoggle":E=y0}var V=(t&4)!==0,Tl=!V&&(l==="scroll"||l==="scrollend"),v=V?g!==null?g+"Capture":null:g;V=[];for(var d=h,y;d!==null;){var z=d;if(y=z.stateNode,z=z.tag,z!==5&&z!==26&&z!==27||y===null||v===null||(z=Qe(d,v),z!=null&&V.push(zu(d,z,y))),Tl)break;d=d.return}0<V.length&&(g=new E(g,q,null,a,T),M.push({event:g,listeners:V}))}}if(!(t&7)){l:{if(g=l==="mouseover"||l==="pointerover",E=l==="mouseout"||l==="pointerout",g&&a!==hi&&(q=a.relatedTarget||a.fromElement)&&(_a(q)||q[Ia]))break l;if((E||g)&&(g=T.window===T?T:(g=T.ownerDocument)?g.defaultView||g.parentWindow:window,E?(q=a.relatedTarget||a.toElement,E=h,q=q?_a(q):null,q!==null&&(Tl=Z(q),V=q.tag,q!==Tl||V!==5&&V!==27&&V!==6)&&(q=null)):(E=null,q=h),E!==q)){if(V=Jf,z="onMouseLeave",v="onMouseEnter",d="mouse",(l==="pointerout"||l==="pointerover")&&(V=$f,z="onPointerLeave",v="onPointerEnter",d="pointer"),Tl=E==null?g:Xe(E),y=q==null?g:Xe(q),g=new V(z,d+"leave",E,a,T),g.target=Tl,g.relatedTarget=y,z=null,_a(T)===h&&(V=new V(v,d+"enter",q,a,T),V.target=y,V.relatedTarget=Tl,z=V),Tl=z,E&&q)t:{for(V=E,v=q,d=0,y=V;y;y=xe(y))d++;for(y=0,z=v;z;z=xe(z))y++;for(;0<d-y;)V=xe(V),d--;for(;0<y-d;)v=xe(v),y--;for(;d--;){if(V===v||v!==null&&V===v.alternate)break t;V=xe(V),v=xe(v)}V=null}else V=null;E!==null&&Uo(M,g,E,V,!1),q!==null&&Tl!==null&&Uo(M,Tl,q,V,!0)}}l:{if(g=h?Xe(h):window,E=g.nodeName&&g.nodeName.toLowerCase(),E==="select"||E==="input"&&g.type==="file")var j=es;else if(ts(g))if(us)j=O0;else{j=z0;var W=T0}else E=g.nodeName,!E||E.toLowerCase()!=="input"||g.type!=="checkbox"&&g.type!=="radio"?h&&di(h.elementType)&&(j=es):j=A0;if(j&&(j=j(l,h))){as(M,j,a,T);break l}W&&W(l,g,h),l==="focusout"&&h&&g.type==="number"&&h.memoizedProps.value!=null&&oi(g,"number",g.value)}switch(W=h?Xe(h):window,l){case"focusin":(ts(W)||W.contentEditable==="true")&&(fe=W,Mi=h,$e=null);break;case"focusout":$e=Mi=fe=null;break;case"mousedown":Di=!0;break;case"contextmenu":case"mouseup":case"dragend":Di=!1,ds(M,a,T);break;case"selectionchange":if(_0)break;case"keydown":case"keyup":ds(M,a,T)}var B;if(Ti)l:{switch(l){case"compositionstart":var G="onCompositionStart";break l;case"compositionend":G="onCompositionEnd";break l;case"compositionupdate":G="onCompositionUpdate";break l}G=void 0}else ce?If(l,a)&&(G="onCompositionEnd"):l==="keydown"&&a.keyCode===229&&(G="onCompositionStart");G&&(Wf&&a.locale!=="ko"&&(ce||G!=="onCompositionStart"?G==="onCompositionEnd"&&ce&&(B=Kf()):(ua=T,gi="value"in ua?ua.value:ua.textContent,ce=!0)),W=Bn(h,G),0<W.length&&(G=new kf(G,l,null,a,T),M.push({event:G,listeners:W}),B?G.data=B:(B=ls(a),B!==null&&(G.data=B)))),(B=g0?b0(l,a):S0(l,a))&&(G=Bn(h,"onBeforeInput"),0<G.length&&(W=new kf("onBeforeInput","beforeinput",null,a,T),M.push({event:W,listeners:G}),W.data=B)),r1(M,l,h,a,T)}No(M,t)})}function zu(l,t,a){return{instance:l,listener:t,currentTarget:a}}function Bn(l,t){for(var a=t+"Capture",e=[];l!==null;){var u=l,n=u.stateNode;u=u.tag,u!==5&&u!==26&&u!==27||n===null||(u=Qe(l,a),u!=null&&e.unshift(zu(l,u,n)),u=Qe(l,t),u!=null&&e.push(zu(l,u,n))),l=l.return}return e}function xe(l){if(l===null)return null;do l=l.return;while(l&&l.tag!==5&&l.tag!==27);return l||null}function Uo(l,t,a,e,u){for(var n=t._reactName,i=[];a!==null&&a!==e;){var c=a,s=c.alternate,h=c.stateNode;if(c=c.tag,s!==null&&s===e)break;c!==5&&c!==26&&c!==27||h===null||(s=h,u?(h=Qe(a,n),h!=null&&i.unshift(zu(a,h,s))):u||(h=Qe(a,n),h!=null&&i.push(zu(a,h,s)))),a=a.return}i.length!==0&&l.push({event:t,listeners:i})}var v1=/\r\n?/g,y1=/\u0000|\uFFFD/g;function Ro(l){return(typeof l=="string"?l:""+l).replace(v1,`
`).replace(y1,"")}function Ho(l,t){return t=Ro(t),Ro(l)===t}function Yn(){}function ol(l,t,a,e,u,n){switch(a){case"children":typeof e=="string"?t==="body"||t==="textarea"&&e===""||ue(l,e):(typeof e=="number"||typeof e=="bigint")&&t!=="body"&&ue(l,""+e);break;case"className":Lu(l,"class",e);break;case"tabIndex":Lu(l,"tabindex",e);break;case"dir":case"role":case"viewBox":case"width":case"height":Lu(l,a,e);break;case"style":Zf(l,e,n);break;case"data":if(t!=="object"){Lu(l,"data",e);break}case"src":case"href":if(e===""&&(t!=="a"||a!=="href")){l.removeAttribute(a);break}if(e==null||typeof e=="function"||typeof e=="symbol"||typeof e=="boolean"){l.removeAttribute(a);break}e=Ju(""+e),l.setAttribute(a,e);break;case"action":case"formAction":if(typeof e=="function"){l.setAttribute(a,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof n=="function"&&(a==="formAction"?(t!=="input"&&ol(l,t,"name",u.name,u,null),ol(l,t,"formEncType",u.formEncType,u,null),ol(l,t,"formMethod",u.formMethod,u,null),ol(l,t,"formTarget",u.formTarget,u,null)):(ol(l,t,"encType",u.encType,u,null),ol(l,t,"method",u.method,u,null),ol(l,t,"target",u.target,u,null)));if(e==null||typeof e=="symbol"||typeof e=="boolean"){l.removeAttribute(a);break}e=Ju(""+e),l.setAttribute(a,e);break;case"onClick":e!=null&&(l.onclick=Yn);break;case"onScroll":e!=null&&I("scroll",l);break;case"onScrollEnd":e!=null&&I("scrollend",l);break;case"dangerouslySetInnerHTML":if(e!=null){if(typeof e!="object"||!("__html"in e))throw Error(r(61));if(a=e.__html,a!=null){if(u.children!=null)throw Error(r(60));l.innerHTML=a}}break;case"multiple":l.multiple=e&&typeof e!="function"&&typeof e!="symbol";break;case"muted":l.muted=e&&typeof e!="function"&&typeof e!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(e==null||typeof e=="function"||typeof e=="boolean"||typeof e=="symbol"){l.removeAttribute("xlink:href");break}a=Ju(""+e),l.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",a);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":e!=null&&typeof e!="function"&&typeof e!="symbol"?l.setAttribute(a,""+e):l.removeAttribute(a);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":e&&typeof e!="function"&&typeof e!="symbol"?l.setAttribute(a,""):l.removeAttribute(a);break;case"capture":case"download":e===!0?l.setAttribute(a,""):e!==!1&&e!=null&&typeof e!="function"&&typeof e!="symbol"?l.setAttribute(a,e):l.removeAttribute(a);break;case"cols":case"rows":case"size":case"span":e!=null&&typeof e!="function"&&typeof e!="symbol"&&!isNaN(e)&&1<=e?l.setAttribute(a,e):l.removeAttribute(a);break;case"rowSpan":case"start":e==null||typeof e=="function"||typeof e=="symbol"||isNaN(e)?l.removeAttribute(a):l.setAttribute(a,e);break;case"popover":I("beforetoggle",l),I("toggle",l),Vu(l,"popover",e);break;case"xlinkActuate":jt(l,"http://www.w3.org/1999/xlink","xlink:actuate",e);break;case"xlinkArcrole":jt(l,"http://www.w3.org/1999/xlink","xlink:arcrole",e);break;case"xlinkRole":jt(l,"http://www.w3.org/1999/xlink","xlink:role",e);break;case"xlinkShow":jt(l,"http://www.w3.org/1999/xlink","xlink:show",e);break;case"xlinkTitle":jt(l,"http://www.w3.org/1999/xlink","xlink:title",e);break;case"xlinkType":jt(l,"http://www.w3.org/1999/xlink","xlink:type",e);break;case"xmlBase":jt(l,"http://www.w3.org/XML/1998/namespace","xml:base",e);break;case"xmlLang":jt(l,"http://www.w3.org/XML/1998/namespace","xml:lang",e);break;case"xmlSpace":jt(l,"http://www.w3.org/XML/1998/namespace","xml:space",e);break;case"is":Vu(l,"is",e);break;case"innerText":case"textContent":break;default:(!(2<a.length)||a[0]!=="o"&&a[0]!=="O"||a[1]!=="n"&&a[1]!=="N")&&(a=Ld.get(a)||a,Vu(l,a,e))}}function Wc(l,t,a,e,u,n){switch(a){case"style":Zf(l,e,n);break;case"dangerouslySetInnerHTML":if(e!=null){if(typeof e!="object"||!("__html"in e))throw Error(r(61));if(a=e.__html,a!=null){if(u.children!=null)throw Error(r(60));l.innerHTML=a}}break;case"children":typeof e=="string"?ue(l,e):(typeof e=="number"||typeof e=="bigint")&&ue(l,""+e);break;case"onScroll":e!=null&&I("scroll",l);break;case"onScrollEnd":e!=null&&I("scrollend",l);break;case"onClick":e!=null&&(l.onclick=Yn);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!Hf.hasOwnProperty(a))l:{if(a[0]==="o"&&a[1]==="n"&&(u=a.endsWith("Capture"),t=a.slice(2,u?a.length-7:void 0),n=l[$l]||null,n=n!=null?n[a]:null,typeof n=="function"&&l.removeEventListener(t,n,u),typeof e=="function")){typeof n!="function"&&n!==null&&(a in l?l[a]=null:l.hasAttribute(a)&&l.removeAttribute(a)),l.addEventListener(t,e,u);break l}a in l?l[a]=e:e===!0?l.setAttribute(a,""):Vu(l,a,e)}}}function Yl(l,t,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":I("error",l),I("load",l);var e=!1,u=!1,n;for(n in a)if(a.hasOwnProperty(n)){var i=a[n];if(i!=null)switch(n){case"src":e=!0;break;case"srcSet":u=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(r(137,t));default:ol(l,t,n,i,a,null)}}u&&ol(l,t,"srcSet",a.srcSet,a,null),e&&ol(l,t,"src",a.src,a,null);return;case"input":I("invalid",l);var c=n=i=u=null,s=null,h=null;for(e in a)if(a.hasOwnProperty(e)){var T=a[e];if(T!=null)switch(e){case"name":u=T;break;case"type":i=T;break;case"checked":s=T;break;case"defaultChecked":h=T;break;case"value":n=T;break;case"defaultValue":c=T;break;case"children":case"dangerouslySetInnerHTML":if(T!=null)throw Error(r(137,t));break;default:ol(l,t,e,T,a,null)}}Cf(l,n,c,s,h,i,u,!1),Ku(l);return;case"select":I("invalid",l),e=i=n=null;for(u in a)if(a.hasOwnProperty(u)&&(c=a[u],c!=null))switch(u){case"value":n=c;break;case"defaultValue":i=c;break;case"multiple":e=c;default:ol(l,t,u,c,a,null)}t=n,a=i,l.multiple=!!e,t!=null?ee(l,!!e,t,!1):a!=null&&ee(l,!!e,a,!0);return;case"textarea":I("invalid",l),n=u=e=null;for(i in a)if(a.hasOwnProperty(i)&&(c=a[i],c!=null))switch(i){case"value":e=c;break;case"defaultValue":u=c;break;case"children":n=c;break;case"dangerouslySetInnerHTML":if(c!=null)throw Error(r(91));break;default:ol(l,t,i,c,a,null)}Xf(l,e,u,n),Ku(l);return;case"option":for(s in a)if(a.hasOwnProperty(s)&&(e=a[s],e!=null))switch(s){case"selected":l.selected=e&&typeof e!="function"&&typeof e!="symbol";break;default:ol(l,t,s,e,a,null)}return;case"dialog":I("cancel",l),I("close",l);break;case"iframe":case"object":I("load",l);break;case"video":case"audio":for(e=0;e<Tu.length;e++)I(Tu[e],l);break;case"image":I("error",l),I("load",l);break;case"details":I("toggle",l);break;case"embed":case"source":case"link":I("error",l),I("load",l);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(h in a)if(a.hasOwnProperty(h)&&(e=a[h],e!=null))switch(h){case"children":case"dangerouslySetInnerHTML":throw Error(r(137,t));default:ol(l,t,h,e,a,null)}return;default:if(di(t)){for(T in a)a.hasOwnProperty(T)&&(e=a[T],e!==void 0&&Wc(l,t,T,e,a,void 0));return}}for(c in a)a.hasOwnProperty(c)&&(e=a[c],e!=null&&ol(l,t,c,e,a,null))}function m1(l,t,a,e){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var u=null,n=null,i=null,c=null,s=null,h=null,T=null;for(E in a){var M=a[E];if(a.hasOwnProperty(E)&&M!=null)switch(E){case"checked":break;case"value":break;case"defaultValue":s=M;default:e.hasOwnProperty(E)||ol(l,t,E,null,e,M)}}for(var g in e){var E=e[g];if(M=a[g],e.hasOwnProperty(g)&&(E!=null||M!=null))switch(g){case"type":n=E;break;case"name":u=E;break;case"checked":h=E;break;case"defaultChecked":T=E;break;case"value":i=E;break;case"defaultValue":c=E;break;case"children":case"dangerouslySetInnerHTML":if(E!=null)throw Error(r(137,t));break;default:E!==M&&ol(l,t,g,E,e,M)}}ri(l,i,c,s,h,T,n,u);return;case"select":E=i=c=g=null;for(n in a)if(s=a[n],a.hasOwnProperty(n)&&s!=null)switch(n){case"value":break;case"multiple":E=s;default:e.hasOwnProperty(n)||ol(l,t,n,null,e,s)}for(u in e)if(n=e[u],s=a[u],e.hasOwnProperty(u)&&(n!=null||s!=null))switch(u){case"value":g=n;break;case"defaultValue":c=n;break;case"multiple":i=n;default:n!==s&&ol(l,t,u,n,e,s)}t=c,a=i,e=E,g!=null?ee(l,!!a,g,!1):!!e!=!!a&&(t!=null?ee(l,!!a,t,!0):ee(l,!!a,a?[]:"",!1));return;case"textarea":E=g=null;for(c in a)if(u=a[c],a.hasOwnProperty(c)&&u!=null&&!e.hasOwnProperty(c))switch(c){case"value":break;case"children":break;default:ol(l,t,c,null,e,u)}for(i in e)if(u=e[i],n=a[i],e.hasOwnProperty(i)&&(u!=null||n!=null))switch(i){case"value":g=u;break;case"defaultValue":E=u;break;case"children":break;case"dangerouslySetInnerHTML":if(u!=null)throw Error(r(91));break;default:u!==n&&ol(l,t,i,u,e,n)}Gf(l,g,E);return;case"option":for(var q in a)if(g=a[q],a.hasOwnProperty(q)&&g!=null&&!e.hasOwnProperty(q))switch(q){case"selected":l.selected=!1;break;default:ol(l,t,q,null,e,g)}for(s in e)if(g=e[s],E=a[s],e.hasOwnProperty(s)&&g!==E&&(g!=null||E!=null))switch(s){case"selected":l.selected=g&&typeof g!="function"&&typeof g!="symbol";break;default:ol(l,t,s,g,e,E)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var V in a)g=a[V],a.hasOwnProperty(V)&&g!=null&&!e.hasOwnProperty(V)&&ol(l,t,V,null,e,g);for(h in e)if(g=e[h],E=a[h],e.hasOwnProperty(h)&&g!==E&&(g!=null||E!=null))switch(h){case"children":case"dangerouslySetInnerHTML":if(g!=null)throw Error(r(137,t));break;default:ol(l,t,h,g,e,E)}return;default:if(di(t)){for(var Tl in a)g=a[Tl],a.hasOwnProperty(Tl)&&g!==void 0&&!e.hasOwnProperty(Tl)&&Wc(l,t,Tl,void 0,e,g);for(T in e)g=e[T],E=a[T],!e.hasOwnProperty(T)||g===E||g===void 0&&E===void 0||Wc(l,t,T,g,e,E);return}}for(var v in a)g=a[v],a.hasOwnProperty(v)&&g!=null&&!e.hasOwnProperty(v)&&ol(l,t,v,null,e,g);for(M in e)g=e[M],E=a[M],!e.hasOwnProperty(M)||g===E||g==null&&E==null||ol(l,t,M,g,e,E)}var Fc=null,Pc=null;function Cn(l){return l.nodeType===9?l:l.ownerDocument}function jo(l){switch(l){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function qo(l,t){if(l===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return l===1&&t==="foreignObject"?0:l}function Ic(l,t){return l==="textarea"||l==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var lf=null;function g1(){var l=window.event;return l&&l.type==="popstate"?l===lf?!1:(lf=l,!0):(lf=null,!1)}var Bo=typeof setTimeout=="function"?setTimeout:void 0,b1=typeof clearTimeout=="function"?clearTimeout:void 0,Yo=typeof Promise=="function"?Promise:void 0,S1=typeof queueMicrotask=="function"?queueMicrotask:typeof Yo<"u"?function(l){return Yo.resolve(null).then(l).catch(p1)}:Bo;function p1(l){setTimeout(function(){throw l})}function tf(l,t){var a=t,e=0;do{var u=a.nextSibling;if(l.removeChild(a),u&&u.nodeType===8)if(a=u.data,a==="/$"){if(e===0){l.removeChild(u),Uu(t);return}e--}else a!=="$"&&a!=="$?"&&a!=="$!"||e++;a=u}while(a);Uu(t)}function af(l){var t=l.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var a=t;switch(t=t.nextSibling,a.nodeName){case"HTML":case"HEAD":case"BODY":af(a),si(a);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(a.rel.toLowerCase()==="stylesheet")continue}l.removeChild(a)}}function E1(l,t,a,e){for(;l.nodeType===1;){var u=a;if(l.nodeName.toLowerCase()!==t.toLowerCase()){if(!e&&(l.nodeName!=="INPUT"||l.type!=="hidden"))break}else if(e){if(!l[Ge])switch(t){case"meta":if(!l.hasAttribute("itemprop"))break;return l;case"link":if(n=l.getAttribute("rel"),n==="stylesheet"&&l.hasAttribute("data-precedence"))break;if(n!==u.rel||l.getAttribute("href")!==(u.href==null?null:u.href)||l.getAttribute("crossorigin")!==(u.crossOrigin==null?null:u.crossOrigin)||l.getAttribute("title")!==(u.title==null?null:u.title))break;return l;case"style":if(l.hasAttribute("data-precedence"))break;return l;case"script":if(n=l.getAttribute("src"),(n!==(u.src==null?null:u.src)||l.getAttribute("type")!==(u.type==null?null:u.type)||l.getAttribute("crossorigin")!==(u.crossOrigin==null?null:u.crossOrigin))&&n&&l.hasAttribute("async")&&!l.hasAttribute("itemprop"))break;return l;default:return l}}else if(t==="input"&&l.type==="hidden"){var n=u.name==null?null:""+u.name;if(u.type==="hidden"&&l.getAttribute("name")===n)return l}else return l;if(l=Tt(l.nextSibling),l===null)break}return null}function T1(l,t,a){if(t==="")return null;for(;l.nodeType!==3;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!a||(l=Tt(l.nextSibling),l===null))return null;return l}function Tt(l){for(;l!=null;l=l.nextSibling){var t=l.nodeType;if(t===1||t===3)break;if(t===8){if(t=l.data,t==="$"||t==="$!"||t==="$?"||t==="F!"||t==="F")break;if(t==="/$")return null}}return l}function Co(l){l=l.previousSibling;for(var t=0;l;){if(l.nodeType===8){var a=l.data;if(a==="$"||a==="$!"||a==="$?"){if(t===0)return l;t--}else a==="/$"&&t++}l=l.previousSibling}return null}function Go(l,t,a){switch(t=Cn(a),l){case"html":if(l=t.documentElement,!l)throw Error(r(452));return l;case"head":if(l=t.head,!l)throw Error(r(453));return l;case"body":if(l=t.body,!l)throw Error(r(454));return l;default:throw Error(r(451))}}var gt=new Map,Xo=new Set;function Gn(l){return typeof l.getRootNode=="function"?l.getRootNode():l.ownerDocument}var $t=H.d;H.d={f:z1,r:A1,D:O1,C:M1,L:D1,m:_1,X:x1,S:N1,M:U1};function z1(){var l=$t.f(),t=Un();return l||t}function A1(l){var t=le(l);t!==null&&t.tag===5&&t.type==="form"?dr(t):$t.r(l)}var Ue=typeof document>"u"?null:document;function Qo(l,t,a){var e=Ue;if(e&&typeof t=="string"&&t){var u=ct(t);u='link[rel="'+l+'"][href="'+u+'"]',typeof a=="string"&&(u+='[crossorigin="'+a+'"]'),Xo.has(u)||(Xo.add(u),l={rel:l,crossOrigin:a,href:t},e.querySelector(u)===null&&(t=e.createElement("link"),Yl(t,"link",l),Ul(t),e.head.appendChild(t)))}}function O1(l){$t.D(l),Qo("dns-prefetch",l,null)}function M1(l,t){$t.C(l,t),Qo("preconnect",l,t)}function D1(l,t,a){$t.L(l,t,a);var e=Ue;if(e&&l&&t){var u='link[rel="preload"][as="'+ct(t)+'"]';t==="image"&&a&&a.imageSrcSet?(u+='[imagesrcset="'+ct(a.imageSrcSet)+'"]',typeof a.imageSizes=="string"&&(u+='[imagesizes="'+ct(a.imageSizes)+'"]')):u+='[href="'+ct(l)+'"]';var n=u;switch(t){case"style":n=Re(l);break;case"script":n=He(l)}gt.has(n)||(l=cl({rel:"preload",href:t==="image"&&a&&a.imageSrcSet?void 0:l,as:t},a),gt.set(n,l),e.querySelector(u)!==null||t==="style"&&e.querySelector(Au(n))||t==="script"&&e.querySelector(Ou(n))||(t=e.createElement("link"),Yl(t,"link",l),Ul(t),e.head.appendChild(t)))}}function _1(l,t){$t.m(l,t);var a=Ue;if(a&&l){var e=t&&typeof t.as=="string"?t.as:"script",u='link[rel="modulepreload"][as="'+ct(e)+'"][href="'+ct(l)+'"]',n=u;switch(e){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":n=He(l)}if(!gt.has(n)&&(l=cl({rel:"modulepreload",href:l},t),gt.set(n,l),a.querySelector(u)===null)){switch(e){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(a.querySelector(Ou(n)))return}e=a.createElement("link"),Yl(e,"link",l),Ul(e),a.head.appendChild(e)}}}function N1(l,t,a){$t.S(l,t,a);var e=Ue;if(e&&l){var u=te(e).hoistableStyles,n=Re(l);t=t||"default";var i=u.get(n);if(!i){var c={loading:0,preload:null};if(i=e.querySelector(Au(n)))c.loading=5;else{l=cl({rel:"stylesheet",href:l,"data-precedence":t},a),(a=gt.get(n))&&ef(l,a);var s=i=e.createElement("link");Ul(s),Yl(s,"link",l),s._p=new Promise(function(h,T){s.onload=h,s.onerror=T}),s.addEventListener("load",function(){c.loading|=1}),s.addEventListener("error",function(){c.loading|=2}),c.loading|=4,Xn(i,t,e)}i={type:"stylesheet",instance:i,count:1,state:c},u.set(n,i)}}}function x1(l,t){$t.X(l,t);var a=Ue;if(a&&l){var e=te(a).hoistableScripts,u=He(l),n=e.get(u);n||(n=a.querySelector(Ou(u)),n||(l=cl({src:l,async:!0},t),(t=gt.get(u))&&uf(l,t),n=a.createElement("script"),Ul(n),Yl(n,"link",l),a.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},e.set(u,n))}}function U1(l,t){$t.M(l,t);var a=Ue;if(a&&l){var e=te(a).hoistableScripts,u=He(l),n=e.get(u);n||(n=a.querySelector(Ou(u)),n||(l=cl({src:l,async:!0,type:"module"},t),(t=gt.get(u))&&uf(l,t),n=a.createElement("script"),Ul(n),Yl(n,"link",l),a.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},e.set(u,n))}}function Zo(l,t,a,e){var u=(u=ta.current)?Gn(u):null;if(!u)throw Error(r(446));switch(l){case"meta":case"title":return null;case"style":return typeof a.precedence=="string"&&typeof a.href=="string"?(t=Re(a.href),a=te(u).hoistableStyles,e=a.get(t),e||(e={type:"style",instance:null,count:0,state:null},a.set(t,e)),e):{type:"void",instance:null,count:0,state:null};case"link":if(a.rel==="stylesheet"&&typeof a.href=="string"&&typeof a.precedence=="string"){l=Re(a.href);var n=te(u).hoistableStyles,i=n.get(l);if(i||(u=u.ownerDocument||u,i={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},n.set(l,i),(n=u.querySelector(Au(l)))&&!n._p&&(i.instance=n,i.state.loading=5),gt.has(l)||(a={rel:"preload",as:"style",href:a.href,crossOrigin:a.crossOrigin,integrity:a.integrity,media:a.media,hrefLang:a.hrefLang,referrerPolicy:a.referrerPolicy},gt.set(l,a),n||R1(u,l,a,i.state))),t&&e===null)throw Error(r(528,""));return i}if(t&&e!==null)throw Error(r(529,""));return null;case"script":return t=a.async,a=a.src,typeof a=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=He(a),a=te(u).hoistableScripts,e=a.get(t),e||(e={type:"script",instance:null,count:0,state:null},a.set(t,e)),e):{type:"void",instance:null,count:0,state:null};default:throw Error(r(444,l))}}function Re(l){return'href="'+ct(l)+'"'}function Au(l){return'link[rel="stylesheet"]['+l+"]"}function Vo(l){return cl({},l,{"data-precedence":l.precedence,precedence:null})}function R1(l,t,a,e){l.querySelector('link[rel="preload"][as="style"]['+t+"]")?e.loading=1:(t=l.createElement("link"),e.preload=t,t.addEventListener("load",function(){return e.loading|=1}),t.addEventListener("error",function(){return e.loading|=2}),Yl(t,"link",a),Ul(t),l.head.appendChild(t))}function He(l){return'[src="'+ct(l)+'"]'}function Ou(l){return"script[async]"+l}function Lo(l,t,a){if(t.count++,t.instance===null)switch(t.type){case"style":var e=l.querySelector('style[data-href~="'+ct(a.href)+'"]');if(e)return t.instance=e,Ul(e),e;var u=cl({},a,{"data-href":a.href,"data-precedence":a.precedence,href:null,precedence:null});return e=(l.ownerDocument||l).createElement("style"),Ul(e),Yl(e,"style",u),Xn(e,a.precedence,l),t.instance=e;case"stylesheet":u=Re(a.href);var n=l.querySelector(Au(u));if(n)return t.state.loading|=4,t.instance=n,Ul(n),n;e=Vo(a),(u=gt.get(u))&&ef(e,u),n=(l.ownerDocument||l).createElement("link"),Ul(n);var i=n;return i._p=new Promise(function(c,s){i.onload=c,i.onerror=s}),Yl(n,"link",e),t.state.loading|=4,Xn(n,a.precedence,l),t.instance=n;case"script":return n=He(a.src),(u=l.querySelector(Ou(n)))?(t.instance=u,Ul(u),u):(e=a,(u=gt.get(n))&&(e=cl({},a),uf(e,u)),l=l.ownerDocument||l,u=l.createElement("script"),Ul(u),Yl(u,"link",e),l.head.appendChild(u),t.instance=u);case"void":return null;default:throw Error(r(443,t.type))}else t.type==="stylesheet"&&!(t.state.loading&4)&&(e=t.instance,t.state.loading|=4,Xn(e,a.precedence,l));return t.instance}function Xn(l,t,a){for(var e=a.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),u=e.length?e[e.length-1]:null,n=u,i=0;i<e.length;i++){var c=e[i];if(c.dataset.precedence===t)n=c;else if(n!==u)break}n?n.parentNode.insertBefore(l,n.nextSibling):(t=a.nodeType===9?a.head:a,t.insertBefore(l,t.firstChild))}function ef(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.title==null&&(l.title=t.title)}function uf(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.integrity==null&&(l.integrity=t.integrity)}var Qn=null;function Ko(l,t,a){if(Qn===null){var e=new Map,u=Qn=new Map;u.set(a,e)}else u=Qn,e=u.get(a),e||(e=new Map,u.set(a,e));if(e.has(l))return e;for(e.set(l,null),a=a.getElementsByTagName(l),u=0;u<a.length;u++){var n=a[u];if(!(n[Ge]||n[Cl]||l==="link"&&n.getAttribute("rel")==="stylesheet")&&n.namespaceURI!=="http://www.w3.org/2000/svg"){var i=n.getAttribute(t)||"";i=l+i;var c=e.get(i);c?c.push(n):e.set(i,[n])}}return e}function wo(l,t,a){l=l.ownerDocument||l,l.head.insertBefore(a,t==="title"?l.querySelector("head > title"):null)}function H1(l,t,a){if(a===1||t.itemProp!=null)return!1;switch(l){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return l=t.disabled,typeof t.precedence=="string"&&l==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function Jo(l){return!(l.type==="stylesheet"&&!(l.state.loading&3))}var Mu=null;function j1(){}function q1(l,t,a){if(Mu===null)throw Error(r(475));var e=Mu;if(t.type==="stylesheet"&&(typeof a.media!="string"||matchMedia(a.media).matches!==!1)&&!(t.state.loading&4)){if(t.instance===null){var u=Re(a.href),n=l.querySelector(Au(u));if(n){l=n._p,l!==null&&typeof l=="object"&&typeof l.then=="function"&&(e.count++,e=Zn.bind(e),l.then(e,e)),t.state.loading|=4,t.instance=n,Ul(n);return}n=l.ownerDocument||l,a=Vo(a),(u=gt.get(u))&&ef(a,u),n=n.createElement("link"),Ul(n);var i=n;i._p=new Promise(function(c,s){i.onload=c,i.onerror=s}),Yl(n,"link",a),t.instance=n}e.stylesheets===null&&(e.stylesheets=new Map),e.stylesheets.set(t,l),(l=t.state.preload)&&!(t.state.loading&3)&&(e.count++,t=Zn.bind(e),l.addEventListener("load",t),l.addEventListener("error",t))}}function B1(){if(Mu===null)throw Error(r(475));var l=Mu;return l.stylesheets&&l.count===0&&nf(l,l.stylesheets),0<l.count?function(t){var a=setTimeout(function(){if(l.stylesheets&&nf(l,l.stylesheets),l.unsuspend){var e=l.unsuspend;l.unsuspend=null,e()}},6e4);return l.unsuspend=t,function(){l.unsuspend=null,clearTimeout(a)}}:null}function Zn(){if(this.count--,this.count===0){if(this.stylesheets)nf(this,this.stylesheets);else if(this.unsuspend){var l=this.unsuspend;this.unsuspend=null,l()}}}var Vn=null;function nf(l,t){l.stylesheets=null,l.unsuspend!==null&&(l.count++,Vn=new Map,t.forEach(Y1,l),Vn=null,Zn.call(l))}function Y1(l,t){if(!(t.state.loading&4)){var a=Vn.get(l);if(a)var e=a.get(null);else{a=new Map,Vn.set(l,a);for(var u=l.querySelectorAll("link[data-precedence],style[data-precedence]"),n=0;n<u.length;n++){var i=u[n];(i.nodeName==="LINK"||i.getAttribute("media")!=="not all")&&(a.set(i.dataset.precedence,i),e=i)}e&&a.set(null,e)}u=t.instance,i=u.getAttribute("data-precedence"),n=a.get(i)||e,n===e&&a.set(null,u),a.set(i,u),this.count++,e=Zn.bind(this),u.addEventListener("load",e),u.addEventListener("error",e),n?n.parentNode.insertBefore(u,n.nextSibling):(l=l.nodeType===9?l.head:l,l.insertBefore(u,l.firstChild)),t.state.loading|=4}}var Du={$$typeof:P,Provider:null,Consumer:null,_currentValue:ll,_currentValue2:ll,_threadCount:0};function C1(l,t,a,e,u,n,i,c){this.tag=1,this.containerInfo=l,this.finishedWork=this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=ci(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.finishedLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=ci(0),this.hiddenUpdates=ci(null),this.identifierPrefix=e,this.onUncaughtError=u,this.onCaughtError=n,this.onRecoverableError=i,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=c,this.incompleteTransitions=new Map}function ko(l,t,a,e,u,n,i,c,s,h,T,M){return l=new C1(l,t,a,i,c,s,h,M),t=1,n===!0&&(t|=24),n=yt(3,null,null,t),l.current=n,n.stateNode=l,t=Yi(),t.refCount++,l.pooledCache=t,t.refCount++,n.memoizedState={element:e,isDehydrated:a,cache:t},gc(n),l}function $o(l){return l?(l=oe,l):oe}function Wo(l,t,a,e,u,n){u=$o(u),e.context===null?e.context=u:e.pendingContext=u,e=da(t),e.payload={element:a},n=n===void 0?null:n,n!==null&&(e.callback=n),a=ha(l,e,t),a!==null&&(Kl(a,l,t),ru(a,l,t))}function Fo(l,t){if(l=l.memoizedState,l!==null&&l.dehydrated!==null){var a=l.retryLane;l.retryLane=a!==0&&a<t?a:t}}function cf(l,t){Fo(l,t),(l=l.alternate)&&Fo(l,t)}function Po(l){if(l.tag===13){var t=na(l,67108864);t!==null&&Kl(t,l,67108864),cf(l,67108864)}}var Ln=!0;function G1(l,t,a,e){var u=X.T;X.T=null;var n=H.p;try{H.p=2,ff(l,t,a,e)}finally{H.p=n,X.T=u}}function X1(l,t,a,e){var u=X.T;X.T=null;var n=H.p;try{H.p=8,ff(l,t,a,e)}finally{H.p=n,X.T=u}}function ff(l,t,a,e){if(Ln){var u=sf(e);if(u===null)$c(l,t,e,Kn,a),ld(l,e);else if(Z1(u,l,t,a,e))e.stopPropagation();else if(ld(l,e),t&4&&-1<Q1.indexOf(l)){for(;u!==null;){var n=le(u);if(n!==null)switch(n.tag){case 3:if(n=n.stateNode,n.current.memoizedState.isDehydrated){var i=Da(n.pendingLanes);if(i!==0){var c=n;for(c.pendingLanes|=2,c.entangledLanes|=2;i;){var s=1<<31-Il(i);c.entanglements[1]|=s,i&=~s}xt(n),!(Sl&6)&&(_n=Ot()+500,Eu(0))}}break;case 13:c=na(n,2),c!==null&&Kl(c,n,2),Un(),cf(n,2)}if(n=sf(e),n===null&&$c(l,t,e,Kn,a),n===u)break;u=n}u!==null&&e.stopPropagation()}else $c(l,t,e,null,a)}}function sf(l){return l=vi(l),rf(l)}var Kn=null;function rf(l){if(Kn=null,l=_a(l),l!==null){var t=Z(l);if(t===null)l=null;else{var a=t.tag;if(a===13){if(l=hl(t),l!==null)return l;l=null}else if(a===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;l=null}else t!==l&&(l=null)}}return Kn=l,null}function Io(l){switch(l){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Md()){case Tf:return 2;case zf:return 8;case Gu:case Dd:return 32;case Af:return 268435456;default:return 32}default:return 32}}var of=!1,pa=null,Ea=null,Ta=null,_u=new Map,Nu=new Map,za=[],Q1="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function ld(l,t){switch(l){case"focusin":case"focusout":pa=null;break;case"dragenter":case"dragleave":Ea=null;break;case"mouseover":case"mouseout":Ta=null;break;case"pointerover":case"pointerout":_u.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":Nu.delete(t.pointerId)}}function xu(l,t,a,e,u,n){return l===null||l.nativeEvent!==n?(l={blockedOn:t,domEventName:a,eventSystemFlags:e,nativeEvent:n,targetContainers:[u]},t!==null&&(t=le(t),t!==null&&Po(t)),l):(l.eventSystemFlags|=e,t=l.targetContainers,u!==null&&t.indexOf(u)===-1&&t.push(u),l)}function Z1(l,t,a,e,u){switch(t){case"focusin":return pa=xu(pa,l,t,a,e,u),!0;case"dragenter":return Ea=xu(Ea,l,t,a,e,u),!0;case"mouseover":return Ta=xu(Ta,l,t,a,e,u),!0;case"pointerover":var n=u.pointerId;return _u.set(n,xu(_u.get(n)||null,l,t,a,e,u)),!0;case"gotpointercapture":return n=u.pointerId,Nu.set(n,xu(Nu.get(n)||null,l,t,a,e,u)),!0}return!1}function td(l){var t=_a(l.target);if(t!==null){var a=Z(t);if(a!==null){if(t=a.tag,t===13){if(t=hl(a),t!==null){l.blockedOn=t,Bd(l.priority,function(){if(a.tag===13){var e=ut(),u=na(a,e);u!==null&&Kl(u,a,e),cf(a,e)}});return}}else if(t===3&&a.stateNode.current.memoizedState.isDehydrated){l.blockedOn=a.tag===3?a.stateNode.containerInfo:null;return}}}l.blockedOn=null}function wn(l){if(l.blockedOn!==null)return!1;for(var t=l.targetContainers;0<t.length;){var a=sf(l.nativeEvent);if(a===null){a=l.nativeEvent;var e=new a.constructor(a.type,a);hi=e,a.target.dispatchEvent(e),hi=null}else return t=le(a),t!==null&&Po(t),l.blockedOn=a,!1;t.shift()}return!0}function ad(l,t,a){wn(l)&&a.delete(t)}function V1(){of=!1,pa!==null&&wn(pa)&&(pa=null),Ea!==null&&wn(Ea)&&(Ea=null),Ta!==null&&wn(Ta)&&(Ta=null),_u.forEach(ad),Nu.forEach(ad)}function Jn(l,t){l.blockedOn===t&&(l.blockedOn=null,of||(of=!0,f.unstable_scheduleCallback(f.unstable_NormalPriority,V1)))}var kn=null;function ed(l){kn!==l&&(kn=l,f.unstable_scheduleCallback(f.unstable_NormalPriority,function(){kn===l&&(kn=null);for(var t=0;t<l.length;t+=3){var a=l[t],e=l[t+1],u=l[t+2];if(typeof e!="function"){if(rf(e||a)===null)continue;break}var n=le(a);n!==null&&(l.splice(t,3),t-=3,Ii(n,{pending:!0,data:u,method:a.method,action:e},e,u))}}))}function Uu(l){function t(s){return Jn(s,l)}pa!==null&&Jn(pa,l),Ea!==null&&Jn(Ea,l),Ta!==null&&Jn(Ta,l),_u.forEach(t),Nu.forEach(t);for(var a=0;a<za.length;a++){var e=za[a];e.blockedOn===l&&(e.blockedOn=null)}for(;0<za.length&&(a=za[0],a.blockedOn===null);)td(a),a.blockedOn===null&&za.shift();if(a=(l.ownerDocument||l).$$reactFormReplay,a!=null)for(e=0;e<a.length;e+=3){var u=a[e],n=a[e+1],i=u[$l]||null;if(typeof n=="function")i||ed(a);else if(i){var c=null;if(n&&n.hasAttribute("formAction")){if(u=n,i=n[$l]||null)c=i.formAction;else if(rf(u)!==null)continue}else c=i.action;typeof c=="function"?a[e+1]=c:(a.splice(e,3),e-=3),ed(a)}}}function df(l){this._internalRoot=l}$n.prototype.render=df.prototype.render=function(l){var t=this._internalRoot;if(t===null)throw Error(r(409));var a=t.current,e=ut();Wo(a,e,l,t,null,null)},$n.prototype.unmount=df.prototype.unmount=function(){var l=this._internalRoot;if(l!==null){this._internalRoot=null;var t=l.containerInfo;l.tag===0&&_e(),Wo(l.current,2,null,l,null,null),Un(),t[Ia]=null}};function $n(l){this._internalRoot=l}$n.prototype.unstable_scheduleHydration=function(l){if(l){var t=xf();l={blockedOn:null,target:l,priority:t};for(var a=0;a<za.length&&t!==0&&t<za[a].priority;a++);za.splice(a,0,l),a===0&&td(l)}};var ud=m.version;if(ud!=="19.0.0")throw Error(r(527,ud,"19.0.0"));H.findDOMNode=function(l){var t=l._reactInternals;if(t===void 0)throw typeof l.render=="function"?Error(r(188)):(l=Object.keys(l).join(","),Error(r(268,l)));return l=_(t),l=l!==null?Q(l):null,l=l===null?null:l.stateNode,l};var L1={bundleType:0,version:"19.0.0",rendererPackageName:"react-dom",currentDispatcherRef:X,findFiberByHostInstance:_a,reconcilerVersion:"19.0.0"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var Wn=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!Wn.isDisabled&&Wn.supportsFiber)try{Be=Wn.inject(L1),Pl=Wn}catch{}}return Hu.createRoot=function(l,t){if(!D(l))throw Error(r(299));var a=!1,e="",u=pr,n=Er,i=Tr,c=null;return t!=null&&(t.unstable_strictMode===!0&&(a=!0),t.identifierPrefix!==void 0&&(e=t.identifierPrefix),t.onUncaughtError!==void 0&&(u=t.onUncaughtError),t.onCaughtError!==void 0&&(n=t.onCaughtError),t.onRecoverableError!==void 0&&(i=t.onRecoverableError),t.unstable_transitionCallbacks!==void 0&&(c=t.unstable_transitionCallbacks)),t=ko(l,1,!1,null,null,a,e,u,n,i,c,null),l[Ia]=t.current,kc(l.nodeType===8?l.parentNode:l),new df(t)},Hu.hydrateRoot=function(l,t,a){if(!D(l))throw Error(r(299));var e=!1,u="",n=pr,i=Er,c=Tr,s=null,h=null;return a!=null&&(a.unstable_strictMode===!0&&(e=!0),a.identifierPrefix!==void 0&&(u=a.identifierPrefix),a.onUncaughtError!==void 0&&(n=a.onUncaughtError),a.onCaughtError!==void 0&&(i=a.onCaughtError),a.onRecoverableError!==void 0&&(c=a.onRecoverableError),a.unstable_transitionCallbacks!==void 0&&(s=a.unstable_transitionCallbacks),a.formState!==void 0&&(h=a.formState)),t=ko(l,1,!0,t,a??null,e,u,n,i,c,s,h),t.context=$o(null),a=t.current,e=ut(),u=da(e),u.callback=null,ha(a,u,e),t.current.lanes=e,Ce(t,e),xt(t),l[Ia]=t.current,kc(l),new $n(t)},Hu.version="19.0.0",Hu}var vd;function lh(){if(vd)return yf.exports;vd=1;function f(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(f)}catch(m){console.error(m)}}return f(),yf.exports=I1(),yf.exports}var th=lh();let ah={data:""},eh=f=>typeof window=="object"?((f?f.querySelector("#_goober"):window._goober)||Object.assign((f||document.head).appendChild(document.createElement("style")),{innerHTML:" ",id:"_goober"})).firstChild:f||ah,uh=/(?:([\u0080-\uFFFF\w-%@]+) *:? *([^{;]+?);|([^;}{]*?) *{)|(}\s*)/g,nh=/\/\*[^]*?\*\/|  +/g,yd=/\n+/g,Oa=(f,m)=>{let b="",r="",D="";for(let p in f){let x=f[p];p[0]=="@"?p[1]=="i"?b=p+" "+x+";":r+=p[1]=="f"?Oa(x,p):p+"{"+Oa(x,p[1]=="k"?"":m)+"}":typeof x=="object"?r+=Oa(x,m?m.replace(/([^,])+/g,N=>p.replace(/([^,]*:\S+\([^)]*\))|([^,])+/g,O=>/&/.test(O)?O.replace(/&/g,N):N?N+" "+O:O)):p):x!=null&&(p=/^--/.test(p)?p:p.replace(/[A-Z]/g,"-$&").toLowerCase(),D+=Oa.p?Oa.p(p,x):p+":"+x+";")}return b+(m&&D?m+"{"+D+"}":D)+r},Wt={},gd=f=>{if(typeof f=="object"){let m="";for(let b in f)m+=b+gd(f[b]);return m}return f},ih=(f,m,b,r,D)=>{let p=gd(f),x=Wt[p]||(Wt[p]=(O=>{let S=0,R=11;for(;S<O.length;)R=101*R+O.charCodeAt(S++)>>>0;return"go"+R})(p));if(!Wt[x]){let O=p!==f?f:(S=>{let R,Y,w=[{}];for(;R=uh.exec(S.replace(nh,""));)R[4]?w.shift():R[3]?(Y=R[3].replace(yd," ").trim(),w.unshift(w[0][Y]=w[0][Y]||{})):w[0][R[1]]=R[2].replace(yd," ").trim();return w[0]})(f);Wt[x]=Oa(D?{["@keyframes "+x]:O}:O,b?"":"."+x)}let N=b&&Wt.g?Wt.g:null;return b&&(Wt.g=Wt[x]),((O,S,R,Y)=>{Y?S.data=S.data.replace(Y,O):S.data.indexOf(O)===-1&&(S.data=R?O+S.data:S.data+O)})(Wt[x],m,r,N),x},ch=(f,m,b)=>f.reduce((r,D,p)=>{let x=m[p];if(x&&x.call){let N=x(b),O=N&&N.props&&N.props.className||/^go/.test(N)&&N;x=O?"."+O:N&&typeof N=="object"?N.props?"":Oa(N,""):N===!1?"":N}return r+D+(x??"")},"");function ai(f){let m=this||{},b=f.call?f(m.p):f;return ih(b.unshift?b.raw?ch(b,[].slice.call(arguments,1),m.p):b.reduce((r,D)=>Object.assign(r,D&&D.call?D(m.p):D),{}):b,eh(m.target),m.g,m.o,m.k)}let bd,Sf,pf;ai.bind({g:1});let Pt=ai.bind({k:1});function fh(f,m,b,r){Oa.p=m,bd=f,Sf=b,pf=r}function Ma(f,m){let b=this||{};return function(){let r=arguments;function D(p,x){let N=Object.assign({},p),O=N.className||D.className;b.p=Object.assign({theme:Sf&&Sf()},N),b.o=/ *go\d+/.test(O),N.className=ai.apply(b,r)+(O?" "+O:"");let S=f;return f[0]&&(S=N.as||f,delete N.as),pf&&S[0]&&pf(N),bd(S,N)}return D}}var sh=f=>typeof f=="function",In=(f,m)=>sh(f)?f(m):f,rh=(()=>{let f=0;return()=>(++f).toString()})(),Sd=(()=>{let f;return()=>{if(f===void 0&&typeof window<"u"){let m=matchMedia("(prefers-reduced-motion: reduce)");f=!m||m.matches}return f}})(),oh=20,pd=(f,m)=>{switch(m.type){case 0:return{...f,toasts:[m.toast,...f.toasts].slice(0,oh)};case 1:return{...f,toasts:f.toasts.map(p=>p.id===m.toast.id?{...p,...m.toast}:p)};case 2:let{toast:b}=m;return pd(f,{type:f.toasts.find(p=>p.id===b.id)?1:0,toast:b});case 3:let{toastId:r}=m;return{...f,toasts:f.toasts.map(p=>p.id===r||r===void 0?{...p,dismissed:!0,visible:!1}:p)};case 4:return m.toastId===void 0?{...f,toasts:[]}:{...f,toasts:f.toasts.filter(p=>p.id!==m.toastId)};case 5:return{...f,pausedAt:m.time};case 6:let D=m.time-(f.pausedAt||0);return{...f,pausedAt:void 0,toasts:f.toasts.map(p=>({...p,pauseDuration:p.pauseDuration+D}))}}},Pn=[],Wa={toasts:[],pausedAt:void 0},Fa=f=>{Wa=pd(Wa,f),Pn.forEach(m=>{m(Wa)})},dh={blank:4e3,error:4e3,success:2e3,loading:1/0,custom:4e3},hh=(f={})=>{let[m,b]=L.useState(Wa),r=L.useRef(Wa);L.useEffect(()=>(r.current!==Wa&&b(Wa),Pn.push(b),()=>{let p=Pn.indexOf(b);p>-1&&Pn.splice(p,1)}),[]);let D=m.toasts.map(p=>{var x,N,O;return{...f,...f[p.type],...p,removeDelay:p.removeDelay||((x=f[p.type])==null?void 0:x.removeDelay)||(f==null?void 0:f.removeDelay),duration:p.duration||((N=f[p.type])==null?void 0:N.duration)||(f==null?void 0:f.duration)||dh[p.type],style:{...f.style,...(O=f[p.type])==null?void 0:O.style,...p.style}}});return{...m,toasts:D}},vh=(f,m="blank",b)=>({createdAt:Date.now(),visible:!0,dismissed:!1,type:m,ariaProps:{role:"status","aria-live":"polite"},message:f,pauseDuration:0,...b,id:(b==null?void 0:b.id)||rh()}),qu=f=>(m,b)=>{let r=vh(m,f,b);return Fa({type:2,toast:r}),r.id},gl=(f,m)=>qu("blank")(f,m);gl.error=qu("error");gl.success=qu("success");gl.loading=qu("loading");gl.custom=qu("custom");gl.dismiss=f=>{Fa({type:3,toastId:f})};gl.remove=f=>Fa({type:4,toastId:f});gl.promise=(f,m,b)=>{let r=gl.loading(m.loading,{...b,...b==null?void 0:b.loading});return typeof f=="function"&&(f=f()),f.then(D=>{let p=m.success?In(m.success,D):void 0;return p?gl.success(p,{id:r,...b,...b==null?void 0:b.success}):gl.dismiss(r),D}).catch(D=>{let p=m.error?In(m.error,D):void 0;p?gl.error(p,{id:r,...b,...b==null?void 0:b.error}):gl.dismiss(r)}),f};var yh=(f,m)=>{Fa({type:1,toast:{id:f,height:m}})},mh=()=>{Fa({type:5,time:Date.now()})},ju=new Map,gh=1e3,bh=(f,m=gh)=>{if(ju.has(f))return;let b=setTimeout(()=>{ju.delete(f),Fa({type:4,toastId:f})},m);ju.set(f,b)},Sh=f=>{let{toasts:m,pausedAt:b}=hh(f);L.useEffect(()=>{if(b)return;let p=Date.now(),x=m.map(N=>{if(N.duration===1/0)return;let O=(N.duration||0)+N.pauseDuration-(p-N.createdAt);if(O<0){N.visible&&gl.dismiss(N.id);return}return setTimeout(()=>gl.dismiss(N.id),O)});return()=>{x.forEach(N=>N&&clearTimeout(N))}},[m,b]);let r=L.useCallback(()=>{b&&Fa({type:6,time:Date.now()})},[b]),D=L.useCallback((p,x)=>{let{reverseOrder:N=!1,gutter:O=8,defaultPosition:S}=x||{},R=m.filter(P=>(P.position||S)===(p.position||S)&&P.height),Y=R.findIndex(P=>P.id===p.id),w=R.filter((P,Al)=>Al<Y&&P.visible).length;return R.filter(P=>P.visible).slice(...N?[w+1]:[0,w]).reduce((P,Al)=>P+(Al.height||0)+O,0)},[m]);return L.useEffect(()=>{m.forEach(p=>{if(p.dismissed)bh(p.id,p.removeDelay);else{let x=ju.get(p.id);x&&(clearTimeout(x),ju.delete(p.id))}})},[m]),{toasts:m,handlers:{updateHeight:yh,startPause:mh,endPause:r,calculateOffset:D}}},ph=Pt`
from {
  transform: scale(0) rotate(45deg);
	opacity: 0;
}
to {
 transform: scale(1) rotate(45deg);
  opacity: 1;
}`,Eh=Pt`
from {
  transform: scale(0);
  opacity: 0;
}
to {
  transform: scale(1);
  opacity: 1;
}`,Th=Pt`
from {
  transform: scale(0) rotate(90deg);
	opacity: 0;
}
to {
  transform: scale(1) rotate(90deg);
	opacity: 1;
}`,zh=Ma("div")`
  width: 20px;
  opacity: 0;
  height: 20px;
  border-radius: 10px;
  background: ${f=>f.primary||"#ff4b4b"};
  position: relative;
  transform: rotate(45deg);

  animation: ${ph} 0.3s cubic-bezier(0.175, 0.885, 0.32, 1.275)
    forwards;
  animation-delay: 100ms;

  &:after,
  &:before {
    content: '';
    animation: ${Eh} 0.15s ease-out forwards;
    animation-delay: 150ms;
    position: absolute;
    border-radius: 3px;
    opacity: 0;
    background: ${f=>f.secondary||"#fff"};
    bottom: 9px;
    left: 4px;
    height: 2px;
    width: 12px;
  }

  &:before {
    animation: ${Th} 0.15s ease-out forwards;
    animation-delay: 180ms;
    transform: rotate(90deg);
  }
`,Ah=Pt`
  from {
    transform: rotate(0deg);
  }
  to {
    transform: rotate(360deg);
  }
`,Oh=Ma("div")`
  width: 12px;
  height: 12px;
  box-sizing: border-box;
  border: 2px solid;
  border-radius: 100%;
  border-color: ${f=>f.secondary||"#e0e0e0"};
  border-right-color: ${f=>f.primary||"#616161"};
  animation: ${Ah} 1s linear infinite;
`,Mh=Pt`
from {
  transform: scale(0) rotate(45deg);
	opacity: 0;
}
to {
  transform: scale(1) rotate(45deg);
	opacity: 1;
}`,Dh=Pt`
0% {
	height: 0;
	width: 0;
	opacity: 0;
}
40% {
  height: 0;
	width: 6px;
	opacity: 1;
}
100% {
  opacity: 1;
  height: 10px;
}`,_h=Ma("div")`
  width: 20px;
  opacity: 0;
  height: 20px;
  border-radius: 10px;
  background: ${f=>f.primary||"#61d345"};
  position: relative;
  transform: rotate(45deg);

  animation: ${Mh} 0.3s cubic-bezier(0.175, 0.885, 0.32, 1.275)
    forwards;
  animation-delay: 100ms;
  &:after {
    content: '';
    box-sizing: border-box;
    animation: ${Dh} 0.2s ease-out forwards;
    opacity: 0;
    animation-delay: 200ms;
    position: absolute;
    border-right: 2px solid;
    border-bottom: 2px solid;
    border-color: ${f=>f.secondary||"#fff"};
    bottom: 6px;
    left: 6px;
    height: 10px;
    width: 6px;
  }
`,Nh=Ma("div")`
  position: absolute;
`,xh=Ma("div")`
  position: relative;
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 20px;
  min-height: 20px;
`,Uh=Pt`
from {
  transform: scale(0.6);
  opacity: 0.4;
}
to {
  transform: scale(1);
  opacity: 1;
}`,Rh=Ma("div")`
  position: relative;
  transform: scale(0.6);
  opacity: 0.4;
  min-width: 20px;
  animation: ${Uh} 0.3s 0.12s cubic-bezier(0.175, 0.885, 0.32, 1.275)
    forwards;
`,Hh=({toast:f})=>{let{icon:m,type:b,iconTheme:r}=f;return m!==void 0?typeof m=="string"?L.createElement(Rh,null,m):m:b==="blank"?null:L.createElement(xh,null,L.createElement(Oh,{...r}),b!=="loading"&&L.createElement(Nh,null,b==="error"?L.createElement(zh,{...r}):L.createElement(_h,{...r})))},jh=f=>`
0% {transform: translate3d(0,${f*-200}%,0) scale(.6); opacity:.5;}
100% {transform: translate3d(0,0,0) scale(1); opacity:1;}
`,qh=f=>`
0% {transform: translate3d(0,0,-1px) scale(1); opacity:1;}
100% {transform: translate3d(0,${f*-150}%,-1px) scale(.6); opacity:0;}
`,Bh="0%{opacity:0;} 100%{opacity:1;}",Yh="0%{opacity:1;} 100%{opacity:0;}",Ch=Ma("div")`
  display: flex;
  align-items: center;
  background: #fff;
  color: #363636;
  line-height: 1.3;
  will-change: transform;
  box-shadow: 0 3px 10px rgba(0, 0, 0, 0.1), 0 3px 3px rgba(0, 0, 0, 0.05);
  max-width: 350px;
  pointer-events: auto;
  padding: 8px 10px;
  border-radius: 8px;
`,Gh=Ma("div")`
  display: flex;
  justify-content: center;
  margin: 4px 10px;
  color: inherit;
  flex: 1 1 auto;
  white-space: pre-line;
`,Xh=(f,m)=>{let b=f.includes("top")?1:-1,[r,D]=Sd()?[Bh,Yh]:[jh(b),qh(b)];return{animation:m?`${Pt(r)} 0.35s cubic-bezier(.21,1.02,.73,1) forwards`:`${Pt(D)} 0.4s forwards cubic-bezier(.06,.71,.55,1)`}},Qh=L.memo(({toast:f,position:m,style:b,children:r})=>{let D=f.height?Xh(f.position||m||"top-center",f.visible):{opacity:0},p=L.createElement(Hh,{toast:f}),x=L.createElement(Gh,{...f.ariaProps},In(f.message,f));return L.createElement(Ch,{className:f.className,style:{...D,...b,...f.style}},typeof r=="function"?r({icon:p,message:x}):L.createElement(L.Fragment,null,p,x))});fh(L.createElement);var Zh=({id:f,className:m,style:b,onHeightUpdate:r,children:D})=>{let p=L.useCallback(x=>{if(x){let N=()=>{let O=x.getBoundingClientRect().height;r(f,O)};N(),new MutationObserver(N).observe(x,{subtree:!0,childList:!0,characterData:!0})}},[f,r]);return L.createElement("div",{ref:p,className:m,style:b},D)},Vh=(f,m)=>{let b=f.includes("top"),r=b?{top:0}:{bottom:0},D=f.includes("center")?{justifyContent:"center"}:f.includes("right")?{justifyContent:"flex-end"}:{};return{left:0,right:0,display:"flex",position:"absolute",transition:Sd()?void 0:"all 230ms cubic-bezier(.21,1.02,.73,1)",transform:`translateY(${m*(b?1:-1)}px)`,...r,...D}},Lh=ai`
  z-index: 9999;
  > * {
    pointer-events: auto;
  }
`,Fn=16,Kh=({reverseOrder:f,position:m="top-center",toastOptions:b,gutter:r,children:D,containerStyle:p,containerClassName:x})=>{let{toasts:N,handlers:O}=Sh(b);return L.createElement("div",{id:"_rht_toaster",style:{position:"fixed",zIndex:9999,top:Fn,left:Fn,right:Fn,bottom:Fn,pointerEvents:"none",...p},className:x,onMouseEnter:O.startPause,onMouseLeave:O.endPause},N.map(S=>{let R=S.position||m,Y=O.calculateOffset(S,{reverseOrder:f,gutter:r,defaultPosition:m}),w=Vh(R,Y);return L.createElement(Zh,{id:S.id,key:S.id,onHeightUpdate:O.updateHeight,className:S.visible?Lh:"",style:w},S.type==="custom"?In(S.message,S):D?D(S):L.createElement(Qh,{toast:S,position:R}))}))};const $a="http://127.0.0.1:8000/api",je={async addTorrent(f){const m=await fetch(`${$a}/torrent/add`,{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({magnet_link:f})});if(!m.ok){const b=await m.json();throw m.status===408?new Error("Timeout waiting for torrent metadata. Please check your link or try again."):m.status===409?new Error("This torrent is already being downloaded."):b.detail&&b.detail.includes("Invalid magnet link format")?new Error("Invalid magnet link format. Please check and try again."):new Error(b.detail||"Failed to add torrent. Please try again.")}return m.json()},async listTorrents(){const f=await fetch(`${$a}/torrent/list`);if(!f.ok)throw new Error("Failed to fetch torrents");return f.json()},async removeTorrent(f,m=!1){if(!(await fetch(`${$a}/torrent/${f}?delete_files=${m}`,{method:"DELETE"})).ok)throw new Error("Failed to remove torrent")},async pauseTorrent(f){if(!(await fetch(`${$a}/torrent/${f}/pause`,{method:"POST"})).ok)throw new Error("Failed to pause torrent")},async resumeTorrent(f){if(!(await fetch(`${$a}/torrent/${f}/resume`,{method:"POST"})).ok)throw new Error("Failed to resume torrent")},async getDownloadsPath(){const f=await fetch(`${$a}/downloads/path`);if(!f.ok)throw new Error("Failed to get downloads path");return(await f.json()).path},async openDownloadsFolder(){const f=await fetch(`${$a}/downloads/open`,{method:"POST"});if(!f.ok){const m=await f.json();throw new Error(m.detail||"Failed to open downloads folder")}}};/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const wh=f=>f.replace(/([a-z0-9])([A-Z])/g,"$1-$2").toLowerCase(),Ed=(...f)=>f.filter((m,b,r)=>!!m&&m.trim()!==""&&r.indexOf(m)===b).join(" ").trim();/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */var Jh={xmlns:"http://www.w3.org/2000/svg",width:24,height:24,viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:2,strokeLinecap:"round",strokeLinejoin:"round"};/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const kh=L.forwardRef(({color:f="currentColor",size:m=24,strokeWidth:b=2,absoluteStrokeWidth:r,className:D="",children:p,iconNode:x,...N},O)=>L.createElement("svg",{ref:O,...Jh,width:m,height:m,stroke:f,strokeWidth:r?Number(b)*24/Number(m):b,className:Ed("lucide",D),...N},[...x.map(([S,R])=>L.createElement(S,R)),...Array.isArray(p)?p:[p]]));/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Ql=(f,m)=>{const b=L.forwardRef(({className:r,...D},p)=>L.createElement(kh,{ref:p,iconNode:m,className:Ed(`lucide-${wh(f)}`,r),...D}));return b.displayName=`${f}`,b};/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const $h=Ql("CircleCheckBig",[["path",{d:"M21.801 10A10 10 0 1 1 17 3.335",key:"yps3ct"}],["path",{d:"m9 11 3 3L22 4",key:"1pflzl"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Wh=Ql("CircleX",[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["path",{d:"m15 9-6 6",key:"1uzhvr"}],["path",{d:"m9 9 6 6",key:"z0biqf"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Fh=Ql("Clock",[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["polyline",{points:"12 6 12 12 16 14",key:"68esgv"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Td=Ql("Download",[["path",{d:"M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4",key:"ih7n3h"}],["polyline",{points:"7 10 12 15 17 10",key:"2ggqvy"}],["line",{x1:"12",x2:"12",y1:"15",y2:"3",key:"1vk2je"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Ph=Ql("EllipsisVertical",[["circle",{cx:"12",cy:"12",r:"1",key:"41hilf"}],["circle",{cx:"12",cy:"5",r:"1",key:"gxeob9"}],["circle",{cx:"12",cy:"19",r:"1",key:"lyex9k"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Ih=Ql("Folder",[["path",{d:"M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",key:"1kt360"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const lv=Ql("HardDrive",[["line",{x1:"22",x2:"2",y1:"12",y2:"12",key:"1y58io"}],["path",{d:"M5.45 5.11 2 12v6a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-6l-3.45-6.89A2 2 0 0 0 16.76 4H7.24a2 2 0 0 0-1.79 1.11z",key:"oot6mr"}],["line",{x1:"6",x2:"6.01",y1:"16",y2:"16",key:"sgf278"}],["line",{x1:"10",x2:"10.01",y1:"16",y2:"16",key:"1l4acy"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const tv=Ql("Link",[["path",{d:"M10 13a5 5 0 0 0 7.54.54l3-3a5 5 0 0 0-7.07-7.07l-1.72 1.71",key:"1cjeqo"}],["path",{d:"M14 11a5 5 0 0 0-7.54-.54l-3 3a5 5 0 0 0 7.07 7.07l1.71-1.71",key:"19qd67"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const av=Ql("LoaderCircle",[["path",{d:"M21 12a9 9 0 1 1-6.219-8.56",key:"13zald"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ev=Ql("Pause",[["rect",{x:"14",y:"4",width:"4",height:"16",rx:"1",key:"zuxfzm"}],["rect",{x:"6",y:"4",width:"4",height:"16",rx:"1",key:"1okwgv"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const uv=Ql("Play",[["polygon",{points:"6 3 20 12 6 21 6 3",key:"1oa8hb"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const nv=Ql("Plus",[["path",{d:"M5 12h14",key:"1ays0h"}],["path",{d:"M12 5v14",key:"s699le"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const iv=Ql("Settings",[["path",{d:"M12.22 2h-.44a2 2 0 0 0-2 2v.18a2 2 0 0 1-1 1.73l-.43.25a2 2 0 0 1-2 0l-.15-.08a2 2 0 0 0-2.73.73l-.22.38a2 2 0 0 0 .73 2.73l.15.1a2 2 0 0 1 1 1.72v.51a2 2 0 0 1-1 1.74l-.15.09a2 2 0 0 0-.73 2.73l.22.38a2 2 0 0 0 2.73.73l.15-.08a2 2 0 0 1 2 0l.43.25a2 2 0 0 1 1 1.73V20a2 2 0 0 0 2 2h.44a2 2 0 0 0 2-2v-.18a2 2 0 0 1 1-1.73l.43-.25a2 2 0 0 1 2 0l.15.08a2 2 0 0 0 2.73-.73l.22-.39a2 2 0 0 0-.73-2.73l-.15-.08a2 2 0 0 1-1-1.74v-.5a2 2 0 0 1 1-1.74l.15-.09a2 2 0 0 0 .73-2.73l-.22-.38a2 2 0 0 0-2.73-.73l-.15.08a2 2 0 0 1-2 0l-.43-.25a2 2 0 0 1-1-1.73V4a2 2 0 0 0-2-2z",key:"1qme2f"}],["circle",{cx:"12",cy:"12",r:"3",key:"1v7zrd"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const cv=Ql("Trash2",[["path",{d:"M3 6h18",key:"d0wm0j"}],["path",{d:"M19 6v14c0 1-1 2-2 2H7c-1 0-2-1-2-2V6",key:"4alrt4"}],["path",{d:"M8 6V4c0-1 1-2 2-2h4c1 0 2 1 2 2v2",key:"v07s0e"}],["line",{x1:"10",x2:"10",y1:"11",y2:"17",key:"1uufr5"}],["line",{x1:"14",x2:"14",y1:"11",y2:"17",key:"xtxkd"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const li=Ql("Upload",[["path",{d:"M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4",key:"ih7n3h"}],["polyline",{points:"17 8 12 3 7 8",key:"t8dd8p"}],["line",{x1:"12",x2:"12",y1:"3",y2:"15",key:"widbto"}]]);/**
 * @license lucide-react v0.462.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const fv=Ql("Wifi",[["path",{d:"M12 20h.01",key:"zekei9"}],["path",{d:"M2 8.82a15 15 0 0 1 20 0",key:"dnpr2z"}],["path",{d:"M5 12.859a10 10 0 0 1 14 0",key:"1x1e6c"}],["path",{d:"M8.5 16.429a5 5 0 0 1 7 0",key:"1bycff"}]]),md=(f,m=2)=>{if(f===0)return"0 Bytes";const b=1024,r=m<0?0:m,D=["Bytes","KB","MB","GB","TB","PB","EB","ZB","YB"],p=Math.floor(Math.log(f)/Math.log(b));return parseFloat((f/Math.pow(b,p)).toFixed(r))+" "+D[p]},ti=f=>f>1024?`${(f/1024).toFixed(2)} MB/s`:`${f.toFixed(2)} KB/s`,sv=f=>{if(f===null)return"Calculating...";if(f===0)return"Complete";if(f<0||isNaN(f))return"Unknown";const m=Math.floor(f/3600),b=Math.floor(f%3600/60),r=Math.floor(f%60);return m>0?`${m}h ${b}m`:b>0?`${b}m ${r}s`:`${r}s`},rv=f=>`${f.toFixed(1)}%`,ov=f=>{switch(f){case"downloading":return"#2563eb";case"seeding":return"#16a34a";case"finished":return"#059669";case"checking":return"#ea580c";default:return"#64748b"}},dv=({torrents:f,onOpenDownloads:m,onShowSettings:b})=>{const r=f.reduce((N,O)=>N+O.download_speed,0),D=f.reduce((N,O)=>N+O.upload_speed,0),p=f.filter(N=>N.state==="downloading").length,x=f.filter(N=>N.state==="seeding").length;return A.jsx("header",{className:"app-header",children:A.jsxs("div",{className:"header-main",children:[A.jsxs("div",{className:"header-brand",children:[A.jsx("h1",{children:"Torrent Downloader"}),A.jsxs("div",{className:"connection-status",children:[A.jsx(fv,{size:16,className:"status-icon online"}),A.jsx("span",{children:"Connected"})]})]}),A.jsxs("div",{className:"header-stats",children:[A.jsxs("div",{className:"stat-group",children:[A.jsxs("div",{className:"stat-item-header",children:[A.jsx(Td,{size:16,className:"stat-icon download"}),A.jsx("span",{className:"stat-label",children:"Down"}),A.jsx("span",{className:"stat-value",children:ti(r)})]}),A.jsxs("div",{className:"stat-item-header",children:[A.jsx(li,{size:16,className:"stat-icon upload"}),A.jsx("span",{className:"stat-label",children:"Up"}),A.jsx("span",{className:"stat-value",children:ti(D)})]})]}),A.jsxs("div",{className:"stat-group",children:[A.jsxs("div",{className:"stat-item-header",children:[A.jsx("span",{className:"stat-count",children:p}),A.jsx("span",{className:"stat-label",children:"Downloading"})]}),A.jsxs("div",{className:"stat-item-header",children:[A.jsx("span",{className:"stat-count",children:x}),A.jsx("span",{className:"stat-label",children:"Seeding"})]})]})]}),A.jsxs("div",{className:"header-actions",children:[A.jsxs("button",{onClick:m,className:"action-button secondary",title:"Open Downloads Folder",children:[A.jsx(Ih,{size:18}),"Downloads"]}),b&&A.jsx("button",{onClick:b,className:"action-button secondary",title:"Settings",children:A.jsx(iv,{size:18})})]})]})})};function zd(f){var m,b,r="";if(typeof f=="string"||typeof f=="number")r+=f;else if(typeof f=="object")if(Array.isArray(f)){var D=f.length;for(m=0;m<D;m++)f[m]&&(b=zd(f[m]))&&(r&&(r+=" "),r+=b)}else for(b in f)f[b]&&(r&&(r+=" "),r+=b);return r}function Ft(){for(var f,m,b=0,r="",D=arguments.length;b<D;b++)(f=arguments[b])&&(m=zd(f))&&(r&&(r+=" "),r+=m);return r}const hv=({onAddMagnet:f,onAddFile:m,isLoading:b})=>{const[r,D]=L.useState(""),[p,x]=L.useState("magnet"),N=L.useRef(null),O=async Y=>{Y.preventDefault(),r.trim()&&(await f(r.trim()),D(""))},S=async Y=>{var P;const w=(P=Y.target.files)==null?void 0:P[0];w&&m&&(await m(w),N.current&&(N.current.value=""))},R=Y=>Y.startsWith("magnet:")&&Y.includes("xt=urn:btih:");return A.jsxs("div",{className:"add-torrent-container",children:[A.jsxs("div",{className:"tab-selector",children:[A.jsxs("button",{onClick:()=>x("magnet"),className:Ft("tab-button",{active:p==="magnet"}),children:[A.jsx(tv,{size:16}),"Magnet Link"]}),A.jsxs("button",{onClick:()=>x("file"),className:Ft("tab-button",{active:p==="file"}),children:[A.jsx(li,{size:16}),"Torrent File"]})]}),p==="magnet"&&A.jsxs("form",{onSubmit:O,className:"add-torrent-form",children:[A.jsxs("div",{className:"input-group",children:[A.jsx("input",{type:"text",value:r,onChange:Y=>D(Y.target.value),placeholder:"Paste magnet link here...",disabled:b,className:Ft("torrent-input",{invalid:r&&!R(r)})}),A.jsx("button",{type:"submit",disabled:b||!r.trim()||!R(r),className:"add-button",children:b?A.jsx("div",{className:"loading-spinner small"}):A.jsxs(A.Fragment,{children:[A.jsx(nv,{size:16}),"Add Torrent"]})})]}),r&&!R(r)&&A.jsx("p",{className:"input-error",children:"Please enter a valid magnet link"})]}),p==="file"&&A.jsxs("div",{className:"file-upload-section",children:[A.jsx("input",{ref:N,type:"file",accept:".torrent",onChange:S,disabled:b||!m,className:"file-input",id:"torrent-file"}),A.jsxs("label",{htmlFor:"torrent-file",className:"file-upload-label",children:[A.jsx(li,{size:24}),A.jsx("span",{children:"Choose .torrent file or drag & drop"})]}),!m&&A.jsx("p",{className:"file-upload-notice",children:"File upload will be available in a future update"})]})]})},vv=({torrent:f,onRemove:m,onPause:b,onResume:r})=>{const[D,p]=L.useState(!1),[x,N]=L.useState(!1),O=async()=>{N(!0);try{await m(f.id)}catch{N(!1)}},S=()=>{const R="px-2 py-1 rounded-full text-xs font-medium uppercase tracking-wide";switch(f.state){case"downloading":return A.jsx("span",{className:Ft(R,"bg-blue-100 text-blue-800 dark:bg-blue-900 dark:text-blue-200"),children:"Downloading"});case"seeding":return A.jsx("span",{className:Ft(R,"bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-200"),children:"Seeding"});case"finished":return A.jsx("span",{className:Ft(R,"bg-emerald-100 text-emerald-800 dark:bg-emerald-900 dark:text-emerald-200"),children:"Finished"});case"checking":return A.jsx("span",{className:Ft(R,"bg-orange-100 text-orange-800 dark:bg-orange-900 dark:text-orange-200"),children:"Checking"});default:return A.jsx("span",{className:Ft(R,"bg-gray-100 text-gray-800 dark:bg-gray-900 dark:text-gray-200"),children:"Unknown"})}};return A.jsxs("div",{className:"torrent-card",children:[A.jsxs("div",{className:"torrent-card-header",children:[A.jsxs("div",{className:"torrent-title-section",children:[A.jsx("h3",{className:"torrent-title",children:f.name}),S()]}),A.jsx("div",{className:"torrent-actions",children:A.jsxs("div",{className:"relative",children:[A.jsx("button",{onClick:()=>p(!D),className:"action-button secondary","aria-label":"More actions",children:A.jsx(Ph,{size:16})}),D&&A.jsxs("div",{className:"action-menu",children:[f.state==="downloading"?A.jsxs("button",{onClick:()=>{b==null||b(f.id),p(!1)},className:"menu-item",children:[A.jsx(ev,{size:14}),"Pause"]}):A.jsxs("button",{onClick:()=>{r==null||r(f.id),p(!1)},className:"menu-item",children:[A.jsx(uv,{size:14}),"Resume"]}),A.jsxs("button",{onClick:()=>{O(),p(!1)},className:"menu-item danger",disabled:x,children:[A.jsx(cv,{size:14}),x?"Removing...":"Remove"]})]})]})})]}),A.jsx("div",{className:"torrent-progress-section",children:A.jsxs("div",{className:"progress-bar-container",children:[A.jsx("div",{className:"progress-bar",children:A.jsx("div",{className:"progress-fill",style:{width:`${f.progress}%`,backgroundColor:ov(f.state)}})}),A.jsx("span",{className:"progress-text",children:rv(f.progress)})]})}),A.jsxs("div",{className:"torrent-stats",children:[A.jsxs("div",{className:"stat-item",children:[A.jsx(Td,{size:16,className:"stat-icon"}),A.jsx("span",{className:"stat-value",children:ti(f.download_speed)})]}),A.jsxs("div",{className:"stat-item",children:[A.jsx(li,{size:16,className:"stat-icon"}),A.jsx("span",{className:"stat-value",children:ti(f.upload_speed)})]}),A.jsxs("div",{className:"stat-item",children:[A.jsx(lv,{size:16,className:"stat-icon"}),A.jsxs("span",{className:"stat-value",children:[md(f.downloaded)," / ",md(f.total_size)]})]}),A.jsxs("div",{className:"stat-item",children:[A.jsx(Fh,{size:16,className:"stat-icon"}),A.jsx("span",{className:"stat-value",children:sv(f.eta_seconds)})]})]})]})},yv=({status:f,message:m,className:b})=>{if(f==="idle")return null;const r=()=>{switch(f){case"loading":return A.jsx(av,{size:20,className:"animate-spin"});case"success":return A.jsx($h,{size:20,className:"text-green-500"});case"error":return A.jsx(Wh,{size:20,className:"text-red-500"});default:return null}},D=()=>{switch(f){case"loading":return"status-loading";case"success":return"status-success";case"error":return"status-error";default:return""}};return A.jsx("div",{className:Ft("status-message",D(),b),children:A.jsxs("div",{className:"status-content",children:[r(),A.jsx("p",{className:"status-text",children:m})]})})};function mv(){const[f,m]=L.useState([]),[b,r]=L.useState(!1),[D,p]=L.useState(null),[x,N]=L.useState({status:"idle",message:""}),[O,S]=L.useState(1e3),R=L.useCallback(al=>{al.filter(sl=>sl.state==="downloading"||sl.state==="checking").length===0?S(5e3):S(1e3)},[]),Y=L.useCallback(async()=>{try{const al=await je.listTorrents();m(al),R(al),p(null)}catch(al){console.error("Error fetching torrents:",al),p("Connection lost. Retrying...")}},[R]);L.useEffect(()=>{Y();const al=setInterval(Y,O);return()=>clearInterval(al)},[Y,O]);const w=async al=>{r(!0),p(null),N({status:"loading",message:"Connecting to trackers..."});try{const el=setTimeout(()=>{N({status:"loading",message:"Fetching torrent metadata..."})},1e3),sl=setTimeout(()=>{N({status:"loading",message:"Waiting for peers..."})},3e3),bt=await je.addTorrent(al);clearTimeout(el),clearTimeout(sl),N({status:"success",message:bt.message||"Torrent added successfully!"}),gl.success(`Added: ${bt.message||"Torrent added successfully!"}`),Y(),setTimeout(()=>{N({status:"idle",message:""})},3e3)}catch(el){const sl=el instanceof Error?el.message:"Failed to add torrent";p(sl),N({status:"error",message:sl}),gl.error(sl),setTimeout(()=>{N({status:"idle",message:""})},5e3)}finally{r(!1)}},P=async al=>{try{await je.removeTorrent(al),m(f.filter(el=>el.id!==al)),gl.success("Torrent removed successfully"),p(null)}catch(el){const sl="Failed to remove torrent";p(sl),gl.error(sl),console.error("Error removing torrent:",el)}},Al=async()=>{try{await je.openDownloadsFolder(),gl.success("Downloads folder opened"),p(null)}catch(al){const el="Failed to open downloads folder";p(el),gl.error(el),console.error("Error opening downloads folder:",al)}},wl=async al=>{try{await je.pauseTorrent(al),gl.success("Torrent paused successfully"),p(null),Y()}catch(el){const sl="Failed to pause torrent";p(sl),gl.error(sl),console.error("Error pausing torrent:",el)}},Zl=async al=>{try{await je.resumeTorrent(al),gl.success("Torrent resumed successfully"),p(null),Y()}catch(el){const sl="Failed to resume torrent";p(sl),gl.error(sl),console.error("Error resuming torrent:",el)}};return A.jsxs("div",{className:"app",children:[A.jsx(Kh,{position:"top-right",toastOptions:{duration:4e3,style:{background:"var(--background-primary)",color:"var(--text-primary)",border:"1px solid var(--border-color)"}}}),A.jsx(dv,{torrents:f,onOpenDownloads:Al}),A.jsxs("main",{className:"main-content",children:[D&&A.jsx("div",{className:"error-banner",children:A.jsx("p",{children:D})}),A.jsx(hv,{onAddMagnet:w,isLoading:b}),A.jsx(yv,{status:x.status,message:x.message}),A.jsx("div",{className:"torrents-section",children:f.length===0?A.jsx("div",{className:"empty-state",children:A.jsxs("div",{className:"empty-state-content",children:[A.jsx("h3",{children:"No torrents yet"}),A.jsx("p",{children:"Add a magnet link above to get started downloading torrents"})]})}):A.jsx("div",{className:"torrents-grid",children:f.map(al=>A.jsx(vv,{torrent:al,onRemove:P,onPause:wl,onResume:Zl},al.id))})})]})]})}th.createRoot(document.getElementById("root")).render(A.jsx(L.StrictMode,{children:A.jsx(mv,{})}));
